@@ -124,7 +124,7 @@ const storageAcctName = 'azmonteststorage';
 const logAnalyticsName = 'az-mon-test-logs';
 const applicationInsightsName = 'az-mon-test-ai-a';
 
-describe('Azure monitor datasource', () => {
+describe.skip('Azure monitor datasource', () => {
   before(() => {
     e2e.flows.login(Cypress.env('USERNAME'), Cypress.env('PASSWORD'));
 
