@@ -1,7 +1,8 @@
 import testDashboard from '../dashboards/DashboardLiveTest.json';
 import { e2e } from '../utils';
 
-describe('Dashboard Live streaming support', () => {
+// Skipping due to flakiness/race conditions with same old arch test  e2e/dashboards-suite/dashboard-live-streaming.spec.ts
+describe.skip('Dashboard Live streaming support', () => {
   beforeEach(() => {
     e2e.flows.login(Cypress.env('USERNAME'), Cypress.env('PASSWORD'));
     e2e.flows.importDashboard(testDashboard, 1000);
