@@ -1,4 +1,4 @@
-import { marked } from 'marked';
+import { marked, MarkedOptions } from 'marked';
 import { mangle } from 'marked-mangle';
 
 import { sanitizeTextPanelContent } from './sanitize';
@@ -10,13 +10,9 @@ export interface RenderMarkdownOptions {
   breaks?: boolean;
 }
 
-const markdownOptions = {
-  headerIds: false,
+const markdownOptions: MarkedOptions = {
   pedantic: false,
   gfm: true,
-  smartLists: true,
-  smartypants: false,
-  xhtml: false,
   breaks: false,
 };
 
@@ -36,6 +32,12 @@ export function renderMarkdown(str?: string, options?: RenderMarkdownOptions): s
   }
   const html = marked(str || '', opts);
 
+  // `marked()` returns a promise if using any extensions that require async processing.
+  // we don't use any async extensions, but there is no way for typescript to know this, so we need to check the type.
+  if (typeof html !== 'string') {
+    throw new Error('Failed to process markdown synchronously.');
+  }
+
   if (options?.noSanitize) {
     return html;
   }
@@ -51,6 +53,13 @@ export function renderTextPanelMarkdown(str?: string, options?: RenderMarkdownOp
   }
 
   const html = marked(str || '');
+
+  // `marked()` returns a promise if using any extensions that require async processing.
+  // we don't use any async extensions, but there is no way for typescript to know this, so we need to check the type.
+  if (typeof html !== 'string') {
+    throw new Error('Failed to process markdown synchronously.');
+  }
+
   if (options?.noSanitize) {
     return html;
   }
