@@ -1,4 +1,4 @@
-import { toDataFrame } from '../../../dataframe';
+import { toDataFrame } from '../../../dataframe/processDataFrame';
 import { DataFrame } from '../../../types/dataFrame';
 import { getValueMatcher } from '../../matchers';
 import { ValueMatcherID } from '../ids';
