@@ -1,4 +1,4 @@
-import React, { SVGProps } from 'react';
+import { SVGProps } from 'react';
 
 export type IconSize = 'xs' | 'sm' | 'md' | 'lg' | 'xl' | 'xxl' | 'xxxl';
 
@@ -33,8 +33,6 @@ export const IconBase = ({ title, size = 'md', color = 'currentColor', ...props
   return (
     <svg
       {...props}
-      xmlns="http://www.w3.org/2000/svg"
-      viewBox="0 0 24 24"
       height={svgSize}
       width={svgSize}
       style={{
