@@ -1,4 +1,6 @@
-import { ScopedVars, DataSourceApi, DataSourceInstanceSettings } from '@grafana/data';
+import { ScopedVars, DataSourceApi, DataSourceInstanceSettings, DataSourceRef } from '@grafana/data';
+
+import { RuntimeDataSource } from './RuntimeDataSource';
 
 /**
  * This is the entry point for communicating with a datasource that is added as
@@ -10,10 +12,11 @@ import { ScopedVars, DataSourceApi, DataSourceInstanceSettings } from '@grafana/
  */
 export interface DataSourceSrv {
   /**
-   * @param name - name of the datasource plugin you want to use.
+   * Returns the requested dataSource. If it cannot be found it rejects the promise.
+   * @param ref - The datasource identifier, typically an object with UID and type,
    * @param scopedVars - variables used to interpolate a templated passed as name.
    */
-  get(name?: string | null, scopedVars?: ScopedVars): Promise<DataSourceApi>;
+  get(ref?: DataSourceRef | string | null, scopedVars?: ScopedVars): Promise<DataSourceApi>;
 
   /**
    * Get a list of data sources
@@ -23,12 +26,29 @@ export interface DataSourceSrv {
   /**
    * Get settings and plugin metadata by name or uid
    */
-  getInstanceSettings(nameOrUid: string | null | undefined): DataSourceInstanceSettings | undefined;
+  getInstanceSettings(
+    ref?: DataSourceRef | string | null,
+    scopedVars?: ScopedVars
+  ): DataSourceInstanceSettings | undefined;
+
+  /**
+   * Reloads the DataSourceSrv
+   */
+  reload(): void;
+
+  /**
+   * Registers a runtime data source. Make sure your data source uid is unique.
+   */
+  registerRuntimeDataSource(entry: RuntimeDataSourceRegistration): void;
+}
+
+export interface RuntimeDataSourceRegistration {
+  dataSource: RuntimeDataSource;
 }
 
 /** @public */
 export interface GetDataSourceListFilters {
-  /** Include mixed deta source by setting this to true */
+  /** Include mixed data source by setting this to true */
   mixed?: boolean;
 
   /** Only return data sources that support metrics response */
@@ -37,9 +57,15 @@ export interface GetDataSourceListFilters {
   /** Only return data sources that support tracing response */
   tracing?: boolean;
 
+  /** Only return data sources that support logging response */
+  logs?: boolean;
+
   /** Only return data sources that support annotations */
   annotations?: boolean;
 
+  /** Only filter data sources that support alerting */
+  alerting?: boolean;
+
   /**
    * By default only data sources that can be queried will be returned. Meaning they have tracing,
    * metrics, logs or annotations flag set in plugin.json file
@@ -54,6 +80,12 @@ export interface GetDataSourceListFilters {
 
   /** filter list by plugin  */
   pluginId?: string;
+
+  /** apply a function to filter */
+  filter?: (dataSource: DataSourceInstanceSettings) => boolean;
+
+  /** Only returns datasources matching the specified types (ie. Loki, Prometheus) */
+  type?: string | string[];
 }
 
 let singletonInstance: DataSourceSrv;
