@@ -6,15 +6,18 @@ export type {
   SQLQuery,
   SqlQueryModel,
   SQLSelectableValue,
+  Func,
+  FuncParameter,
 } from './types';
 export { QueryFormat } from './types'; // this is an enum, we cannot export-type it
+export { COMMON_FNS, MACRO_FUNCTIONS } from './constants';
 export { SqlDatasource } from './datasource/SqlDatasource';
 export { formatSQL } from './utils/formatSQL';
 export { ConnectionLimits } from './components/configuration/ConnectionLimits';
 export { Divider } from './components/configuration/Divider';
 export { TLSSecretsConfig } from './components/configuration/TLSSecretsConfig';
 export { useMigrateDatabaseFields } from './components/configuration/useMigrateDatabaseFields';
-export { SqlQueryEditor } from './components/QueryEditor';
+export { SqlQueryEditorLazy } from './components/QueryEditorLazy';
 export type { QueryHeaderProps } from './components/QueryHeader';
 export { createSelectClause, haveColumns } from './utils/sql.utils';
 export { applyQueryDefaults } from './defaults';
