@@ -1,37 +1,47 @@
 import resolve from '@rollup/plugin-node-resolve';
+import { createRequire } from 'node:module';
 import path from 'path';
 import copy from 'rollup-plugin-copy';
 import dts from 'rollup-plugin-dts';
 import esbuild from 'rollup-plugin-esbuild';
-import { externals } from 'rollup-plugin-node-externals';
+import { nodeExternals } from 'rollup-plugin-node-externals';
 import svg from 'rollup-plugin-svg-import';
 
-const icons = require('../../public/app/core/icons/cached.json');
-
-const pkg = require('./package.json');
+const rq = createRequire(import.meta.url);
+const icons = rq('../../public/app/core/icons/cached.json');
+const pkg = rq('./package.json');
 
 const iconSrcPaths = icons.map((iconSubPath) => {
   return `../../public/img/icons/${iconSubPath}.svg`;
 });
 
+const legacyOutputDefaults = {
+  esModule: true,
+  interop: 'compat',
+};
+
 export default [
   {
     input: 'src/index.ts',
     plugins: [
-      externals({ deps: true, packagePath: './package.json' }),
+      nodeExternals({ deps: true, packagePath: './package.json' }),
       svg({ stringify: true }),
       resolve(),
       copy({
         targets: [{ src: iconSrcPaths, dest: './dist/public/' }],
         flatten: false,
       }),
-      esbuild(),
+      esbuild({
+        target: 'es2018',
+        tsconfig: 'tsconfig.build.json',
+      }),
     ],
     output: [
       {
         format: 'cjs',
         sourcemap: true,
         dir: path.dirname(pkg.publishConfig.main),
+        ...legacyOutputDefaults,
       },
       {
         format: 'esm',
@@ -40,6 +50,7 @@ export default [
         preserveModules: true,
         // @ts-expect-error (TS cannot assure that `process.env.PROJECT_CWD` is a string)
         preserveModulesRoot: path.join(process.env.PROJECT_CWD, `packages/grafana-ui/src`),
+        ...legacyOutputDefaults,
       },
     ],
   },
