@@ -1,16 +1,12 @@
 import { render, screen } from '@testing-library/react';
 import userEvent from '@testing-library/user-event';
-import React from 'react';
-import renderer from 'react-test-renderer';
 
 import { ColorPicker } from './ColorPicker';
-import { ColorSwatch } from './ColorSwatch';
 
 describe('ColorPicker', () => {
   it('renders ColorPickerTrigger component by default', () => {
-    expect(
-      renderer.create(<ColorPicker color="#EAB839" onChange={() => {}} />).root.findByType(ColorSwatch)
-    ).toBeTruthy();
+    render(<ColorPicker color="#EAB839" onChange={() => {}} />);
+    expect(screen.getByRole('button', { name: '#EAB839 color' })).toBeInTheDocument();
   });
 
   it('should not have buttons with default submit type', async () => {
@@ -25,13 +21,11 @@ describe('ColorPicker', () => {
   });
 
   it('renders custom trigger when supplied', () => {
-    const div = renderer
-      .create(
-        <ColorPicker color="#EAB839" onChange={() => {}}>
-          {() => <div>Custom trigger</div>}
-        </ColorPicker>
-      )
-      .root.findByType('div');
-    expect(div.children[0]).toBe('Custom trigger');
+    render(
+      <ColorPicker color="#EAB839" onChange={() => {}}>
+        {() => <div>Custom trigger</div>}
+      </ColorPicker>
+    );
+    expect(screen.getByText('Custom trigger')).toBeInTheDocument();
   });
 });
