@@ -1,6 +1,6 @@
 import { action } from '@storybook/addon-actions';
 import { StoryFn, Meta } from '@storybook/react';
-import React from 'react';
+import * as React from 'react';
 
 import { IconButton } from '../IconButton/IconButton';
 
