@@ -1,6 +1,7 @@
 import { css, cx } from '@emotion/css';
 import { groupBy, capitalize } from 'lodash';
-import React, { useRef, useMemo } from 'react';
+import { useRef, useMemo } from 'react';
+import * as React from 'react';
 import useClickAway from 'react-use/lib/useClickAway';
 
 import { VariableSuggestion, GrafanaTheme2 } from '@grafana/data';
