@@ -1,5 +1,5 @@
 import { css } from '@emotion/css';
-import React, { ReactNode } from 'react';
+import { useRef, ReactNode } from 'react';
 
 import { TimeOption } from '@grafana/data';
 
@@ -8,6 +8,7 @@ import { t } from '../../../utils/i18n';
 
 import { TimePickerTitle } from './TimePickerTitle';
 import { TimeRangeOption } from './TimeRangeOption';
+import { useListFocus } from './hooks';
 
 interface Props {
   title?: string;
@@ -44,9 +45,17 @@ export const TimeRangeList = (props: Props) => {
 const Options = ({ options, value, onChange, title }: Props) => {
   const styles = useStyles2(getOptionsStyles);
 
+  const localRef = useRef<HTMLUListElement>(null);
+  const [handleKeys] = useListFocus({ localRef, options });
+
   return (
     <>
-      <ul aria-roledescription={t('time-picker.time-range.aria-role', 'Time range selection')}>
+      <ul
+        role="presentation"
+        onKeyDown={handleKeys}
+        ref={localRef}
+        aria-roledescription={t('time-picker.time-range.aria-role', 'Time range selection')}
+      >
         {options.map((option, index) => (
           <TimeRangeOption
             key={keyForOption(option, index)}
