@@ -1,5 +1,5 @@
 import { toLower, isEmpty, isString } from 'lodash';
-import React, { useMemo, useCallback } from 'react';
+import { useMemo, useCallback } from 'react';
 
 import {
   SelectableValue,
