@@ -1,6 +1,7 @@
 // Libraries
 import classNames from 'classnames';
-import React, { PureComponent } from 'react';
+import { PureComponent } from 'react';
+import * as React from 'react';
 import { default as ReactSelect, components, MenuListProps } from 'react-select';
 import { default as ReactAsyncSelect } from 'react-select/async';
 import Creatable from 'react-select/creatable';
@@ -8,8 +9,7 @@ import Creatable from 'react-select/creatable';
 // Components
 import { SelectableValue, ThemeContext } from '@grafana/data';
 
-import { CustomScrollbar } from '../../../CustomScrollbar/CustomScrollbar';
-import { SelectOptionGroup } from '../../../Select/SelectOptionGroup';
+import { ScrollContainer } from '../../../ScrollContainer/ScrollContainer';
 import { SingleValue } from '../../../Select/SingleValue';
 import resetSelectStyles from '../../../Select/resetSelectStyles';
 import { SelectCommonProps, SelectAsyncProps } from '../../../Select/types';
@@ -18,6 +18,7 @@ import { Tooltip, PopoverContent } from '../../../Tooltip';
 import IndicatorsContainer from './IndicatorsContainer';
 import NoOptionsMessage from './NoOptionsMessage';
 import { SelectOption } from './SelectOption';
+import { SelectOptionGroup } from './SelectOptionGroup';
 
 /**
  * Changes in new selects:
@@ -44,9 +45,9 @@ export interface LegacySelectProps<T> extends LegacyCommonProps<T> {
 export const MenuList = (props: MenuListProps) => {
   return (
     <components.MenuList {...props}>
-      <CustomScrollbar autoHide={false} autoHeightMax="inherit">
+      <ScrollContainer showScrollIndicators overflowX="hidden" maxHeight="inherit">
         {props.children}
-      </CustomScrollbar>
+      </ScrollContainer>
     </components.MenuList>
   );
 };
@@ -245,6 +246,7 @@ export class AsyncSelect<T> extends PureComponent<AsyncProps<T>> {
               //@ts-expect-error
               getOptionValue={getOptionValue}
               menuShouldScrollIntoView={false}
+              //@ts-expect-error
               onChange={onChange}
               loadOptions={loadOptions}
               isLoading={isLoading}
