@@ -1,8 +1,7 @@
 import { Meta, StoryFn } from '@storybook/react';
-import React from 'react';
 
 import { StoryExample } from '../../utils/storybook/StoryExample';
-import { VerticalGroup } from '../Layout/Layout';
+import { Stack } from '../Layout/Stack/Stack';
 import { Text } from '../Text/Text';
 
 import { TextLink } from './TextLink';
@@ -33,7 +32,7 @@ const meta: Meta = {
     inline: { control: 'boolean' },
   },
   args: {
-    href: 'https://www.google.com',
+    href: 'https://www.grafana.com',
     external: true,
     icon: 'external-link-alt',
   },
@@ -41,7 +40,7 @@ const meta: Meta = {
 
 export const Example: StoryFn = (args) => {
   return (
-    <VerticalGroup>
+    <Stack direction="column">
       <StoryExample name="This is a 'inline + external' link with the default behaviour">
         <Text element="p">
           To get started with a forever free Grafana Cloud account, sign up at &#160;
@@ -52,7 +51,7 @@ export const Example: StoryFn = (args) => {
         </Text>
       </StoryExample>
       <StoryExample name="This is a 'standalone + external' link with the default behaviour">
-        <TextLink href="https://grafana.com/docs/grafana/latest/" {...args}>
+        <TextLink href="https://grafana.com/docs/grafana/latest/" external inline={false} {...args}>
           Learn how in the docs
         </TextLink>
       </StoryExample>
@@ -60,7 +59,7 @@ export const Example: StoryFn = (args) => {
       <Text element="p">
         *The examples cannot contemplate an internal link due to conflicts between Storybook and React Router
       </Text>
-    </VerticalGroup>
+    </Stack>
   );
 };
 
@@ -68,14 +67,33 @@ Example.parameters = {
   controls: { exclude: ['href', 'external', 'variant', 'weight', 'color', 'inline', 'icon'] },
 };
 
-export const Basic: StoryFn = (args) => {
+export const Inline: StoryFn = (args) => {
   return (
     <div>
+      For more information{' '}
       <TextLink href={args.href} {...args}>
-        Go to Google
+        see Grafana.com
       </TextLink>
     </div>
   );
 };
 
+Inline.args = {
+  inline: true,
+};
+
+export const Standalone: StoryFn = (args) => {
+  return (
+    <div>
+      <TextLink href={args.href} {...args}>
+        Go to Grafana.com
+      </TextLink>
+    </div>
+  );
+};
+
+Standalone.args = {
+  inline: false,
+};
+
 export default meta;
