@@ -1,5 +1,6 @@
 import { css } from '@emotion/css';
-import React, { useMemo, useCallback } from 'react';
+import { useMemo, useCallback } from 'react';
+import * as React from 'react';
 
 import {
   FieldMatcherID,
@@ -61,7 +62,7 @@ export const FieldValueMatcherEditor = ({ options, onChange }: Props) => {
   );
 
   const opts = options ?? {};
-  const isBool = isBooleanReducer(options.reducer);
+  const isBool = isBooleanReducer(opts.reducer);
 
   return (
     <div className={styles.spot}>
