@@ -1,4 +1,5 @@
-import React, { useState, useRef, ReactElement } from 'react';
+import { useState, useRef, ReactElement } from 'react';
+import * as React from 'react';
 
 import { useStyles2 } from '../../themes';
 import { clearButtonStyles } from '../Button';
