@@ -1,11 +1,12 @@
 import { css, cx } from '@emotion/css';
 import { uniqueId } from 'lodash';
-import React, { HTMLProps, useRef } from 'react';
+import { forwardRef, HTMLProps, useRef } from 'react';
 
 import { GrafanaTheme2, deprecationWarning } from '@grafana/data';
 
 import { useStyles2 } from '../../themes';
 import { getFocusStyles, getMouseFocusStyles } from '../../themes/mixins';
+import { Icon } from '../Icon/Icon';
 
 export interface Props extends Omit<HTMLProps<HTMLInputElement>, 'value'> {
   value?: boolean;
@@ -13,7 +14,7 @@ export interface Props extends Omit<HTMLProps<HTMLInputElement>, 'value'> {
   invalid?: boolean;
 }
 
-export const Switch = React.forwardRef<HTMLInputElement, Props>(
+export const Switch = forwardRef<HTMLInputElement, Props>(
   ({ value, checked, onChange, id, label, disabled, invalid = false, ...inputProps }, ref) => {
     if (checked) {
       deprecationWarning('Switch', 'checked prop', 'value');
@@ -26,6 +27,7 @@ export const Switch = React.forwardRef<HTMLInputElement, Props>(
       <div className={cx(styles.switch, invalid && styles.invalid)}>
         <input
           type="checkbox"
+          role="switch"
           disabled={disabled}
           checked={value}
           onChange={(event) => {
@@ -35,7 +37,9 @@ export const Switch = React.forwardRef<HTMLInputElement, Props>(
           {...inputProps}
           ref={ref}
         />
-        <label htmlFor={switchIdRef.current} aria-label={label ?? 'Toggle switch'} />
+        <label htmlFor={switchIdRef.current} aria-label={label}>
+          <Icon name="check" size="xs" />
+        </label>
       </div>
     );
   }
@@ -50,7 +54,7 @@ export interface InlineSwitchProps extends Props {
   transparent?: boolean;
 }
 
-export const InlineSwitch = React.forwardRef<HTMLInputElement, InlineSwitchProps>(
+export const InlineSwitch = forwardRef<HTMLInputElement, InlineSwitchProps>(
   ({ transparent, className, showLabel, label, value, id, invalid, ...props }, ref) => {
     const styles = useStyles2(getSwitchStyles, transparent);
 
@@ -76,14 +80,15 @@ InlineSwitch.displayName = 'Switch';
 
 const getSwitchStyles = (theme: GrafanaTheme2, transparent?: boolean) => ({
   switch: css({
-    width: '32px',
-    height: '16px',
+    width: theme.spacing(4),
+    height: theme.spacing(2),
     position: 'relative',
     lineHeight: 1,
 
     input: {
+      height: '100%',
+      width: '100% !important',
       opacity: 0,
-      left: '-100vw',
       zIndex: -1000,
       position: 'absolute',
 
@@ -95,9 +100,10 @@ const getSwitchStyles = (theme: GrafanaTheme2, transparent?: boolean) => ({
           background: theme.colors.primary.shade,
         },
 
-        '&::after': {
-          transform: 'translate3d(18px, -50%, 0)',
+        svg: {
+          transform: `translate3d(${theme.spacing(2.25)}, -50%, 0)`,
           background: theme.colors.primary.contrastText,
+          color: theme.colors.primary.main,
         },
       },
 
@@ -106,14 +112,16 @@ const getSwitchStyles = (theme: GrafanaTheme2, transparent?: boolean) => ({
         borderColor: theme.colors.border.weak,
         cursor: 'not-allowed',
 
-        '&:hover': {
-          background: theme.colors.action.disabledBackground,
+        svg: {
+          background: theme.colors.text.disabled,
         },
       },
 
       '&:disabled:checked + label': {
-        '&::after': {
-          background: theme.colors.text.disabled,
+        background: theme.colors.primary.transparent,
+
+        svg: {
+          color: theme.colors.primary.contrastText,
         },
       },
 
@@ -135,21 +143,22 @@ const getSwitchStyles = (theme: GrafanaTheme2, transparent?: boolean) => ({
         borderColor: theme.components.input.borderHover,
       },
 
-      '&::after': {
+      svg: {
         position: 'absolute',
         display: 'block',
-        content: '""',
-        width: '12px',
-        height: '12px',
+        color: 'transparent',
+        width: theme.spacing(1.5),
+        height: theme.spacing(1.5),
         borderRadius: theme.shape.radius.circle,
         background: theme.colors.text.secondary,
         boxShadow: theme.shadows.z1,
+        left: 0,
         top: '50%',
-        transform: 'translate3d(2px, -50%, 0)',
+        transform: `translate3d(${theme.spacing(0.25)}, -50%, 0)`,
         transition: 'transform 0.2s cubic-bezier(0.19, 1, 0.22, 1)',
 
         '@media (forced-colors: active)': {
-          border: '1px solid transparent',
+          border: `1px solid ${theme.colors.primary.contrastText}`,
         },
       },
     },
