@@ -1,5 +1,6 @@
 import { css } from '@emotion/css';
-import React, { createElement, CSSProperties } from 'react';
+import { createElement, CSSProperties } from 'react';
+import * as React from 'react';
 
 import { GrafanaTheme2, ThemeTypographyVariantTypes } from '@grafana/data';
 
@@ -21,14 +22,19 @@ export interface TextProps extends Omit<React.HTMLAttributes<HTMLElement>, 'clas
   truncate?: boolean;
   /** If true, show the text as italic. False by default */
   italic?: boolean;
+  /** If true, numbers will have fixed width, useful for displaying tabular data. False by default */
+  tabular?: boolean;
   /** Whether to align the text to left, center or right */
   textAlignment?: CSSProperties['textAlign'];
   children: NonNullable<React.ReactNode>;
 }
 
 export const Text = React.forwardRef<HTMLElement, TextProps>(
-  ({ element = 'span', variant, weight, color, truncate, italic, textAlignment, children, ...restProps }, ref) => {
-    const styles = useStyles2(getTextStyles, element, variant, color, weight, truncate, italic, textAlignment);
+  (
+    { element = 'span', variant, weight, color, truncate, italic, textAlignment, children, tabular, ...restProps },
+    ref
+  ) => {
+    const styles = useStyles2(getTextStyles, element, variant, color, weight, truncate, italic, textAlignment, tabular);
 
     const childElement = (ref: React.ForwardedRef<HTMLElement> | undefined) => {
       return createElement(
@@ -71,7 +77,8 @@ const getTextStyles = (
   weight?: TextProps['weight'],
   truncate?: TextProps['truncate'],
   italic?: TextProps['italic'],
-  textAlignment?: TextProps['textAlignment']
+  textAlignment?: TextProps['textAlignment'],
+  tabular?: TextProps['tabular']
 ) => {
   return css([
     {
@@ -99,5 +106,8 @@ const getTextStyles = (
     textAlignment && {
       textAlign: textAlignment,
     },
+    tabular && {
+      fontFeatureSettings: '"tnum"',
+    },
   ]);
 };
