@@ -1,9 +1,7 @@
 import { action } from '@storybook/addon-actions';
 import { Meta, StoryFn } from '@storybook/react';
-import React from 'react';
 
 import { UnitPicker, UnitPickerProps } from './UnitPicker';
-import mdx from './UnitPicker.mdx';
 
 const meta: Meta<typeof UnitPicker> = {
   title: 'Pickers and Editors/UnitPicker',
@@ -12,7 +10,6 @@ const meta: Meta<typeof UnitPicker> = {
     controls: {
       exclude: ['onChange', 'value'],
     },
-    docs: mdx,
   },
 };
 
