@@ -1,10 +1,12 @@
 import { css, cx } from '@emotion/css';
-import React, { useCallback } from 'react';
+import { useCallback } from 'react';
+import * as React from 'react';
 
 import { formattedValueToString, GrafanaTheme2 } from '@grafana/data';
 
 import { styleMixins } from '../../themes';
 import { useStyles2 } from '../../themes/ThemeContext';
+import { Trans } from '../../utils/i18n';
 
 import { VizLegendSeriesIcon } from './VizLegendSeriesIcon';
 import { VizLegendItem } from './types';
@@ -69,7 +71,12 @@ export const LegendTableItem = ({
     <tr className={cx(styles.row, className)}>
       <td>
         <span className={styles.itemWrapper}>
-          <VizLegendSeriesIcon color={item.color} seriesName={item.fieldName ?? item.label} readonly={readonly} />
+          <VizLegendSeriesIcon
+            color={item.color}
+            seriesName={item.fieldName ?? item.label}
+            readonly={readonly}
+            lineStyle={item.lineStyle}
+          />
           <button
             disabled={readonly}
             type="button"
@@ -81,7 +88,12 @@ export const LegendTableItem = ({
             onClick={!readonly ? onClick : undefined}
             className={cx(styles.label, item.disabled && styles.labelDisabled)}
           >
-            {item.label} {item.yAxis === 2 && <span className={styles.yAxisLabel}>(right y-axis)</span>}
+            {item.label}{' '}
+            {item.yAxis === 2 && (
+              <span className={styles.yAxisLabel}>
+                <Trans i18nKey="grafana-ui.viz-legend.right-axis-indicator">(right y-axis)</Trans>
+              </span>
+            )}
           </button>
         </span>
       </td>
