@@ -1,18 +1,20 @@
 import { css, cx } from '@emotion/css';
-import React, { useLayoutEffect, useRef, useReducer, CSSProperties } from 'react';
+import { useLayoutEffect, useRef, useReducer, CSSProperties } from 'react';
+import * as React from 'react';
 import { createPortal } from 'react-dom';
 import uPlot from 'uplot';
 
-import { GrafanaTheme2 } from '@grafana/data';
+import { GrafanaTheme2, LinkModel } from '@grafana/data';
+import { DashboardCursorSync } from '@grafana/schema';
 
 import { useStyles2 } from '../../../themes';
+import { RangeSelection1D, RangeSelection2D, OnSelectRangeCallback } from '../../PanelChrome';
 import { getPortalContainer } from '../../Portal/Portal';
 import { UPlotConfigBuilder } from '../config/UPlotConfigBuilder';
 
 import { CloseButton } from './CloseButton';
 
 export const DEFAULT_TOOLTIP_WIDTH = undefined;
-export const DEFAULT_TOOLTIP_HEIGHT = undefined;
 export const TOOLTIP_OFFSET = 10;
 
 // todo: barchart? histogram?
@@ -25,17 +27,23 @@ export const enum TooltipHoverMode {
   xyOne,
 }
 
+type GeDataLinksCallback = (seriesIdx: number, dataIdx: number) => LinkModel[];
+
 interface TooltipPlugin2Props {
   config: UPlotConfigBuilder;
   hoverMode: TooltipHoverMode;
 
-  syncTooltip?: () => boolean;
+  syncMode?: DashboardCursorSync;
+  syncScope?: string;
 
   // x only
   queryZoom?: (range: { from: number; to: number }) => void;
   // y-only, via shiftKey
   clientZoom?: boolean;
 
+  onSelectRange?: OnSelectRangeCallback;
+  getDataLinks?: GeDataLinksCallback;
+
   render: (
     u: uPlot,
     dataIdxs: Array<number | null>,
@@ -44,11 +52,11 @@ interface TooltipPlugin2Props {
     dismiss: () => void,
     // selected time range (for annotation triggering)
     timeRange: TimeRange2 | null,
-    viaSync: boolean
+    viaSync: boolean,
+    dataLinks: LinkModel[]
   ) => React.ReactNode;
 
   maxWidth?: number;
-  maxHeight?: number;
 }
 
 interface TooltipContainerState {
@@ -98,18 +106,22 @@ const MIN_ZOOM_DIST = 5;
 
 const maybeZoomAction = (e?: MouseEvent | null) => e != null && !e.ctrlKey && !e.metaKey;
 
+const getDataLinksFallback: GeDataLinksCallback = () => [];
+
 /**
  * @alpha
  */
-export const TooltipPlugin2: React.FC<TooltipPlugin2Props> = ({
+export const TooltipPlugin2 = ({
   config,
   hoverMode,
   render,
   clientZoom = false,
   queryZoom,
+  onSelectRange,
   maxWidth,
-  maxHeight,
-  syncTooltip = () => false,
+  syncMode = DashboardCursorSync.Off,
+  syncScope = 'global', // eventsScope
+  getDataLinks = getDataLinksFallback,
 }: TooltipPlugin2Props) => {
   const domRef = useRef<HTMLDivElement>(null);
   const portalRoot = useRef<HTMLElement | null>(null);
@@ -121,14 +133,14 @@ export const TooltipPlugin2: React.FC<TooltipPlugin2Props> = ({
   const [{ plot, isHovering, isPinned, contents, style, dismiss }, setState] = useReducer(mergeState, null, initState);
 
   const sizeRef = useRef<TooltipContainerSize>();
-
-  maxWidth = isPinned ? DEFAULT_TOOLTIP_WIDTH : maxWidth ?? DEFAULT_TOOLTIP_WIDTH;
-  maxHeight ??= DEFAULT_TOOLTIP_HEIGHT;
-  const styles = useStyles2(getStyles, maxWidth, maxHeight);
+  const styles = useStyles2(getStyles, maxWidth);
 
   const renderRef = useRef(render);
   renderRef.current = render;
 
+  const getLinksRef = useRef(getDataLinks);
+  getLinksRef.current = getDataLinks;
+
   useLayoutEffect(() => {
     sizeRef.current = {
       width: 0,
@@ -159,9 +171,20 @@ export const TooltipPlugin2: React.FC<TooltipPlugin2Props> = ({
 
     let plotVisible = false;
 
+    const syncTooltip = syncMode === DashboardCursorSync.Tooltip;
+
+    if (syncMode !== DashboardCursorSync.Off && config.scales[0].props.isTime) {
+      config.setCursor({
+        sync: {
+          key: syncScope,
+          scales: ['x', null],
+        },
+      });
+    }
+
     const updateHovering = () => {
       if (viaSync) {
-        _isHovering = plotVisible && _someSeriesIdx && syncTooltip();
+        _isHovering = plotVisible && _someSeriesIdx && syncTooltip;
       } else {
         _isHovering = closestSeriesIdx != null || (hoverMode === TooltipHoverMode.xAll && _someSeriesIdx);
       }
@@ -174,6 +197,7 @@ export const TooltipPlugin2: React.FC<TooltipPlugin2Props> = ({
     let seriesIdxs: Array<number | null> = plot?.cursor.idxs!.slice()!;
     let closestSeriesIdx: number | null = null;
     let viaSync = false;
+    let dataLinks: LinkModel[] = [];
 
     let pendingRender = false;
     let pendingPinned = false;
@@ -229,7 +253,16 @@ export const TooltipPlugin2: React.FC<TooltipPlugin2Props> = ({
         isHovering: _isHovering,
         contents:
           _isHovering || selectedRange != null
-            ? renderRef.current(_plot!, seriesIdxs, closestSeriesIdx, _isPinned, dismiss, selectedRange, viaSync)
+            ? renderRef.current(
+                _plot!,
+                seriesIdxs,
+                closestSeriesIdx,
+                _isPinned,
+                dismiss,
+                selectedRange,
+                viaSync,
+                dataLinks
+              )
             : null,
         dismiss,
       };
@@ -244,6 +277,8 @@ export const TooltipPlugin2: React.FC<TooltipPlugin2Props> = ({
       _isPinned = false;
       _isHovering = false;
       _plot!.setCursor({ left: -10, top: -10 });
+      dataLinks = [];
+
       scheduleRender(prevIsPinned);
     };
 
@@ -300,8 +335,12 @@ export const TooltipPlugin2: React.FC<TooltipPlugin2Props> = ({
           }
           // only pinnable tooltip is visible *and* is within proximity to series/point
           else if (_isHovering && closestSeriesIdx != null && !_isPinned) {
-            _isPinned = true;
-            scheduleRender(true);
+            dataLinks = getLinksRef.current(closestSeriesIdx!, seriesIdxs[closestSeriesIdx!]!);
+
+            setTimeout(() => {
+              _isPinned = true;
+              scheduleRender(true);
+            }, 0);
           }
         }
       });
@@ -309,9 +348,65 @@ export const TooltipPlugin2: React.FC<TooltipPlugin2Props> = ({
 
     config.addHook('setSelect', (u) => {
       const isXAxisHorizontal = u.scales.x.ori === 0;
+
       if (!viaSync && (clientZoom || queryZoom != null)) {
         if (maybeZoomAction(u.cursor!.event)) {
-          if (clientZoom && yDrag) {
+          if (onSelectRange != null) {
+            let selections: RangeSelection2D[] = [];
+
+            const yDrag = Boolean(u.cursor!.drag!.y);
+            const xDrag = Boolean(u.cursor!.drag!.x);
+
+            let xSel = null;
+            let ySels: RangeSelection1D[] = [];
+
+            // get x selection
+            if (xDrag) {
+              xSel = {
+                from: isXAxisHorizontal
+                  ? u.posToVal(u.select.left!, 'x')
+                  : u.posToVal(u.select.top + u.select.height, 'x'),
+                to: isXAxisHorizontal
+                  ? u.posToVal(u.select.left! + u.select.width, 'x')
+                  : u.posToVal(u.select.top, 'x'),
+              };
+            }
+
+            // get y selections
+            if (yDrag) {
+              config.scales.forEach((scale) => {
+                const key = scale.props.scaleKey;
+
+                if (key !== 'x') {
+                  let ySel = {
+                    from: isXAxisHorizontal
+                      ? u.posToVal(u.select.top + u.select.height, key)
+                      : u.posToVal(u.select.left + u.select.width, key),
+                    to: isXAxisHorizontal ? u.posToVal(u.select.top, key) : u.posToVal(u.select.left, key),
+                  };
+
+                  ySels.push(ySel);
+                }
+              });
+            }
+
+            if (xDrag) {
+              if (yDrag) {
+                // x + y
+                selections = ySels.map((ySel) => ({ x: xSel!, y: ySel }));
+              } else {
+                // x only
+                selections = [{ x: xSel! }];
+              }
+            } else {
+              if (yDrag) {
+                // y only
+                selections = ySels.map((ySel) => ({ y: ySel }));
+              }
+            }
+
+            onSelectRange(selections);
+          } else if (clientZoom && yDrag) {
             if (u.select.height >= MIN_ZOOM_DIST) {
               for (let key in u.scales!) {
                 if (key !== 'x') {
@@ -394,6 +489,10 @@ export const TooltipPlugin2: React.FC<TooltipPlugin2Props> = ({
     config.addHook('setData', (u) => {
       yZoomed = false;
       yDrag = false;
+
+      if (_isPinned) {
+        dismiss();
+      }
     });
 
     // fires on series focus/proximity changes
@@ -507,7 +606,7 @@ export const TooltipPlugin2: React.FC<TooltipPlugin2Props> = ({
 
     const onscroll = (e: Event) => {
       updatePlotVisible();
-      _isHovering && !_isPinned && e.target instanceof HTMLElement && e.target.contains(_plot!.root) && dismiss();
+      _isHovering && e.target instanceof Node && e.target.contains(_plot!.root) && dismiss();
     };
 
     window.addEventListener('resize', updateWinSize);
@@ -516,6 +615,10 @@ export const TooltipPlugin2: React.FC<TooltipPlugin2Props> = ({
     return () => {
       window.removeEventListener('resize', updateWinSize);
       window.removeEventListener('scroll', onscroll, true);
+
+      // in case this component unmounts while anchored (due to data auto-refresh + re-config)
+      document.removeEventListener('mousedown', downEventOutside, true);
+      document.removeEventListener('keydown', downEventOutside, true);
     };
   }, [config]);
 
@@ -531,11 +634,31 @@ export const TooltipPlugin2: React.FC<TooltipPlugin2Props> = ({
       size.width = width;
       size.height = height;
 
-      const event = plot!.cursor.event;
+      let event = plot!.cursor.event;
 
       // if not viaSync, re-dispatch real event
       if (event != null) {
-        plot!.over.dispatchEvent(event);
+        // we expect to re-dispatch mousemove, but on mobile we'll get mouseup or click
+        const isMobile = event.type !== 'mousemove';
+
+        if (isMobile) {
+          event = new MouseEvent('mousemove', {
+            view: window,
+            bubbles: true,
+            cancelable: true,
+            clientX: event.clientX,
+            clientY: event.clientY,
+            screenX: event.screenX,
+            screenY: event.screenY,
+          });
+        }
+
+        // this works around the fact that uPlot does not unset cursor.event (for perf reasons)
+        // so if the last real mouse event was mouseleave and you manually trigger u.setCursor()
+        // it would end up re-dispatching mouseleave
+        const isStaleEvent = isMobile ? false : performance.now() - event.timeStamp > 16;
+
+        !isStaleEvent && plot!.over.dispatchEvent(event);
       } else {
         plot!.setCursor(
           {
@@ -570,7 +693,7 @@ export const TooltipPlugin2: React.FC<TooltipPlugin2Props> = ({
   return null;
 };
 
-const getStyles = (theme: GrafanaTheme2, maxWidth?: number, maxHeight?: number) => ({
+const getStyles = (theme: GrafanaTheme2, maxWidth?: number) => ({
   tooltipWrapper: css({
     top: 0,
     left: 0,
@@ -583,8 +706,6 @@ const getStyles = (theme: GrafanaTheme2, maxWidth?: number, maxHeight?: number)
     boxShadow: theme.shadows.z2,
     userSelect: 'text',
     maxWidth: maxWidth ?? 'none',
-    maxHeight: maxHeight ?? 'none',
-    overflowY: 'auto',
   }),
   pinned: css({
     boxShadow: theme.shadows.z3,
