@@ -3,21 +3,7 @@ import { BarAlignment, GraphDrawStyle, GraphTransform, LineInterpolation, Stacki
 
 import { preparePlotFrame } from '..';
 
-import { getStackingGroups, preparePlotData2, timeFormatToTemplate } from './utils';
-
-describe('timeFormatToTemplate', () => {
-  it.each`
-    format           | expected
-    ${'HH:mm:ss'}    | ${'{HH}:{mm}:{ss}'}
-    ${'HH:mm'}       | ${'{HH}:{mm}'}
-    ${'MM/DD HH:mm'} | ${'{MM}/{DD} {HH}:{mm}'}
-    ${'MM/DD'}       | ${'{MM}/{DD}'}
-    ${'YYYY-MM'}     | ${'{YYYY}-{MM}'}
-    ${'YYYY'}        | ${'{YYYY}'}
-  `('should convert $format to $expected', ({ format, expected }) => {
-    expect(timeFormatToTemplate(format)).toEqual(expected);
-  });
-});
+import { getStackingGroups, preparePlotData2 } from './utils';
 
 describe('preparePlotData2', () => {
   const df = new MutableDataFrame({
