@@ -1,13 +1,7 @@
-export {
-  ThemeContext,
-  withTheme,
-  withTheme2,
-  useTheme,
-  useTheme2,
-  useStyles,
-  useStyles2,
-  mockThemeContext,
-} from './ThemeContext';
+// @deprecated use ThemeContext from @grafana/data instead
+export { ThemeContext } from '@grafana/data';
+
+export { withTheme, withTheme2, useTheme, useTheme2, useStyles, useStyles2, mockThemeContext } from './ThemeContext';
 export { getTheme, mockTheme } from './getTheme';
 export { stylesFactory } from './stylesFactory';
 export { GlobalStyles } from './GlobalStyles/GlobalStyles';
