@@ -1,11 +1,11 @@
 import { getAvailableIcons } from '../../types';
 
-export const iconOptions = {
+export const iconOptions: Record<string, string | undefined> = {
   None: undefined,
   ...getAvailableIcons().reduce<Record<string, string>>((prev, c) => {
     return {
       ...prev,
-      [`Icon: ${c}`]: `${c}`,
+      [`${c}`]: `Icon: ${c}`,
     };
   }, {}),
 };
