@@ -1,5 +1,5 @@
-import { DecoratorFn } from '@storybook/react';
-import React from 'react';
+import { Decorator } from '@storybook/react';
+import * as React from 'react';
 import { useDarkMode } from 'storybook-dark-mode';
 
 import { createTheme, GrafanaTheme2, ThemeContext } from '@grafana/data';
@@ -35,22 +35,7 @@ const ThemeableStory = ({
   );
 };
 
-// Temporary solution. When we update to Storybook V5 we will be able to pass data from decorator to story
-// https://github.com/storybooks/storybook/issues/340#issuecomment-456013702
-export const renderComponentWithTheme = (component: React.ComponentType<any>, props: any) => {
-  return (
-    <ThemeContext.Consumer>
-      {(theme) => {
-        return React.createElement(component, {
-          ...props,
-          theme,
-        });
-      }}
-    </ThemeContext.Consumer>
-  );
-};
-
 export const withTheme =
-  (handleSassThemeChange: SassThemeChangeHandler): DecoratorFn =>
+  (handleSassThemeChange: SassThemeChangeHandler): Decorator =>
   // eslint-disable-next-line react/display-name
   (story) => <ThemeableStory handleSassThemeChange={handleSassThemeChange}>{story()}</ThemeableStory>;
