@@ -4,6 +4,7 @@ import (
 	"context"
 
 	"xorm.io/core"
+	"xorm.io/xorm"
 
 	"github.com/grafana/grafana/pkg/services/sqlstore"
 	"github.com/grafana/grafana/pkg/services/sqlstore/migrator"
@@ -43,6 +44,10 @@ func (f *FakeDB) GetDialect() migrator.Dialect {
 	return nil
 }
 
+func (f *FakeDB) GetEngine() *xorm.Engine {
+	return nil
+}
+
 func (f *FakeDB) GetSqlxSession() *session.SessionDB {
 	return nil
 }
