@@ -33,6 +33,7 @@ func AddDefaultResponseHeaders(cfg *setting.Cfg) web.Handler {
 	t := web.NewTree()
 	t.Add("/api/datasources/uid/:uid/resources/*", nil)
 	t.Add("/api/datasources/:id/resources/*", nil)
+	t.Add("/api/plugins/:id/resources/*", nil)
 
 	return func(c *web.Context) {
 		c.Resp.Before(func(w web.ResponseWriter) { // if response has already been written, skip.
@@ -51,7 +52,8 @@ func AddDefaultResponseHeaders(cfg *setting.Cfg) web.Handler {
 				!strings.HasPrefix(c.Req.URL.Path, "/avatar/") &&
 				!strings.HasPrefix(c.Req.URL.Path, "/api/datasources/proxy/") &&
 				!strings.HasPrefix(c.Req.URL.Path, "/api/reports/render/") &&
-				!strings.HasPrefix(c.Req.URL.Path, "/render/d-solo/") && !resourceCachable {
+				!strings.HasPrefix(c.Req.URL.Path, "/render/d-solo/") &&
+				!(strings.HasPrefix(c.Req.URL.Path, "/api/gnet/plugins") && strings.Contains(c.Req.URL.Path, "/logos/")) && !resourceCachable {
 				addNoCacheHeaders(c.Resp)
 			}
 
@@ -66,14 +68,6 @@ func AddDefaultResponseHeaders(cfg *setting.Cfg) web.Handler {
 	}
 }
 
-func AddAllowEmbeddingHeader() web.Handler {
-	return func(c *web.Context) {
-		c.Resp.Before(func(w web.ResponseWriter) {
-			w.Header().Set("X-Allow-Embedding", "allow")
-		})
-	}
-}
-
 // addSecurityHeaders adds HTTP(S) response headers that enable various security protections in the client's browser.
 func addSecurityHeaders(w web.ResponseWriter, cfg *setting.Cfg) {
 	if cfg.StrictTransportSecurity {
