@@ -71,7 +71,7 @@ func (m *service) Run(ctx context.Context) error {
 		return nil
 	}
 
-	var svcs []services.Service
+	svcs := make([]services.Service, 0, len(m.serviceMap))
 	for _, s := range m.serviceMap {
 		svcs = append(svcs, s)
 	}
