@@ -12,7 +12,7 @@ import (
 
 type Installer interface {
 	// Add adds a new plugin.
-	Add(ctx context.Context, pluginID, version string, opts CompatOpts) error
+	Add(ctx context.Context, pluginID, version string, opts AddOpts) error
 	// Remove removes an existing plugin.
 	Remove(ctx context.Context, pluginID, version string) error
 }
@@ -33,31 +33,33 @@ type File struct {
 	ModTime time.Time
 }
 
-type CompatOpts struct {
+type AddOpts struct {
 	grafanaVersion string
 
 	os   string
 	arch string
+
+	url string
 }
 
-func (co CompatOpts) GrafanaVersion() string {
+func (co AddOpts) GrafanaVersion() string {
 	return co.grafanaVersion
 }
 
-func (co CompatOpts) OS() string {
+func (co AddOpts) OS() string {
 	return co.os
 }
 
-func (co CompatOpts) Arch() string {
+func (co AddOpts) Arch() string {
 	return co.arch
 }
 
-func NewCompatOpts(grafanaVersion, os, arch string) CompatOpts {
-	return CompatOpts{grafanaVersion: grafanaVersion, arch: arch, os: os}
+func (co AddOpts) URL() string {
+	return co.url
 }
 
-func NewSystemCompatOpts(os, arch string) CompatOpts {
-	return CompatOpts{arch: arch, os: os}
+func NewAddOpts(grafanaVersion, os, arch, url string) AddOpts {
+	return AddOpts{grafanaVersion: grafanaVersion, arch: arch, os: os, url: url}
 }
 
 type UpdateInfo struct {
@@ -69,6 +71,7 @@ type FS interface {
 
 	Base() string
 	Files() ([]string, error)
+	Rel(string) (string, error)
 }
 
 type FSRemover interface {
@@ -87,11 +90,7 @@ type FoundPlugin struct {
 
 // Client is used to communicate with backend plugin implementations.
 type Client interface {
-	backend.QueryDataHandler
-	backend.CheckHealthHandler
-	backend.StreamHandler
-	backend.CallResourceHandler
-	backend.CollectMetricsHandler
+	backend.Handler
 }
 
 // BackendFactoryProvider provides a backend factory for a provided plugin.
@@ -110,6 +109,7 @@ type StaticRouteResolver interface {
 
 type ErrorResolver interface {
 	PluginErrors(ctx context.Context) []*Error
+	PluginError(ctx context.Context, pluginID string) *Error
 }
 
 type PluginLoaderAuthorizer interface {
@@ -127,28 +127,6 @@ type Licensing interface {
 	AppURL() string
 }
 
-// RoleRegistry handles the plugin RBAC roles and their assignments
-type RoleRegistry interface {
-	DeclarePluginRoles(ctx context.Context, ID, name string, registrations []RoleRegistration) error
-}
-
-// ClientMiddleware is an interface representing the ability to create a middleware
-// that implements the Client interface.
-type ClientMiddleware interface {
-	// CreateClientMiddleware creates a new client middleware.
-	CreateClientMiddleware(next Client) Client
-}
-
-// The ClientMiddlewareFunc type is an adapter to allow the use of ordinary
-// functions as ClientMiddleware's. If f is a function with the appropriate
-// signature, ClientMiddlewareFunc(f) is a ClientMiddleware that calls f.
-type ClientMiddlewareFunc func(next Client) Client
-
-// CreateClientMiddleware implements the ClientMiddleware interface.
-func (fn ClientMiddlewareFunc) CreateClientMiddleware(next Client) Client {
-	return fn(next)
-}
-
 type SignatureCalculator interface {
 	Calculate(ctx context.Context, src PluginSource, plugin FoundPlugin) (Signature, error)
 }
