@@ -3,7 +3,7 @@ package repo
 import (
 	"fmt"
 
-	"github.com/grafana/grafana/pkg/util/errutil"
+	"github.com/grafana/grafana/pkg/apimachinery/errutil"
 )
 
 type ErrResponse4xx struct {
@@ -67,6 +67,10 @@ var (
 	ErrCorePluginMsg  = "plugin {{.Public.PluginID}} is a core plugin and cannot be installed separately"
 	ErrCorePluginBase = errutil.Forbidden("plugin.forbiddenCorePluginInstall").
 				MustTemplate(ErrCorePluginMsg, errutil.WithPublic(ErrCorePluginMsg))
+
+	ErrNotCompatibledMsg = "{{.Public.PluginID}} is not compatible with your Grafana version: {{.Public.GrafanaVersion}}"
+	ErrNotCompatibleBase = errutil.NotFound("plugin.grafanaVersionNotCompatible").
+				MustTemplate(ErrNotCompatibledMsg, errutil.WithPublic(ErrNotCompatibledMsg))
 )
 
 func ErrVersionUnsupported(pluginID, requestedVersion, systemInfo string) error {
@@ -88,3 +92,7 @@ func ErrChecksumMismatch(archiveURL string) error {
 func ErrCorePlugin(pluginID string) error {
 	return ErrCorePluginBase.Build(errutil.TemplateData{Public: map[string]any{"PluginID": pluginID}})
 }
+
+func ErrNoCompatibleVersions(pluginID, grafanaVersion string) error {
+	return ErrNotCompatibleBase.Build(errutil.TemplateData{Public: map[string]any{"PluginID": pluginID, "GrafanaVersion": grafanaVersion}})
+}
