@@ -9,15 +9,15 @@ const (
 	metricsNamespace = "grafana"
 )
 
-type metrics struct {
+type queryMetrics struct {
 	dsRequests *prometheus.CounterVec
 
 	// older metric
 	expressionsQuerySummary *prometheus.SummaryVec
 }
 
-func newMetrics(reg prometheus.Registerer) *metrics {
-	m := &metrics{
+func newQueryMetrics(reg prometheus.Registerer) *queryMetrics {
+	m := &queryMetrics{
 		dsRequests: prometheus.NewCounterVec(prometheus.CounterOpts{
 			Namespace: metricsNamespace,
 			Subsystem: metricsSubSystem,
