@@ -16,16 +16,18 @@ import (
 	"github.com/grafana/grafana/pkg/infra/tracing"
 	"github.com/grafana/grafana/pkg/services/accesscontrol"
 	"github.com/grafana/grafana/pkg/services/accesscontrol/acimpl"
+	accesscontrolmock "github.com/grafana/grafana/pkg/services/accesscontrol/mock"
 	"github.com/grafana/grafana/pkg/services/annotations"
 	"github.com/grafana/grafana/pkg/services/annotations/testutil"
 	"github.com/grafana/grafana/pkg/services/dashboards"
-	dashboardstore "github.com/grafana/grafana/pkg/services/dashboards/database"
+	"github.com/grafana/grafana/pkg/services/dashboards/database"
+	dashboardsservice "github.com/grafana/grafana/pkg/services/dashboards/service"
 	"github.com/grafana/grafana/pkg/services/featuremgmt"
 	"github.com/grafana/grafana/pkg/services/folder"
 	"github.com/grafana/grafana/pkg/services/folder/folderimpl"
 	"github.com/grafana/grafana/pkg/services/guardian"
+	alertingStore "github.com/grafana/grafana/pkg/services/ngalert/store"
 	"github.com/grafana/grafana/pkg/services/quota/quotatest"
-	"github.com/grafana/grafana/pkg/services/sqlstore"
 	"github.com/grafana/grafana/pkg/services/supportbundles/supportbundlestest"
 	"github.com/grafana/grafana/pkg/services/tag/tagimpl"
 	"github.com/grafana/grafana/pkg/services/user"
@@ -48,10 +50,25 @@ func TestIntegrationAnnotationListingWithRBAC(t *testing.T) {
 
 	features := featuremgmt.WithFeatures()
 	tagService := tagimpl.ProvideService(sql)
+	ruleStore := alertingStore.SetupStoreForTesting(t, sql)
+	origNewDashboardGuardian := guardian.New
+	defer func() { guardian.New = origNewDashboardGuardian }()
+	guardian.MockDashboardGuardian(&guardian.FakeDashboardGuardian{})
+	folderStore := folderimpl.ProvideDashboardFolderStore(sql)
+	fStore := folderimpl.ProvideStore(sql)
+	dashStore, err := database.ProvideDashboardStore(sql, cfg, featuremgmt.WithFeatures(), tagimpl.ProvideService(sql))
+	require.NoError(t, err)
+	ac := acimpl.ProvideAccessControl(featuremgmt.WithFeatures())
+	folderSvc := folderimpl.ProvideService(fStore, accesscontrolmock.New(), bus.ProvideBus(tracing.InitializeTracerForTest()),
+		dashStore, folderStore, sql, featuremgmt.WithFeatures(),
+		supportbundlestest.NewFakeBundleService(), cfg, nil, tracing.InitializeTracerForTest())
+	dashSvc, err := dashboardsservice.ProvideDashboardServiceImpl(cfg, dashStore, folderStore, featuremgmt.WithFeatures(), accesscontrolmock.NewMockedPermissionsService(), accesscontrolmock.NewMockedPermissionsService(),
+		ac, folderSvc, fStore, nil, nil, nil, nil, quotatest.New(false, nil), nil)
+	require.NoError(t, err)
 
-	repo := ProvideService(sql, cfg, features, tagService)
+	repo := ProvideService(sql, cfg, features, tagService, tracing.InitializeTracerForTest(), ruleStore, dashSvc)
 
-	dashboard1 := testutil.CreateDashboard(t, sql, features, dashboards.SaveDashboardCommand{
+	dashboard1 := testutil.CreateDashboard(t, sql, cfg, features, dashboards.SaveDashboardCommand{
 		UserID:   1,
 		OrgID:    1,
 		IsFolder: false,
@@ -60,7 +77,7 @@ func TestIntegrationAnnotationListingWithRBAC(t *testing.T) {
 		}),
 	})
 
-	_ = testutil.CreateDashboard(t, sql, features, dashboards.SaveDashboardCommand{
+	_ = testutil.CreateDashboard(t, sql, cfg, features, dashboards.SaveDashboardCommand{
 		UserID:   1,
 		OrgID:    1,
 		IsFolder: false,
@@ -69,8 +86,6 @@ func TestIntegrationAnnotationListingWithRBAC(t *testing.T) {
 		}),
 	})
 
-	var err error
-
 	dash1Annotation := &annotations.Item{
 		OrgID:       1,
 		DashboardID: 1,
@@ -188,15 +203,13 @@ func TestIntegrationAnnotationListingWithInheritedRBAC(t *testing.T) {
 	permissions := []accesscontrol.Permission{
 		{
 			Action: dashboards.ActionFoldersCreate,
-		}, {
-			Action: dashboards.ActionFoldersWrite,
 			Scope:  dashboards.ScopeFoldersAll,
 		},
 	}
 	usr := &user.SignedInUser{
 		UserID:      1,
 		OrgID:       orgID,
-		Permissions: map[int64]map[string][]string{orgID: accesscontrol.GroupScopesByAction(permissions)},
+		Permissions: map[int64]map[string][]string{orgID: accesscontrol.GroupScopesByActionContext(context.Background(), permissions)},
 	}
 
 	var role *accesscontrol.Role
@@ -209,15 +222,15 @@ func TestIntegrationAnnotationListingWithInheritedRBAC(t *testing.T) {
 	allDashboards := make([]dashInfo, 0, folder.MaxNestedFolderDepth+1)
 	annotationsTexts := make([]string, 0, folder.MaxNestedFolderDepth+1)
 
-	setupFolderStructure := func() *sqlstore.SQLStore {
-		sql := db.InitTestDB(t)
+	setupFolderStructure := func() (db.DB, dashboards.DashboardService) {
+		sql, cfg := db.InitTestDBWithCfg(t)
 
 		// enable nested folders so that the folder table is populated for all the tests
 		features := featuremgmt.WithFeatures(featuremgmt.FlagNestedFolders)
 
 		tagService := tagimpl.ProvideService(sql)
 
-		dashStore, err := dashboardstore.ProvideDashboardStore(sql, sql.Cfg, features, tagService, quotatest.New(false, nil))
+		dashStore, err := database.ProvideDashboardStore(sql, cfg, features, tagService)
 		require.NoError(t, err)
 
 		origNewGuardian := guardian.New
@@ -226,10 +239,15 @@ func TestIntegrationAnnotationListingWithInheritedRBAC(t *testing.T) {
 			guardian.New = origNewGuardian
 		})
 
-		ac := acimpl.ProvideAccessControl(sql.Cfg)
-		folderSvc := folderimpl.ProvideService(ac, bus.ProvideBus(tracing.InitializeTracerForTest()), sql.Cfg, dashStore, folderimpl.ProvideDashboardFolderStore(sql), sql, features, supportbundlestest.NewFakeBundleService(), nil)
+		ac := acimpl.ProvideAccessControl(features)
+		fStore := folderimpl.ProvideStore(sql)
+		folderStore := folderimpl.ProvideDashboardFolderStore(sql)
+		folderSvc := folderimpl.ProvideService(fStore, ac, bus.ProvideBus(tracing.InitializeTracerForTest()), dashStore,
+			folderStore, sql, features, supportbundlestest.NewFakeBundleService(), cfg, nil, tracing.InitializeTracerForTest())
+		dashSvc, err := dashboardsservice.ProvideDashboardServiceImpl(cfg, dashStore, folderStore, features, accesscontrolmock.NewMockedPermissionsService(), accesscontrolmock.NewMockedPermissionsService(),
+			ac, folderSvc, fStore, nil, nil, nil, nil, quotatest.New(false, nil), nil)
+		require.NoError(t, err)
 
-		cfg := setting.NewCfg()
 		cfg.AnnotationMaximumTagsLength = 60
 
 		store := NewXormStore(cfg, log.New("annotation.test"), sql, tagService)
@@ -253,16 +271,18 @@ func TestIntegrationAnnotationListingWithInheritedRBAC(t *testing.T) {
 				t.Fail()
 			}
 
-			dashboard := testutil.CreateDashboard(t, sql, features, dashboards.SaveDashboardCommand{
-				UserID:   usr.UserID,
-				OrgID:    orgID,
-				IsFolder: false,
-				Dashboard: simplejson.NewFromAny(map[string]any{
-					"title": fmt.Sprintf("Dashboard under %s", f.UID),
-				}),
-				FolderID:  f.ID, // nolint:staticcheck
-				FolderUID: f.UID,
-			})
+			dashboard, err := dashSvc.SaveDashboard(context.Background(), &dashboards.SaveDashboardDTO{
+				User:  usr,
+				OrgID: orgID,
+				Dashboard: &dashboards.Dashboard{
+					IsFolder:  false,
+					Title:     fmt.Sprintf("Dashboard under %s", f.UID),
+					Data:      simplejson.New(),
+					FolderID:  f.ID, // nolint:staticcheck
+					FolderUID: f.UID,
+				},
+			}, false)
+			require.NoError(t, err)
 
 			allDashboards = append(allDashboards, dashInfo{UID: dashboard.UID, ID: dashboard.ID})
 
@@ -282,10 +302,10 @@ func TestIntegrationAnnotationListingWithInheritedRBAC(t *testing.T) {
 		}
 
 		role = testutil.SetupRBACRole(t, sql, usr)
-		return sql
+		return sql, dashSvc
 	}
 
-	sql := setupFolderStructure()
+	sql, dashSvc := setupFolderStructure()
 
 	testCases := []struct {
 		desc                   string
@@ -318,8 +338,8 @@ func TestIntegrationAnnotationListingWithInheritedRBAC(t *testing.T) {
 		t.Run(tc.desc, func(t *testing.T) {
 			cfg := setting.NewCfg()
 			cfg.AnnotationMaximumTagsLength = 60
-
-			repo := ProvideService(sql, cfg, tc.features, tagimpl.ProvideService(sql))
+			ruleStore := alertingStore.SetupStoreForTesting(t, sql)
+			repo := ProvideService(sql, cfg, tc.features, tagimpl.ProvideService(sql), tracing.InitializeTracerForTest(), ruleStore, dashSvc)
 
 			usr.Permissions = map[int64]map[string][]string{1: tc.permissions}
 			testutil.SetupRBACPermission(t, sql, role, usr)
