@@ -3,14 +3,17 @@ package loki
 import (
 	"context"
 	"encoding/json"
-	"errors"
 	"math/rand"
 	"net/url"
+	"slices"
 	"strconv"
-	"sync"
 	"testing"
 	"time"
 
+	"github.com/prometheus/client_golang/prometheus"
+	"github.com/stretchr/testify/require"
+	"golang.org/x/exp/maps"
+
 	"github.com/grafana/grafana/pkg/components/simplejson"
 	"github.com/grafana/grafana/pkg/infra/db"
 	"github.com/grafana/grafana/pkg/infra/log"
@@ -26,11 +29,10 @@ import (
 	"github.com/grafana/grafana/pkg/services/ngalert/state"
 	"github.com/grafana/grafana/pkg/services/ngalert/state/historian"
 	historymodel "github.com/grafana/grafana/pkg/services/ngalert/state/historian/model"
+	"github.com/grafana/grafana/pkg/services/ngalert/store"
+	"github.com/grafana/grafana/pkg/services/sqlstore"
 	"github.com/grafana/grafana/pkg/setting"
 	"github.com/grafana/grafana/pkg/tests/testsuite"
-	"github.com/prometheus/client_golang/prometheus"
-
-	"github.com/stretchr/testify/require"
 )
 
 func TestMain(m *testing.M) {
@@ -42,9 +44,9 @@ func TestIntegrationAlertStateHistoryStore(t *testing.T) {
 		t.Skip("skipping integration test")
 	}
 
-	sql := db.InitTestDB(t)
+	sql, cfg := db.InitTestDBWithCfg(t)
 
-	dashboard1 := testutil.CreateDashboard(t, sql, featuremgmt.WithFeatures(), dashboards.SaveDashboardCommand{
+	dashboard1 := testutil.CreateDashboard(t, sql, cfg, featuremgmt.WithFeatures(), dashboards.SaveDashboardCommand{
 		UserID: 1,
 		OrgID:  1,
 		Dashboard: simplejson.NewFromAny(map[string]any{
@@ -52,28 +54,22 @@ func TestIntegrationAlertStateHistoryStore(t *testing.T) {
 		}),
 	})
 
-	dashboard2 := testutil.CreateDashboard(t, sql, featuremgmt.WithFeatures(), dashboards.SaveDashboardCommand{
+	dashboard2 := testutil.CreateDashboard(t, sql, cfg, featuremgmt.WithFeatures(), dashboards.SaveDashboardCommand{
 		UserID: 1,
 		OrgID:  1,
 		Dashboard: simplejson.NewFromAny(map[string]any{
 			"title": "Dashboard 2",
 		}),
 	})
-
-	knownUIDs := &sync.Map{}
-	generator := ngmodels.AlertRuleGen(
-		ngmodels.WithUniqueUID(knownUIDs),
-		ngmodels.WithUniqueID(),
-		ngmodels.WithOrgID(1),
-	)
+	gen := ngmodels.RuleGen.With(ngmodels.RuleGen.WithOrgID(1))
 
 	dashboardRules := map[string][]*ngmodels.AlertRule{
 		dashboard1.UID: {
-			createAlertRuleFromDashboard(t, sql, "Test Rule 1", *dashboard1, generator),
-			createAlertRuleFromDashboard(t, sql, "Test Rule 2", *dashboard1, generator),
+			createAlertRuleFromDashboard(t, sql, "Test Rule 1", *dashboard1, gen),
+			createAlertRuleFromDashboard(t, sql, "Test Rule 2", *dashboard1, gen),
 		},
 		dashboard2.UID: {
-			createAlertRuleFromDashboard(t, sql, "Test Rule 3", *dashboard2, generator),
+			createAlertRuleFromDashboard(t, sql, "Test Rule 3", *dashboard2, gen),
 		},
 	}
 
@@ -100,7 +96,7 @@ func TestIntegrationAlertStateHistoryStore(t *testing.T) {
 			}
 			res, err := store.Get(
 				context.Background(),
-				&query,
+				query,
 				&annotation_ac.AccessResources{
 					Dashboards: map[string]int64{
 						dashboard1.UID: dashboard1.ID,
@@ -112,6 +108,35 @@ func TestIntegrationAlertStateHistoryStore(t *testing.T) {
 			require.Len(t, res, numTransitions)
 		})
 
+		t.Run("should return ErrLokiStoreNotFound if rule is not found", func(t *testing.T) {
+			var rules = slices.Concat(maps.Values(dashboardRules)...)
+			id := rand.Int63n(1000) // in Postgres ID is integer, so limit range
+			// make sure id is not known
+			for slices.IndexFunc(rules, func(rule *ngmodels.AlertRule) bool {
+				return rule.ID == id
+			}) >= 0 {
+				id = rand.Int63n(1000)
+			}
+
+			query := annotations.ItemQuery{
+				OrgID:   1,
+				AlertID: id,
+				From:    start.UnixMilli(),
+				To:      start.Add(time.Second * time.Duration(numTransitions+1)).UnixMilli(),
+			}
+			_, err := store.Get(
+				context.Background(),
+				query,
+				&annotation_ac.AccessResources{
+					Dashboards: map[string]int64{
+						dashboard1.UID: dashboard1.ID,
+					},
+					CanAccessDashAnnotations: true,
+				},
+			)
+			require.ErrorIs(t, err, ErrLokiStoreNotFound)
+		})
+
 		t.Run("can query history by dashboard id", func(t *testing.T) {
 			fakeLokiClient.rangeQueryRes = []historian.Stream{
 				historian.StatesToStream(ruleMetaFromRule(t, dashboardRules[dashboard1.UID][0]), transitions, map[string]string{}, log.NewNopLogger()),
@@ -126,7 +151,7 @@ func TestIntegrationAlertStateHistoryStore(t *testing.T) {
 			}
 			res, err := store.Get(
 				context.Background(),
-				&query,
+				query,
 				&annotation_ac.AccessResources{
 					Dashboards: map[string]int64{
 						dashboard1.UID: dashboard1.ID,
@@ -150,7 +175,7 @@ func TestIntegrationAlertStateHistoryStore(t *testing.T) {
 			}
 			res, err := store.Get(
 				context.Background(),
-				&query,
+				query,
 				&annotation_ac.AccessResources{
 					Dashboards: map[string]int64{
 						dashboard1.UID: dashboard1.ID,
@@ -176,7 +201,7 @@ func TestIntegrationAlertStateHistoryStore(t *testing.T) {
 			}
 			res, err := store.Get(
 				context.Background(),
-				&query,
+				query,
 				&annotation_ac.AccessResources{
 					Dashboards: map[string]int64{
 						dashboard1.UID: dashboard1.ID,
@@ -206,7 +231,7 @@ func TestIntegrationAlertStateHistoryStore(t *testing.T) {
 			}
 			res, err := store.Get(
 				context.Background(),
-				&query,
+				query,
 				&annotation_ac.AccessResources{
 					Dashboards: map[string]int64{
 						dashboard1.UID: dashboard1.ID,
@@ -235,7 +260,7 @@ func TestIntegrationAlertStateHistoryStore(t *testing.T) {
 			}
 			res, err := store.Get(
 				context.Background(),
-				&query,
+				query,
 				&annotation_ac.AccessResources{
 					Dashboards: map[string]int64{
 						dashboard1.UID: dashboard1.ID,
@@ -254,6 +279,32 @@ func TestIntegrationAlertStateHistoryStore(t *testing.T) {
 				lastTime = item.Time
 			}
 		})
+
+		t.Run("should return nothing if query is for tags only", func(t *testing.T) {
+			fakeLokiClient.rangeQueryRes = []historian.Stream{
+				historian.StatesToStream(ruleMetaFromRule(t, dashboardRules[dashboard1.UID][0]), transitions, map[string]string{}, log.NewNopLogger()),
+				historian.StatesToStream(ruleMetaFromRule(t, dashboardRules[dashboard1.UID][1]), transitions, map[string]string{}, log.NewNopLogger()),
+			}
+
+			query := annotations.ItemQuery{
+				OrgID: 1,
+				From:  start.UnixMilli(),
+				To:    start.Add(time.Second * time.Duration(numTransitions+1)).UnixMilli(),
+				Tags:  []string{"tag1"},
+			}
+			res, err := store.Get(
+				context.Background(),
+				query,
+				&annotation_ac.AccessResources{
+					Dashboards: map[string]int64{
+						dashboard1.UID: dashboard1.ID,
+					},
+					CanAccessDashAnnotations: true,
+				},
+			)
+			require.NoError(t, err)
+			require.Empty(t, res)
+		})
 	})
 
 	t.Run("Testing items from Loki stream", func(t *testing.T) {
@@ -317,7 +368,7 @@ func TestIntegrationAlertStateHistoryStore(t *testing.T) {
 			rule := dashboardRules[dashboard1.UID][0]
 			stream1 := historian.StatesToStream(ruleMetaFromRule(t, rule), transitions, map[string]string{}, log.NewNopLogger())
 
-			rule = createAlertRule(t, sql, "Test rule", generator)
+			rule = createAlertRule(t, sql, "Test rule", gen)
 			stream2 := historian.StatesToStream(ruleMetaFromRule(t, rule), transitions, map[string]string{}, log.NewNopLogger())
 
 			stream := historian.Stream{
@@ -553,26 +604,29 @@ func TestBuildTransition(t *testing.T) {
 	})
 }
 
-func createTestLokiStore(t *testing.T, sql db.DB, client lokiQueryClient) *LokiHistorianStore {
+func createTestLokiStore(t *testing.T, sql *sqlstore.SQLStore, client lokiQueryClient) *LokiHistorianStore {
 	t.Helper()
+	ruleStore := store.SetupStoreForTesting(t, sql)
 
 	return &LokiHistorianStore{
-		client: client,
-		db:     sql,
-		log:    log.NewNopLogger(),
+		client:    client,
+		db:        sql,
+		log:       log.NewNopLogger(),
+		ruleStore: ruleStore,
 	}
 }
 
 // createAlertRule creates an alert rule in the database and returns it.
 // If a generator is not specified, uniqueness of primary key is not guaranteed.
-func createAlertRule(t *testing.T, sql db.DB, title string, generator func() *ngmodels.AlertRule) *ngmodels.AlertRule {
+func createAlertRule(t *testing.T, sql *sqlstore.SQLStore, title string, generator *ngmodels.AlertRuleGenerator) *ngmodels.AlertRule {
 	t.Helper()
 
 	if generator == nil {
-		generator = ngmodels.AlertRuleGen(ngmodels.WithTitle(title), withDashboardUID(nil), withPanelID(nil), ngmodels.WithOrgID(1))
+		g := ngmodels.RuleGen
+		generator = g.With(g.WithTitle(title), g.WithDashboardAndPanel(nil, nil), g.WithOrgID(1))
 	}
 
-	rule := generator()
+	rule := generator.Generate()
 	// ensure rule has correct values
 	if rule.Title != title {
 		rule.Title = title
@@ -581,42 +635,28 @@ func createAlertRule(t *testing.T, sql db.DB, title string, generator func() *ng
 	rule.DashboardUID = nil
 	rule.PanelID = nil
 
-	err := sql.WithDbSession(context.Background(), func(sess *db.Session) error {
-		_, err := sess.Table(ngmodels.AlertRule{}).InsertOne(rule)
-		if err != nil {
-			return err
-		}
-
-		dbRule := &ngmodels.AlertRule{}
-		exist, err := sess.Table(ngmodels.AlertRule{}).ID(rule.ID).Get(dbRule)
-		if err != nil {
-			return err
-		}
-		if !exist {
-			return errors.New("cannot read inserted record")
-		}
-		rule = dbRule
-
-		return nil
-	})
+	ruleStore := store.SetupStoreForTesting(t, sql)
+	ids, err := ruleStore.InsertAlertRules(context.Background(), []ngmodels.AlertRule{rule})
 	require.NoError(t, err)
-
-	return rule
+	result, err := ruleStore.GetAlertRuleByUID(context.Background(), &ngmodels.GetAlertRuleByUIDQuery{OrgID: rule.OrgID, UID: ids[0].UID})
+	require.NoError(t, err)
+	return result
 }
 
 // createAlertRuleFromDashboard creates an alert rule with a linked dashboard and panel in the database and returns it.
 // If a generator is not specified, uniqueness of primary key is not guaranteed.
-func createAlertRuleFromDashboard(t *testing.T, sql db.DB, title string, dashboard dashboards.Dashboard, generator func() *ngmodels.AlertRule) *ngmodels.AlertRule {
+func createAlertRuleFromDashboard(t *testing.T, sql *sqlstore.SQLStore, title string, dashboard dashboards.Dashboard, generator *ngmodels.AlertRuleGenerator) *ngmodels.AlertRule {
 	t.Helper()
 
 	panelID := new(int64)
 	*panelID = 123
 
 	if generator == nil {
-		generator = ngmodels.AlertRuleGen(ngmodels.WithTitle(title), ngmodels.WithOrgID(1), withDashboardUID(&dashboard.UID), withPanelID(panelID))
+		g := ngmodels.RuleGen
+		generator = g.With(g.WithTitle(title), g.WithDashboardAndPanel(&dashboard.UID, panelID), g.WithOrgID(1))
 	}
 
-	rule := generator()
+	rule := generator.Generate()
 	// ensure rule has correct values
 	if rule.Title != title {
 		rule.Title = title
@@ -627,28 +667,12 @@ func createAlertRuleFromDashboard(t *testing.T, sql db.DB, title string, dashboa
 	if rule.PanelID == nil || (rule.PanelID != nil && *rule.PanelID != *panelID) {
 		rule.PanelID = panelID
 	}
-
-	err := sql.WithDbSession(context.Background(), func(sess *db.Session) error {
-		_, err := sess.Table(ngmodels.AlertRule{}).InsertOne(rule)
-		if err != nil {
-			return err
-		}
-
-		dbRule := &ngmodels.AlertRule{}
-		exist, err := sess.Table(ngmodels.AlertRule{}).ID(rule.ID).Get(dbRule)
-		if err != nil {
-			return err
-		}
-		if !exist {
-			return errors.New("cannot read inserted record")
-		}
-		rule = dbRule
-
-		return nil
-	})
+	ruleStore := store.SetupStoreForTesting(t, sql)
+	ids, err := ruleStore.InsertAlertRules(context.Background(), []ngmodels.AlertRule{rule})
 	require.NoError(t, err)
-
-	return rule
+	result, err := ruleStore.GetAlertRuleByUID(context.Background(), &ngmodels.GetAlertRuleByUIDQuery{OrgID: rule.OrgID, UID: ids[0].UID})
+	require.NoError(t, err)
+	return result
 }
 
 func ruleMetaFromRule(t *testing.T, rule *ngmodels.AlertRule) historymodel.RuleMeta {
@@ -715,18 +739,6 @@ func genStateTransitions(t *testing.T, num int, start time.Time) []state.StateTr
 	return transitions
 }
 
-func withDashboardUID(dashboardUID *string) ngmodels.AlertRuleMutator {
-	return func(rule *ngmodels.AlertRule) {
-		rule.DashboardUID = dashboardUID
-	}
-}
-
-func withPanelID(panelID *int64) ngmodels.AlertRuleMutator {
-	return func(rule *ngmodels.AlertRule) {
-		rule.PanelID = panelID
-	}
-}
-
 func compareAnnotationItem(t *testing.T, expected, actual *annotations.ItemDTO) {
 	require.Equal(t, expected.AlertID, actual.AlertID)
 	require.Equal(t, expected.AlertName, actual.AlertName)
@@ -768,6 +780,7 @@ func NewFakeLokiClient() *FakeLokiClient {
 			ReadPathURL:    url,
 			Encoder:        historian.JsonEncoder{},
 			MaxQueryLength: 721 * time.Hour,
+			MaxQuerySize:   65536,
 		},
 		metrics: metrics,
 		log:     log.New("ngalert.state.historian", "backend", "loki"),
@@ -802,6 +815,10 @@ func (c *FakeLokiClient) RangeQuery(ctx context.Context, query string, from, to,
 	return res, nil
 }
 
+func (c *FakeLokiClient) MaxQuerySize() int {
+	return c.cfg.MaxQuerySize
+}
+
 func TestUseStore(t *testing.T) {
 	t.Run("false if state history disabled", func(t *testing.T) {
 		cfg := setting.UnifiedAlertingStateHistorySettings{
