@@ -6,9 +6,7 @@ import (
 	"net/http"
 	"path"
 
-	"github.com/grafana/dskit/services"
-	"google.golang.org/grpc"
-	"google.golang.org/grpc/credentials/insecure"
+	"github.com/prometheus/client_golang/prometheus"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
@@ -17,31 +15,40 @@ import (
 	genericapiserver "k8s.io/apiserver/pkg/server"
 	clientrest "k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/clientcmd"
+	aggregatorapiserver "k8s.io/kube-aggregator/pkg/apiserver"
 
+	"github.com/grafana/dskit/services"
+	"github.com/grafana/grafana-plugin-sdk-go/backend"
+	dataplaneaggregator "github.com/grafana/grafana/pkg/aggregator/apiserver"
 	"github.com/grafana/grafana/pkg/api/routing"
-	"github.com/grafana/grafana/pkg/apiserver/builder"
+	"github.com/grafana/grafana/pkg/apimachinery/identity"
 	grafanaresponsewriter "github.com/grafana/grafana/pkg/apiserver/endpoints/responsewriter"
-	filestorage "github.com/grafana/grafana/pkg/apiserver/storage/file"
-	"github.com/grafana/grafana/pkg/infra/appcontext"
 	"github.com/grafana/grafana/pkg/infra/db"
+	"github.com/grafana/grafana/pkg/infra/kvstore"
+	"github.com/grafana/grafana/pkg/infra/log"
+	"github.com/grafana/grafana/pkg/infra/metrics"
+	"github.com/grafana/grafana/pkg/infra/serverlock"
 	"github.com/grafana/grafana/pkg/infra/tracing"
 	"github.com/grafana/grafana/pkg/middleware"
 	"github.com/grafana/grafana/pkg/modules"
+	servicetracing "github.com/grafana/grafana/pkg/modules/tracing"
+	"github.com/grafana/grafana/pkg/plugins"
 	"github.com/grafana/grafana/pkg/registry"
-	"github.com/grafana/grafana/pkg/services/apiserver/aggregator"
+	"github.com/grafana/grafana/pkg/registry/apis/datasource"
+	kubeaggregator "github.com/grafana/grafana/pkg/services/apiserver/aggregator"
 	"github.com/grafana/grafana/pkg/services/apiserver/auth/authenticator"
 	"github.com/grafana/grafana/pkg/services/apiserver/auth/authorizer"
+	"github.com/grafana/grafana/pkg/services/apiserver/builder"
 	"github.com/grafana/grafana/pkg/services/apiserver/endpoints/request"
 	grafanaapiserveroptions "github.com/grafana/grafana/pkg/services/apiserver/options"
-	entitystorage "github.com/grafana/grafana/pkg/services/apiserver/storage/entity"
 	"github.com/grafana/grafana/pkg/services/apiserver/utils"
 	contextmodel "github.com/grafana/grafana/pkg/services/contexthandler/model"
 	"github.com/grafana/grafana/pkg/services/featuremgmt"
 	"github.com/grafana/grafana/pkg/services/org"
-	"github.com/grafana/grafana/pkg/services/store/entity"
-	"github.com/grafana/grafana/pkg/services/store/entity/db/dbimpl"
-	"github.com/grafana/grafana/pkg/services/store/entity/sqlstash"
+	"github.com/grafana/grafana/pkg/services/pluginsintegration/pluginstore"
 	"github.com/grafana/grafana/pkg/setting"
+	"github.com/grafana/grafana/pkg/storage/unified/apistore"
+	"github.com/grafana/grafana/pkg/storage/unified/resource"
 )
 
 var (
@@ -61,6 +68,8 @@ var (
 		&metav1.APIGroupList{},
 		&metav1.APIGroup{},
 		&metav1.APIResourceList{},
+		&metav1.PartialObjectMetadata{},
+		&metav1.PartialObjectMetadataList{},
 	}
 )
 
@@ -77,12 +86,12 @@ type Service interface {
 }
 
 type RestConfigProvider interface {
-	GetRestConfig() *clientrest.Config
+	GetRestConfig(context.Context) *clientrest.Config
 }
 
 type DirectRestConfigProvider interface {
 	// GetDirectRestConfig returns a k8s client configuration that will use the same
-	// logged logged in user as the current request context.  This is useful when
+	// logged in user as the current request context.  This is useful when
 	// creating clients that map legacy API handlers to k8s backed services
 	GetDirectRestConfig(c *contextmodel.ReqContext) *clientrest.Config
 
@@ -91,13 +100,14 @@ type DirectRestConfigProvider interface {
 }
 
 type service struct {
-	*services.BasicService
+	services.NamedService
 
 	options    *grafanaapiserveroptions.Options
 	restConfig *clientrest.Config
 
 	cfg      *setting.Cfg
 	features featuremgmt.FeatureToggles
+	log      log.Logger
 
 	stopCh    chan struct{}
 	stoppedCh chan error
@@ -108,8 +118,17 @@ type service struct {
 	builders []builder.APIGroupBuilder
 
 	tracing *tracing.TracingService
+	metrics prometheus.Registerer
 
-	authorizer *authorizer.GrafanaAuthorizer
+	authorizer        *authorizer.GrafanaAuthorizer
+	serverLockService builder.ServerLockService
+	kvStore           kvstore.KVStore
+
+	pluginClient    plugins.Client
+	datasources     datasource.ScopedPluginDatasourceProvider
+	contextProvider datasource.PluginContextWrapper
+	pluginStore     pluginstore.Store
+	unified         resource.ResourceClient
 }
 
 func ProvideService(
@@ -118,30 +137,52 @@ func ProvideService(
 	rr routing.RouteRegister,
 	orgService org.Service,
 	tracing *tracing.TracingService,
+	serverLockService *serverlock.ServerLockService,
 	db db.DB,
+	kvStore kvstore.KVStore,
+	pluginClient plugins.Client,
+	datasources datasource.ScopedPluginDatasourceProvider,
+	contextProvider datasource.PluginContextWrapper,
+	pluginStore pluginstore.Store,
+	unified resource.ResourceClient,
 ) (*service, error) {
 	s := &service{
-		cfg:        cfg,
-		features:   features,
-		rr:         rr,
-		stopCh:     make(chan struct{}),
-		builders:   []builder.APIGroupBuilder{},
-		authorizer: authorizer.NewGrafanaAuthorizer(cfg, orgService),
-		tracing:    tracing,
-		db:         db, // For Unified storage
+		log:               log.New(modules.GrafanaAPIServer),
+		cfg:               cfg,
+		features:          features,
+		rr:                rr,
+		stopCh:            make(chan struct{}),
+		builders:          []builder.APIGroupBuilder{},
+		authorizer:        authorizer.NewGrafanaAuthorizer(cfg, orgService),
+		tracing:           tracing,
+		db:                db, // For Unified storage
+		metrics:           metrics.ProvideRegisterer(),
+		kvStore:           kvStore,
+		pluginClient:      pluginClient,
+		datasources:       datasources,
+		contextProvider:   contextProvider,
+		pluginStore:       pluginStore,
+		serverLockService: serverLockService,
+		unified:           unified,
 	}
-
 	// This will be used when running as a dskit service
-	s.BasicService = services.NewBasicService(s.start, s.running, nil).WithName(modules.GrafanaAPIServer)
+	service := services.NewBasicService(s.start, s.running, nil).WithName(modules.GrafanaAPIServer)
+	s.NamedService = servicetracing.NewServiceTracer(tracing.GetTracerProvider(), service)
 
 	// TODO: this is very hacky
 	// We need to register the routes in ProvideService to make sure
 	// the routes are registered before the Grafana HTTP server starts.
 	proxyHandler := func(k8sRoute routing.RouteRegister) {
 		handler := func(c *contextmodel.ReqContext) {
+			if err := s.NamedService.AwaitRunning(c.Req.Context()); err != nil {
+				c.Resp.WriteHeader(http.StatusInternalServerError)
+				_, _ = c.Resp.Write([]byte(http.StatusText(http.StatusInternalServerError)))
+				return
+			}
+
 			if s.handler == nil {
-				c.Resp.WriteHeader(404)
-				_, _ = c.Resp.Write([]byte("Not found"))
+				c.Resp.WriteHeader(http.StatusNotFound)
+				_, _ = c.Resp.Write([]byte(http.StatusText(http.StatusNotFound)))
 				return
 			}
 
@@ -150,6 +191,11 @@ func ProvideService(
 				req.URL.Path = "/"
 			}
 
+			if c.SignedInUser != nil {
+				ctx := identity.WithRequester(req.Context(), c.SignedInUser)
+				req = req.WithContext(ctx)
+			}
+
 			resp := responsewriter.WrapForHTTP1Or2(c.Resp)
 			s.handler.ServeHTTP(resp, req)
 		}
@@ -167,7 +213,10 @@ func ProvideService(
 	return s, nil
 }
 
-func (s *service) GetRestConfig() *clientrest.Config {
+func (s *service) GetRestConfig(ctx context.Context) *clientrest.Config {
+	if err := s.NamedService.AwaitRunning(ctx); err != nil {
+		return nil
+	}
 	return s.restConfig
 }
 
@@ -177,23 +226,28 @@ func (s *service) IsDisabled() bool {
 
 // Run is an adapter for the BackgroundService interface.
 func (s *service) Run(ctx context.Context) error {
-	if err := s.start(ctx); err != nil {
+	if err := s.NamedService.StartAsync(ctx); err != nil {
 		return err
 	}
-	return s.running(ctx)
+
+	if err := s.NamedService.AwaitRunning(ctx); err != nil {
+		return err
+	}
+	return s.AwaitTerminated(ctx)
 }
 
 func (s *service) RegisterAPI(b builder.APIGroupBuilder) {
 	s.builders = append(s.builders, b)
 }
 
+// nolint:gocyclo
 func (s *service) start(ctx context.Context) error {
 	// Get the list of groups the server will support
 	builders := s.builders
 
 	groupVersions := make([]schema.GroupVersion, 0, len(builders))
 	// Install schemas
-	initialSize := len(aggregator.APIVersionPriorities)
+	initialSize := len(kubeaggregator.APIVersionPriorities)
 	for i, b := range builders {
 		groupVersions = append(groupVersions, b.GetGroupVersion())
 		if err := b.InstallSchema(Scheme); err != nil {
@@ -202,7 +256,7 @@ func (s *service) start(ctx context.Context) error {
 
 		if s.features.IsEnabledGlobally(featuremgmt.FlagKubernetesAggregator) {
 			// set the priority for the group+version
-			aggregator.APIVersionPriorities[b.GetGroupVersion()] = aggregator.Priority{Group: 15000, Version: int32(i + initialSize)}
+			kubeaggregator.APIVersionPriorities[b.GetGroupVersion()] = kubeaggregator.Priority{Group: 15000, Version: int32(i + initialSize)}
 		}
 
 		auth := b.GetAuthorizer()
@@ -212,13 +266,24 @@ func (s *service) start(ctx context.Context) error {
 	}
 
 	o := grafanaapiserveroptions.NewOptions(Codecs.LegacyCodec(groupVersions...))
-	applyGrafanaConfig(s.cfg, s.features, o)
+	err := applyGrafanaConfig(s.cfg, s.features, o)
+	if err != nil {
+		return err
+	}
 
 	if errs := o.Validate(); len(errs) != 0 {
 		// TODO: handle multiple errors
 		return errs[0]
 	}
 
+	// This will check that required feature toggles are enabled for more advanced storage modes
+	// Any required preconditions should be hardcoded here
+	if o.StorageOptions != nil {
+		if err := o.StorageOptions.EnforceFeatureToggleAfterMode1(s.features); err != nil {
+			return err
+		}
+	}
+
 	serverConfig := genericapiserver.NewRecommendedConfig(Codecs)
 	if err := o.ApplyTo(serverConfig); err != nil {
 		return err
@@ -232,61 +297,25 @@ func (s *service) start(ctx context.Context) error {
 	serverConfig.LoopbackClientConfig.Transport = transport
 	serverConfig.LoopbackClientConfig.TLSClientConfig = clientrest.TLSClientConfig{}
 
-	switch o.StorageOptions.StorageType {
-	case grafanaapiserveroptions.StorageTypeEtcd:
+	var optsregister apistore.StorageOptionsRegister
+
+	if o.StorageOptions.StorageType == grafanaapiserveroptions.StorageTypeEtcd {
 		if err := o.RecommendedOptions.Etcd.Validate(); len(err) > 0 {
 			return err[0]
 		}
 		if err := o.RecommendedOptions.Etcd.ApplyTo(&serverConfig.Config); err != nil {
 			return err
 		}
+	} else {
+		getter := apistore.NewRESTOptionsGetterForClient(s.unified, o.RecommendedOptions.Etcd.StorageConfig)
+		optsregister = getter.RegisterOptions
 
-	case grafanaapiserveroptions.StorageTypeUnified:
-		if !s.features.IsEnabledGlobally(featuremgmt.FlagUnifiedStorage) {
-			return fmt.Errorf("unified storage requires the unifiedStorage feature flag (and app_mode = development)")
-		}
-
-		eDB, err := dbimpl.ProvideEntityDB(s.db, s.cfg, s.features)
-		if err != nil {
-			return err
-		}
-
-		storeServer, err := sqlstash.ProvideSQLEntityServer(eDB)
-		if err != nil {
-			return err
-		}
-
-		store := entity.NewEntityStoreClientLocal(storeServer)
-
-		serverConfig.Config.RESTOptionsGetter = entitystorage.NewRESTOptionsGetter(s.cfg, store, o.RecommendedOptions.Etcd.StorageConfig.Codec)
-
-	case grafanaapiserveroptions.StorageTypeUnifiedGrpc:
-		// Create a connection to the gRPC server
-		conn, err := grpc.Dial(o.StorageOptions.Address, grpc.WithTransportCredentials(insecure.NewCredentials()))
-		if err != nil {
-			return err
-		}
-
-		// TODO: determine when to close the connection, we cannot defer it here
-		// defer conn.Close()
-
-		// Create a client instance
-		store := entity.NewEntityStoreClientGRPC(conn)
-
-		serverConfig.Config.RESTOptionsGetter = entitystorage.NewRESTOptionsGetter(s.cfg, store, o.RecommendedOptions.Etcd.StorageConfig.Codec)
-
-	case grafanaapiserveroptions.StorageTypeLegacy:
-		fallthrough
-	case grafanaapiserveroptions.StorageTypeFile:
-		restOptionsGetter, err := filestorage.NewRESTOptionsGetter(o.StorageOptions.DataPath, o.RecommendedOptions.Etcd.StorageConfig)
-		if err != nil {
-			return err
-		}
-		serverConfig.RESTOptionsGetter = restOptionsGetter
+		// Use unified storage client
+		serverConfig.Config.RESTOptionsGetter = getter
 	}
 
 	// Add OpenAPI specs for each group+version
-	err := builder.SetupConfig(
+	err = builder.SetupConfig(
 		Scheme,
 		serverConfig,
 		builders,
@@ -294,6 +323,7 @@ func (s *service) start(ctx context.Context) error {
 		s.cfg.BuildVersion,
 		s.cfg.BuildCommit,
 		s.cfg.BuildBranch,
+		nil,
 	)
 	if err != nil {
 		return err
@@ -305,13 +335,13 @@ func (s *service) start(ctx context.Context) error {
 		return err
 	}
 
-	// dual writing is only enabled when the storage type is not legacy.
-	// this is needed to support setting a default RESTOptionsGetter for new APIs that don't
-	// support the legacy storage type.
-	dualWriteEnabled := o.StorageOptions.StorageType != grafanaapiserveroptions.StorageTypeLegacy
-
 	// Install the API group+version
-	err = builder.InstallAPIs(Scheme, Codecs, server, serverConfig.RESTOptionsGetter, builders, dualWriteEnabled)
+	err = builder.InstallAPIs(Scheme, Codecs, server, serverConfig.RESTOptionsGetter, builders, o.StorageOptions,
+		// Required for the dual writer initialization
+		s.metrics, request.GetNamespaceMapper(s.cfg), kvstore.WithNamespace(s.kvStore, 0, "storage.dualwriting"),
+		s.serverLockService,
+		optsregister,
+	)
 	if err != nil {
 		return err
 	}
@@ -319,14 +349,29 @@ func (s *service) start(ctx context.Context) error {
 	// stash the options for later use
 	s.options = o
 
-	var runningServer *genericapiserver.GenericAPIServer
+	delegate := server
+	var aggregatorServer *aggregatorapiserver.APIAggregator
 	if s.features.IsEnabledGlobally(featuremgmt.FlagKubernetesAggregator) {
-		runningServer, err = s.startAggregator(transport, serverConfig, server)
+		aggregatorServer, err = s.createKubeAggregator(serverConfig, server, s.metrics)
+		if err != nil {
+			return err
+		}
+		delegate = aggregatorServer.GenericAPIServer
+	}
+
+	var runningServer *genericapiserver.GenericAPIServer
+	if s.features.IsEnabledGlobally(featuremgmt.FlagDataplaneAggregator) {
+		runningServer, err = s.startDataplaneAggregator(ctx, transport, serverConfig, delegate)
+		if err != nil {
+			return err
+		}
+	} else if s.features.IsEnabledGlobally(featuremgmt.FlagKubernetesAggregator) {
+		runningServer, err = s.startKubeAggregator(ctx, transport, aggregatorServer)
 		if err != nil {
 			return err
 		}
 	} else {
-		runningServer, err = s.startCoreServer(transport, serverConfig, server)
+		runningServer, err = s.startCoreServer(ctx, transport, server)
 		if err != nil {
 			return err
 		}
@@ -348,8 +393,8 @@ func (s *service) start(ctx context.Context) error {
 }
 
 func (s *service) startCoreServer(
+	ctx context.Context,
 	transport *roundTripperFunc,
-	serverConfig *genericapiserver.RecommendedConfig,
 	server *genericapiserver.GenericAPIServer,
 ) (*genericapiserver.GenericAPIServer, error) {
 	// setup the loopback transport and signal that it's ready.
@@ -361,25 +406,37 @@ func (s *service) startCoreServer(
 
 	prepared := server.PrepareRun()
 	go func() {
-		s.stoppedCh <- prepared.Run(s.stopCh)
+		s.stoppedCh <- prepared.RunWithContext(ctx)
 	}()
 
 	return server, nil
 }
 
-func (s *service) startAggregator(
+func (s *service) startDataplaneAggregator(
+	ctx context.Context,
 	transport *roundTripperFunc,
 	serverConfig *genericapiserver.RecommendedConfig,
-	server *genericapiserver.GenericAPIServer,
+	delegate *genericapiserver.GenericAPIServer,
 ) (*genericapiserver.GenericAPIServer, error) {
-	namespaceMapper := request.GetNamespaceMapper(s.cfg)
+	config := &dataplaneaggregator.Config{
+		GenericConfig: serverConfig,
+		ExtraConfig: dataplaneaggregator.ExtraConfig{
+			PluginClient: s.pluginClient,
+			PluginContextProvider: &pluginContextProvider{
+				pluginStore:     s.pluginStore,
+				datasources:     s.datasources,
+				contextProvider: s.contextProvider,
+			},
+		},
+	}
 
-	aggregatorConfig, err := aggregator.CreateAggregatorConfig(s.options, *serverConfig, namespaceMapper(1))
-	if err != nil {
+	if err := s.options.GrafanaAggregatorOptions.ApplyTo(config, s.options.RecommendedOptions.Etcd); err != nil {
 		return nil, err
 	}
 
-	aggregatorServer, err := aggregator.CreateAggregatorServer(aggregatorConfig, server)
+	completedConfig := config.Complete()
+
+	aggregatorServer, err := completedConfig.NewWithDelegate(delegate)
 	if err != nil {
 		return nil, err
 	}
@@ -397,7 +454,46 @@ func (s *service) startAggregator(
 	}
 
 	go func() {
-		s.stoppedCh <- prepared.Run(s.stopCh)
+		s.stoppedCh <- prepared.RunWithContext(ctx)
+	}()
+
+	return aggregatorServer.GenericAPIServer, nil
+}
+
+func (s *service) createKubeAggregator(
+	serverConfig *genericapiserver.RecommendedConfig,
+	server *genericapiserver.GenericAPIServer,
+	reg prometheus.Registerer,
+) (*aggregatorapiserver.APIAggregator, error) {
+	namespaceMapper := request.GetNamespaceMapper(s.cfg)
+
+	aggregatorConfig, err := kubeaggregator.CreateAggregatorConfig(s.options, *serverConfig, namespaceMapper(1))
+	if err != nil {
+		return nil, err
+	}
+
+	return kubeaggregator.CreateAggregatorServer(aggregatorConfig, server, reg)
+}
+
+func (s *service) startKubeAggregator(
+	ctx context.Context,
+	transport *roundTripperFunc,
+	aggregatorServer *aggregatorapiserver.APIAggregator,
+) (*genericapiserver.GenericAPIServer, error) {
+	// setup the loopback transport for the aggregator server and signal that it's ready
+	// ignore the lint error because the response is passed directly to the client,
+	// so the client will be responsible for closing the response body.
+	// nolint:bodyclose
+	transport.fn = grafanaresponsewriter.WrapHandler(aggregatorServer.GenericAPIServer.Handler)
+	close(transport.ready)
+
+	prepared, err := aggregatorServer.PrepareRun()
+	if err != nil {
+		return nil, err
+	}
+
+	go func() {
+		s.stoppedCh <- prepared.Run(ctx)
 	}()
 
 	return aggregatorServer.GenericAPIServer, nil
@@ -407,7 +503,10 @@ func (s *service) GetDirectRestConfig(c *contextmodel.ReqContext) *clientrest.Co
 	return &clientrest.Config{
 		Transport: &roundTripperFunc{
 			fn: func(req *http.Request) (*http.Response, error) {
-				ctx := appcontext.WithUser(req.Context(), c.SignedInUser)
+				if err := s.NamedService.AwaitRunning(req.Context()); err != nil {
+					return nil, err
+				}
+				ctx := identity.WithRequester(req.Context(), c.SignedInUser)
 				wrapped := grafanaresponsewriter.WrapHandler(s.handler)
 				return wrapped(req.WithContext(ctx))
 			},
@@ -416,6 +515,9 @@ func (s *service) GetDirectRestConfig(c *contextmodel.ReqContext) *clientrest.Co
 }
 
 func (s *service) DirectlyServeHTTP(w http.ResponseWriter, r *http.Request) {
+	if err := s.NamedService.AwaitRunning(r.Context()); err != nil {
+		return
+	}
 	s.handler.ServeHTTP(w, r)
 }
 
@@ -426,7 +528,7 @@ func (s *service) running(ctx context.Context) error {
 			return err
 		}
 	case <-ctx.Done():
-		close(s.stopCh)
+		return ctx.Err()
 	}
 	return nil
 }
@@ -449,3 +551,30 @@ func (f *roundTripperFunc) RoundTrip(req *http.Request) (*http.Response, error)
 	}
 	return f.fn(req)
 }
+
+type pluginContextProvider struct {
+	pluginStore     pluginstore.Store
+	datasources     datasource.ScopedPluginDatasourceProvider
+	contextProvider datasource.PluginContextWrapper
+}
+
+func (p *pluginContextProvider) GetPluginContext(ctx context.Context, pluginID string, uid string) (backend.PluginContext, error) {
+	all := p.pluginStore.Plugins(ctx)
+
+	var datasourceProvider datasource.PluginDatasourceProvider
+	for _, plugin := range all {
+		if plugin.ID == pluginID {
+			datasourceProvider = p.datasources.GetDatasourceProvider(plugin.JSONData)
+		}
+	}
+	if datasourceProvider == nil {
+		return backend.PluginContext{}, fmt.Errorf("plugin not found")
+	}
+
+	s, err := datasourceProvider.GetInstanceSettings(ctx, uid)
+	if err != nil {
+		return backend.PluginContext{}, err
+	}
+
+	return p.contextProvider.PluginContextForDataSource(ctx, s)
+}
