@@ -8,11 +8,11 @@ import (
 )
 
 func TestReadRuntimeCOnfig(t *testing.T) {
-	out, err := ReadRuntimeConfig("all/all=true,dashboards.grafana.app/v0alpha1=false")
+	out, err := ReadRuntimeConfig("all/all=true,dashboard.grafana.app/v0alpha1=false")
 	require.NoError(t, err)
 	require.Equal(t, []RuntimeConfig{
 		{Group: "all", Version: "all", Enabled: true},
-		{Group: "dashboards.grafana.app", Version: "v0alpha1", Enabled: false},
+		{Group: "dashboard.grafana.app", Version: "v0alpha1", Enabled: false},
 	}, out)
 	require.Equal(t, "all/all=true", fmt.Sprintf("%v", out[0]))
 
