@@ -2,29 +2,36 @@ package clients
 
 import (
 	"context"
+	"errors"
 	"net/url"
+	"strconv"
 	"time"
 
+	"github.com/grafana/authlib/claims"
 	"github.com/grafana/grafana/pkg/infra/log"
 	"github.com/grafana/grafana/pkg/services/auth"
 	"github.com/grafana/grafana/pkg/services/authn"
+	"github.com/grafana/grafana/pkg/services/login"
+	"github.com/grafana/grafana/pkg/services/user"
 	"github.com/grafana/grafana/pkg/setting"
 )
 
 var _ authn.ContextAwareClient = new(Session)
 
-func ProvideSession(cfg *setting.Cfg, sessionService auth.UserTokenService) *Session {
+func ProvideSession(cfg *setting.Cfg, sessionService auth.UserTokenService, authInfoService login.AuthInfoService) *Session {
 	return &Session{
-		cfg:            cfg,
-		sessionService: sessionService,
-		log:            log.New(authn.ClientSession),
+		cfg:             cfg,
+		log:             log.New(authn.ClientSession),
+		sessionService:  sessionService,
+		authInfoService: authInfoService,
 	}
 }
 
 type Session struct {
-	cfg            *setting.Cfg
-	sessionService auth.UserTokenService
-	log            log.Logger
+	cfg             *setting.Cfg
+	log             log.Logger
+	sessionService  auth.UserTokenService
+	authInfoService login.AuthInfoService
 }
 
 func (s *Session) Name() string {
@@ -51,14 +58,31 @@ func (s *Session) Authenticate(ctx context.Context, r *authn.Request) (*authn.Id
 		return nil, authn.ErrTokenNeedsRotation.Errorf("token needs to be rotated")
 	}
 
-	return &authn.Identity{
-		ID:           authn.NamespacedID(authn.NamespaceUser, token.UserId),
+	ident := &authn.Identity{
+		ID:           strconv.FormatInt(token.UserId, 10),
+		Type:         claims.TypeUser,
 		SessionToken: token,
 		ClientParams: authn.ClientParams{
 			FetchSyncedUser: true,
 			SyncPermissions: true,
 		},
-	}, nil
+	}
+
+	info, err := s.authInfoService.GetAuthInfo(ctx, &login.GetAuthInfoQuery{UserId: token.UserId})
+	if err != nil {
+		if !errors.Is(err, user.ErrUserNotFound) {
+			s.log.FromContext(ctx).Error("Failed to fetch auth info", "err", err)
+		}
+		return ident, nil
+	}
+
+	ident.AuthID = info.AuthId
+	ident.AuthenticatedBy = info.AuthModule
+	return ident, nil
+}
+
+func (s *Session) IsEnabled() bool {
+	return true
 }
 
 func (s *Session) Test(ctx context.Context, r *authn.Request) bool {
