@@ -1000,6 +1000,11 @@ func TestService_awsServiceNamespace(t *testing.T) {
 			givenDs:   datasources.DS_PROMETHEUS,
 			givenJson: `{ "sigV4Auth": true, "serverless": true }`,
 			want:      "aps",
+		}, {
+			desc:      "amazon prometheus",
+			givenDs:   datasources.DS_AMAZON_PROMETHEUS,
+			givenJson: `{ "sigV4Auth": true }`,
+			want:      "aps",
 		}, {
 			desc:      "alertmanager",
 			givenDs:   datasources.DS_ALERTMANAGER,
@@ -1011,6 +1016,12 @@ func TestService_awsServiceNamespace(t *testing.T) {
 			givenJson: `{ "sigV4Auth": true, "serverless": true }`,
 			want:      "aps",
 			panic:     true,
+		}, {
+			desc:      "azure prometheus",
+			givenDs:   datasources.DS_AZURE_PROMETHEUS,
+			givenJson: `{ "sigV4Auth": true }`,
+			want:      "aps",
+			panic:     true,
 		},
 	}
 	for _, tc := range testCases {
