@@ -1,6 +1,6 @@
 package extsvcauth
 
-import "github.com/grafana/grafana/pkg/util/errutil"
+import "github.com/grafana/grafana/pkg/apimachinery/errutil"
 
 var (
 	ErrUnknownProvider = errutil.BadRequest("extsvcauth.unknown-provider")
