@@ -11,13 +11,19 @@ import (
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/uuid"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/mock"
 	"github.com/stretchr/testify/require"
 
+	"github.com/grafana/grafana/pkg/infra/db"
+	"github.com/grafana/grafana/pkg/services/accesscontrol"
+	"github.com/grafana/grafana/pkg/services/dashboards"
 	"github.com/grafana/grafana/pkg/services/folder"
 	"github.com/grafana/grafana/pkg/services/org"
 	"github.com/grafana/grafana/pkg/services/org/orgimpl"
 	"github.com/grafana/grafana/pkg/services/quota/quotatest"
 	"github.com/grafana/grafana/pkg/services/sqlstore"
+	"github.com/grafana/grafana/pkg/services/user"
+	"github.com/grafana/grafana/pkg/setting"
 	"github.com/grafana/grafana/pkg/util"
 )
 
@@ -29,10 +35,10 @@ func TestIntegrationCreate(t *testing.T) {
 		t.Skip("skipping integration test")
 	}
 
-	db := sqlstore.InitTestDB(t)
-	folderStore := ProvideStore(db, db.Cfg)
+	db, cfg := sqlstore.InitTestDB(t)
+	folderStore := ProvideStore(db)
 
-	orgID := CreateOrg(t, db)
+	orgID := CreateOrg(t, db, cfg)
 
 	t.Run("creating a folder without providing a UID should fail", func(t *testing.T) {
 		_, err := folderStore.Create(context.Background(), folder.CreateFolderCommand{
@@ -149,10 +155,10 @@ func TestIntegrationDelete(t *testing.T) {
 		t.Skip("skipping integration test")
 	}
 
-	db := sqlstore.InitTestDB(t)
-	folderStore := ProvideStore(db, db.Cfg)
+	db, cfg := sqlstore.InitTestDB(t)
+	folderStore := ProvideStore(db)
 
-	orgID := CreateOrg(t, db)
+	orgID := CreateOrg(t, db, cfg)
 
 	/*
 		t.Run("attempt to delete unknown folder should fail", func(t *testing.T) {
@@ -196,10 +202,10 @@ func TestIntegrationUpdate(t *testing.T) {
 		t.Skip("skipping integration test")
 	}
 
-	db := sqlstore.InitTestDB(t)
-	folderStore := ProvideStore(db, db.Cfg)
+	db, cfg := sqlstore.InitTestDB(t)
+	folderStore := ProvideStore(db)
 
-	orgID := CreateOrg(t, db)
+	orgID := CreateOrg(t, db, cfg)
 
 	// create parent folder
 	parent, err := folderStore.Create(context.Background(), folder.CreateFolderCommand{
@@ -371,10 +377,10 @@ func TestIntegrationGet(t *testing.T) {
 		t.Skip("skipping integration test")
 	}
 
-	db := sqlstore.InitTestDB(t)
-	folderStore := ProvideStore(db, db.Cfg)
+	db, cfg := sqlstore.InitTestDB(t)
+	folderStore := ProvideStore(db)
 
-	orgID := CreateOrg(t, db)
+	orgID := CreateOrg(t, db, cfg)
 
 	// create folder
 	uid1 := util.GenerateShortUID()
@@ -481,6 +487,24 @@ func TestIntegrationGet(t *testing.T) {
 		assert.NotEmpty(t, ff.Updated)
 		assert.NotEmpty(t, ff.URL)
 	})
+
+	t.Run("get folder withFullpathUIDs should set fullpathUIDs as expected", func(t *testing.T) {
+		ff, err := folderStore.Get(context.Background(), folder.GetFolderQuery{
+			UID:              &subfolderWithSameName.UID,
+			OrgID:            orgID,
+			WithFullpathUIDs: true,
+		})
+		require.NoError(t, err)
+		assert.Equal(t, subfolderWithSameName.UID, ff.UID)
+		assert.Equal(t, subfolderWithSameName.OrgID, ff.OrgID)
+		assert.Equal(t, subfolderWithSameName.Title, ff.Title)
+		assert.Equal(t, subfolderWithSameName.Description, ff.Description)
+		assert.Equal(t, path.Join(f.UID, subfolderWithSameName.UID), ff.FullpathUIDs)
+		assert.Equal(t, f.UID, ff.ParentUID)
+		assert.NotEmpty(t, ff.Created)
+		assert.NotEmpty(t, ff.Updated)
+		assert.NotEmpty(t, ff.URL)
+	})
 }
 
 func TestIntegrationGetParents(t *testing.T) {
@@ -488,10 +512,10 @@ func TestIntegrationGetParents(t *testing.T) {
 		t.Skip("skipping integration test")
 	}
 
-	db := sqlstore.InitTestDB(t)
-	folderStore := ProvideStore(db, db.Cfg)
+	db, cfg := sqlstore.InitTestDB(t)
+	folderStore := ProvideStore(db)
 
-	orgID := CreateOrg(t, db)
+	orgID := CreateOrg(t, db, cfg)
 
 	// create folder
 	uid1 := util.GenerateShortUID()
@@ -556,10 +580,10 @@ func TestIntegrationGetChildren(t *testing.T) {
 		t.Skip("skipping integration test")
 	}
 
-	db := sqlstore.InitTestDB(t)
-	folderStore := ProvideStore(db, db.Cfg)
+	db, cfg := sqlstore.InitTestDB(t)
+	folderStore := ProvideStore(db)
 
-	orgID := CreateOrg(t, db)
+	orgID := CreateOrg(t, db, cfg)
 
 	// create folder
 	uid1 := util.GenerateShortUID()
@@ -729,6 +753,68 @@ func TestIntegrationGetChildren(t *testing.T) {
 			t.Errorf("Result mismatch (-want +got):\n%s", diff)
 		}
 	})
+
+	t.Run("should hide k6-app folder for users but not for service accounts", func(t *testing.T) {
+		_, err = folderStore.Create(context.Background(), folder.CreateFolderCommand{
+			Title: "k6-app-folder",
+			OrgID: orgID,
+			UID:   accesscontrol.K6FolderUID,
+		})
+		require.NoError(t, err)
+
+		children, err := folderStore.GetChildren(context.Background(), folder.GetChildrenQuery{
+			OrgID:        orgID,
+			SignedInUser: usr,
+		})
+		require.NoError(t, err)
+		require.Equal(t, 1, len(children))
+		assert.Equal(t, parent.UID, children[0].UID)
+
+		// Service account should be able to list k6 folder
+		children, err = folderStore.GetChildren(context.Background(), folder.GetChildrenQuery{
+			OrgID:        orgID,
+			SignedInUser: &user.SignedInUser{UserID: 2, OrgID: orgID, IsServiceAccount: true},
+		})
+		require.NoError(t, err)
+		require.Equal(t, 2, len(children))
+		childrenUIDs := make([]string, 0, len(children))
+		for _, child := range children {
+			childrenUIDs = append(childrenUIDs, child.UID)
+		}
+		assert.EqualValues(t, []string{parent.UID, accesscontrol.K6FolderUID}, childrenUIDs)
+	})
+
+	t.Run("pagination works if k6-app folder is hidden", func(t *testing.T) {
+		for i := 0; i < 4; i++ {
+			_, err = folderStore.Create(context.Background(), folder.CreateFolderCommand{
+				Title: fmt.Sprintf("root-%d", i),
+				OrgID: orgID,
+				UID:   fmt.Sprintf("root-%d", i),
+			})
+			require.NoError(t, err)
+		}
+
+		// Should skip k6-app folder but get parent folder and two more folders
+		children, err := folderStore.GetChildren(context.Background(), folder.GetChildrenQuery{
+			OrgID:        orgID,
+			SignedInUser: usr,
+			Limit:        3,
+		})
+		require.NoError(t, err)
+		require.Equal(t, 3, len(children))
+		assert.EqualValues(t, []string{parent.UID, "root-0", "root-1"}, []string{children[0].UID, children[1].UID, children[2].UID})
+
+		// Should get the two remaining folders
+		children, err = folderStore.GetChildren(context.Background(), folder.GetChildrenQuery{
+			OrgID:        orgID,
+			SignedInUser: usr,
+			Page:         2,
+			Limit:        3,
+		})
+		require.NoError(t, err)
+		require.Equal(t, 2, len(children))
+		assert.EqualValues(t, []string{"root-2", "root-3"}, []string{children[0].UID, children[1].UID})
+	})
 }
 
 func TestIntegrationGetHeight(t *testing.T) {
@@ -736,10 +822,10 @@ func TestIntegrationGetHeight(t *testing.T) {
 		t.Skip("skipping integration test")
 	}
 
-	db := sqlstore.InitTestDB(t)
-	folderStore := ProvideStore(db, db.Cfg)
+	db, cfg := sqlstore.InitTestDB(t)
+	folderStore := ProvideStore(db)
 
-	orgID := CreateOrg(t, db)
+	orgID := CreateOrg(t, db, cfg)
 
 	// create folder
 	uid1 := util.GenerateShortUID()
@@ -769,10 +855,10 @@ func TestIntegrationGetFolders(t *testing.T) {
 	}
 
 	foldersNum := 10
-	db := sqlstore.InitTestDB(t)
-	folderStore := ProvideStore(db, db.Cfg)
+	db, cfg := sqlstore.InitTestDB(t)
+	folderStore := ProvideStore(db)
 
-	orgID := CreateOrg(t, db)
+	orgID := CreateOrg(t, db, cfg)
 
 	// create folders
 	uids := make([]string, 0)
@@ -799,7 +885,7 @@ func TestIntegrationGetFolders(t *testing.T) {
 	})
 
 	t.Run("get folders by UIDs should succeed", func(t *testing.T) {
-		actualFolders, err := folderStore.GetFolders(context.Background(), NewGetFoldersQuery(folder.GetFoldersQuery{OrgID: orgID, UIDs: uids[1:]}))
+		actualFolders, err := folderStore.GetFolders(context.Background(), folder.NewGetFoldersQuery(folder.GetFoldersQuery{OrgID: orgID, UIDs: uids[1:]}))
 		require.NoError(t, err)
 		assert.Equal(t, len(uids[1:]), len(actualFolders))
 		for _, f := range folders[1:] {
@@ -819,7 +905,7 @@ func TestIntegrationGetFolders(t *testing.T) {
 	})
 
 	t.Run("get folders by UIDs batching should work as expected", func(t *testing.T) {
-		q := NewGetFoldersQuery(folder.GetFoldersQuery{OrgID: orgID, UIDs: uids[1:], BatchSize: 3})
+		q := folder.NewGetFoldersQuery(folder.GetFoldersQuery{OrgID: orgID, UIDs: uids[1:], BatchSize: 3})
 		actualFolders, err := folderStore.GetFolders(context.Background(), q)
 		require.NoError(t, err)
 		assert.Equal(t, len(uids[1:]), len(actualFolders))
@@ -840,7 +926,7 @@ func TestIntegrationGetFolders(t *testing.T) {
 	})
 
 	t.Run("get folders by UIDs with fullpath should succeed", func(t *testing.T) {
-		q := NewGetFoldersQuery(folder.GetFoldersQuery{OrgID: orgID, UIDs: uids[1:], WithFullpath: true})
+		q := folder.NewGetFoldersQuery(folder.GetFoldersQuery{OrgID: orgID, UIDs: uids[1:], WithFullpath: true})
 		q.BatchSize = 3
 		actualFolders, err := folderStore.GetFolders(context.Background(), q)
 		require.NoError(t, err)
@@ -863,12 +949,12 @@ func TestIntegrationGetFolders(t *testing.T) {
 	})
 
 	t.Run("get folders by UIDs and ancestor UIDs should work as expected", func(t *testing.T) {
-		q := NewGetFoldersQuery(folder.GetFoldersQuery{OrgID: orgID, UIDs: uids[1:], BatchSize: 3})
-		q.ancestorUIDs = make([]string, 0, int(q.BatchSize)+1)
+		q := folder.NewGetFoldersQuery(folder.GetFoldersQuery{OrgID: orgID, UIDs: uids[1:], BatchSize: 3})
+		q.AncestorUIDs = make([]string, 0, int(q.BatchSize)+1)
 		for i := 0; i < int(q.BatchSize); i++ {
-			q.ancestorUIDs = append(q.ancestorUIDs, uuid.New().String())
+			q.AncestorUIDs = append(q.AncestorUIDs, uuid.New().String())
 		}
-		q.ancestorUIDs = append(q.ancestorUIDs, folders[len(folders)-1].UID)
+		q.AncestorUIDs = append(q.AncestorUIDs, folders[len(folders)-1].UID)
 
 		actualFolders, err := folderStore.GetFolders(context.Background(), q)
 		require.NoError(t, err)
@@ -886,22 +972,26 @@ func TestIntegrationGetFolders(t *testing.T) {
 	})
 }
 
-func CreateOrg(t *testing.T, db *sqlstore.SQLStore) int64 {
+func CreateOrg(t *testing.T, db db.DB, cfg *setting.Cfg) int64 {
 	t.Helper()
 
-	orgService, err := orgimpl.ProvideService(db, db.Cfg, quotatest.New(false, nil))
+	orgService, err := orgimpl.ProvideService(db, cfg, quotatest.New(false, nil))
+	require.NoError(t, err)
+	dashSvc := &dashboards.FakeDashboardService{}
+	dashSvc.On("DeleteAllDashboards", mock.Anything, mock.Anything).Return(nil)
+	deleteOrgService, err := orgimpl.ProvideDeletionService(db, cfg, dashSvc)
 	require.NoError(t, err)
 	orgID, err := orgService.GetOrCreate(context.Background(), "test-org")
 	require.NoError(t, err)
 	t.Cleanup(func() {
-		err = orgService.Delete(context.Background(), &org.DeleteOrgCommand{ID: orgID})
+		err = deleteOrgService.Delete(context.Background(), &org.DeleteOrgCommand{ID: orgID})
 		require.NoError(t, err)
 	})
 
 	return orgID
 }
 
-func CreateSubtree(t *testing.T, store *sqlStore, orgID int64, parentUID string, depth int, prefix string) []string {
+func CreateSubtree(t *testing.T, store *FolderStoreImpl, orgID int64, parentUID string, depth int, prefix string) []string {
 	t.Helper()
 
 	ancestorUIDs := []string{}
@@ -940,7 +1030,7 @@ func CreateSubtree(t *testing.T, store *sqlStore, orgID int64, parentUID string,
 	return ancestorUIDs
 }
 
-func CreateLeaves(t *testing.T, store *sqlStore, parent *folder.Folder, num int) []string {
+func CreateLeaves(t *testing.T, store *FolderStoreImpl, parent *folder.Folder, num int) []string {
 	t.Helper()
 
 	leaves := make([]string, 0)
@@ -958,7 +1048,7 @@ func CreateLeaves(t *testing.T, store *sqlStore, parent *folder.Folder, num int)
 	return leaves
 }
 
-func assertAncestorUIDs(t *testing.T, store *sqlStore, f *folder.Folder, expected []string) {
+func assertAncestorUIDs(t *testing.T, store *FolderStoreImpl, f *folder.Folder, expected []string) {
 	t.Helper()
 
 	ancestors, err := store.GetParents(context.Background(), folder.GetParentsQuery{
@@ -973,7 +1063,7 @@ func assertAncestorUIDs(t *testing.T, store *sqlStore, f *folder.Folder, expecte
 	assert.Equal(t, expected, actualAncestorsUIDs)
 }
 
-func assertChildrenUIDs(t *testing.T, store *sqlStore, f *folder.Folder, expected []string) {
+func assertChildrenUIDs(t *testing.T, store *FolderStoreImpl, f *folder.Folder, expected []string) {
 	t.Helper()
 
 	ancestors, err := store.GetChildren(context.Background(), folder.GetChildrenQuery{
