@@ -3,7 +3,7 @@ package livecontext
 import (
 	"context"
 
-	"github.com/grafana/grafana/pkg/services/auth/identity"
+	"github.com/grafana/grafana/pkg/apimachinery/identity"
 )
 
 type signedUserContextKeyType int
