@@ -27,6 +27,7 @@ type UserAuth struct {
 
 type ExternalUserInfo struct {
 	OAuthToken     *oauth2.Token
+	SAMLSession    *SAMLSession
 	AuthModule     string
 	AuthId         string
 	UserId         int64
@@ -40,6 +41,11 @@ type ExternalUserInfo struct {
 	SkipTeamSync   bool
 }
 
+type SAMLSession struct {
+	NameID       string
+	SessionIndex string
+}
+
 func (e *ExternalUserInfo) String() string {
 	isGrafanaAdmin := "nil"
 	if e.IsGrafanaAdmin != nil {
@@ -104,9 +110,8 @@ type GetUserByAuthInfoQuery struct {
 
 type UserLookupParams struct {
 	// Describes lookup order as well
-	UserID *int64  // if set, will try to find the user by id
-	Email  *string // if set, will try to find the user by email
-	Login  *string // if set, will try to find the user by login
+	Email *string // if set, will try to find the user by email
+	Login *string // if set, will try to find the user by login
 }
 
 type GetAuthInfoQuery struct {
