@@ -2,12 +2,13 @@ package accesscontrol
 
 import (
 	"fmt"
+	"slices"
 
 	"golang.org/x/net/context"
 
+	"github.com/grafana/grafana/pkg/apimachinery/identity"
 	"github.com/grafana/grafana/pkg/expr"
 	"github.com/grafana/grafana/pkg/services/accesscontrol"
-	"github.com/grafana/grafana/pkg/services/auth/identity"
 	"github.com/grafana/grafana/pkg/services/dashboards"
 	"github.com/grafana/grafana/pkg/services/datasources"
 	"github.com/grafana/grafana/pkg/services/ngalert/models"
@@ -22,32 +23,21 @@ const (
 )
 
 type RuleService struct {
-	ac accesscontrol.AccessControl
+	genericService
+	notificationSettingsAuth notificationSettingsAuth
+}
+
+type notificationSettingsAuth interface {
+	AuthorizeRead(context.Context, identity.Requester, *models.NotificationSettings) error
 }
 
 func NewRuleService(ac accesscontrol.AccessControl) *RuleService {
 	return &RuleService{
-		ac: ac,
+		genericService:           genericService{ac: ac},
+		notificationSettingsAuth: NewReceiverAccess[*models.NotificationSettings](ac, true),
 	}
 }
 
-// HasAccess returns true if the identity.Requester has all permissions specified by the evaluator. Returns error if access control backend could not evaluate permissions
-func (r *RuleService) HasAccess(ctx context.Context, user identity.Requester, evaluator accesscontrol.Evaluator) (bool, error) {
-	return r.ac.Evaluate(ctx, user, evaluator)
-}
-
-// HasAccessOrError returns nil if the identity.Requester has enough permissions to pass the accesscontrol.Evaluator. Otherwise, returns authorization error that contains action that was performed
-func (r *RuleService) HasAccessOrError(ctx context.Context, user identity.Requester, evaluator accesscontrol.Evaluator, action func() string) error {
-	has, err := r.HasAccess(ctx, user, evaluator)
-	if err != nil {
-		return err
-	}
-	if !has {
-		return NewAuthorizationErrorWithPermissions(action(), evaluator)
-	}
-	return nil
-}
-
 // getReadFolderAccessEvaluator constructs accesscontrol.Evaluator that checks all permissions required to read rules in  specific folder
 func getReadFolderAccessEvaluator(folderUID string) accesscontrol.Evaluator {
 	return accesscontrol.EvalAll(
@@ -67,8 +57,7 @@ func (r *RuleService) getRulesReadEvaluator(rules ...*models.AlertRule) accessco
 		added[rule.NamespaceUID] = struct{}{}
 		evals = append(evals, getReadFolderAccessEvaluator(rule.NamespaceUID))
 	}
-	dsEvals := r.getRulesQueryEvaluator(rules...)
-	return accesscontrol.EvalAll(append(evals, dsEvals)...)
+	return accesscontrol.EvalAll(evals...)
 }
 
 // getRulesQueryEvaluator constructs accesscontrol.Evaluator that checks all permissions to query data sources used by the provided rules
@@ -94,6 +83,14 @@ func (r *RuleService) getRulesQueryEvaluator(rules ...*models.AlertRule) accessc
 	return accesscontrol.EvalAll(evals...)
 }
 
+// CanReadAllRules returns true when user has access to all folders and can read rules in them.
+func (r *RuleService) CanReadAllRules(ctx context.Context, user identity.Requester) (bool, error) {
+	return r.HasAccess(ctx, user, accesscontrol.EvalAll(
+		accesscontrol.EvalPermission(ruleRead, dashboards.ScopeFoldersProvider.GetResourceAllScope()),
+		accesscontrol.EvalPermission(dashboards.ActionFoldersRead, dashboards.ScopeFoldersProvider.GetResourceAllScope()),
+	))
+}
+
 // AuthorizeDatasourceAccessForRule checks that user has access to all data sources declared by the rule
 func (r *RuleService) AuthorizeDatasourceAccessForRule(ctx context.Context, user identity.Requester, rule *models.AlertRule) error {
 	ds := r.getRulesQueryEvaluator(rule)
@@ -106,10 +103,17 @@ func (r *RuleService) AuthorizeDatasourceAccessForRule(ctx context.Context, user
 	})
 }
 
-// AuthorizeAccessToRuleGroup checks that the identity.Requester has permissions to all rules, which means that it has permissions to:
+// AuthorizeDatasourceAccessForRuleGroup checks that user has access to all data sources declared by the rules in the group
+func (r *RuleService) AuthorizeDatasourceAccessForRuleGroup(ctx context.Context, user identity.Requester, rules models.RulesGroup) error {
+	ds := r.getRulesQueryEvaluator(rules...)
+	return r.HasAccessOrError(ctx, user, ds, func() string {
+		return fmt.Sprintf("access data sources for the rule group '%s'", rules[0].RuleGroup)
+	})
+}
+
+// HasAccessToRuleGroup checks that the identity.Requester has permissions to all rules, which means that it has permissions to:
 // - ("folders:read") read folders which contain the rules
 // - ("alert.rules:read") read alert rules in the folders
-// - ("datasources:query") query all data sources that rules refer to
 // Returns false if the requester does not have enough permissions, and error if something went wrong during the permission evaluation.
 func (r *RuleService) HasAccessToRuleGroup(ctx context.Context, user identity.Requester, rules models.RulesGroup) (bool, error) {
 	eval := r.getRulesReadEvaluator(rules...)
@@ -119,8 +123,7 @@ func (r *RuleService) HasAccessToRuleGroup(ctx context.Context, user identity.Re
 // AuthorizeAccessToRuleGroup checks that the identity.Requester has permissions to all rules, which means that it has permissions to:
 // - ("folders:read") read folders which contain the rules
 // - ("alert.rules:read") read alert rules in the folders
-// - ("datasources:query") query all data sources that rules refer to
-// Returns error if at least one permissions is missing or if something went wrong during the permission evaluation
+// Returns error if at least one permission is missing or if something went wrong during the permission evaluation
 func (r *RuleService) AuthorizeAccessToRuleGroup(ctx context.Context, user identity.Requester, rules models.RulesGroup) error {
 	eval := r.getRulesReadEvaluator(rules...)
 	return r.HasAccessOrError(ctx, user, eval, func() string {
@@ -133,6 +136,28 @@ func (r *RuleService) AuthorizeAccessToRuleGroup(ctx context.Context, user ident
 	})
 }
 
+// HasAccessInFolder checks that the identity.Requester has permissions to read alert rules in the given folder,
+// which requires the following permissions:
+// - ("folders:read") read the folder
+// - ("alert.rules:read") read alert rules in the folder
+// Returns false if the requester does not have enough permissions, and error if something went wrong during the permission evaluation.
+func (r *RuleService) HasAccessInFolder(ctx context.Context, user identity.Requester, rule models.Namespaced) (bool, error) {
+	eval := accesscontrol.EvalAll(getReadFolderAccessEvaluator(rule.GetNamespaceUID()))
+	return r.HasAccess(ctx, user, eval)
+}
+
+// AuthorizeAccessInFolder checks that the identity.Requester has permissions to read alert rules in the given folder,
+// which requires the following permissions:
+// - ("folders:read") read the folder
+// - ("alert.rules:read") read alert rules in the folder
+// Returns error if at least one permission is missing or if something went wrong during the permission evaluation
+func (r *RuleService) AuthorizeAccessInFolder(ctx context.Context, user identity.Requester, rule models.Namespaced) error {
+	eval := accesscontrol.EvalAll(getReadFolderAccessEvaluator(rule.GetNamespaceUID()))
+	return r.HasAccessOrError(ctx, user, eval, func() string {
+		return fmt.Sprintf("access rules in folder '%s'", rule.GetNamespaceUID())
+	})
+}
+
 // AuthorizeRuleChanges analyzes changes in the rule group, and checks whether the changes are authorized.
 // NOTE: if there are rules for deletion, and the user does not have access to data sources that a rule uses, the rule is removed from the list.
 // If the user is not authorized to perform the changes the function returns ErrAuthorization with a description of what action is not authorized.
@@ -178,6 +203,10 @@ func (r *RuleService) AuthorizeRuleChanges(ctx context.Context, user identity.Re
 			}); err != nil {
 				return err
 			}
+
+			if err := r.authorizeNotificationSettings(ctx, user, rule); err != nil {
+				return err
+			}
 		}
 		if !existingGroup {
 			// create a new group, check that user has "read" access to that new group. Otherwise, it will not be able to read it back.
@@ -220,19 +249,23 @@ func (r *RuleService) AuthorizeRuleChanges(ctx context.Context, user identity.Re
 			updateAuthorized = true
 		}
 
-		if rule.Existing.NamespaceUID != rule.New.NamespaceUID || rule.Existing.RuleGroup != rule.New.RuleGroup {
-			key := rule.Existing.GetGroupKey()
-			rules, existingGroup = change.AffectedGroups[key]
-			if !existingGroup {
-				// add a safeguard in the case of inconsistency. If user hit this then there is a bug in the calculating of changes struct
-				return fmt.Errorf("failed to authorize moving an alert rule %s between groups because unable to check access to group %s from which the rule is moved", rule.Existing.UID, rule.Existing.RuleGroup)
-			}
-			if err := r.HasAccessOrError(ctx, user, r.getRulesQueryEvaluator(rules...), func() string {
-				return fmt.Sprintf("move rule %s between two different groups because user does not have access to the source group %s", rule.Existing.UID, rule.Existing.RuleGroup)
-			}); err != nil {
+		if !slices.EqualFunc(rule.Existing.NotificationSettings, rule.New.NotificationSettings, func(settings models.NotificationSettings, settings2 models.NotificationSettings) bool {
+			return settings.Equals(&settings2)
+		}) {
+			if err := r.authorizeNotificationSettings(ctx, user, rule.New); err != nil {
 				return err
 			}
 		}
 	}
 	return nil
 }
+
+// authorizeNotificationSettings checks if the user has access to all receivers that are used by the rule's notification settings.
+func (r *RuleService) authorizeNotificationSettings(ctx context.Context, user identity.Requester, rule *models.AlertRule) error {
+	for _, ns := range rule.NotificationSettings {
+		if err := r.notificationSettingsAuth.AuthorizeRead(ctx, user, &ns); err != nil {
+			return err
+		}
+	}
+	return nil
+}
