@@ -33,7 +33,6 @@ import (
 	"github.com/grafana/grafana/pkg/services/ngalert/tests/fakes"
 	"github.com/grafana/grafana/pkg/services/user"
 	"github.com/grafana/grafana/pkg/setting"
-	"github.com/grafana/grafana/pkg/util"
 	"github.com/grafana/grafana/pkg/util/cmputil"
 	"github.com/grafana/grafana/pkg/web"
 )
@@ -67,12 +66,13 @@ func TestRouteDeleteAlertRules(t *testing.T) {
 
 	orgID := rand.Int63()
 	folder := randFolder()
+	gen := models.RuleGen.With(models.RuleGen.WithOrgID(orgID))
 
 	initFakeRuleStore := func(t *testing.T) *fakes.RuleStore {
 		ruleStore := fakes.NewRuleStore(t)
 		ruleStore.Folders[orgID] = append(ruleStore.Folders[orgID], folder)
 		// add random data
-		ruleStore.PutRule(context.Background(), models.GenerateAlertRulesSmallNonEmpty(models.AlertRuleGen(withOrgID(orgID)))...)
+		ruleStore.PutRule(context.Background(), gen.GenerateManyRef(1, 5)...)
 		return ruleStore
 	}
 
@@ -80,7 +80,7 @@ func TestRouteDeleteAlertRules(t *testing.T) {
 		t.Run("and group argument is empty", func(t *testing.T) {
 			t.Run("return Forbidden if user is not authorized to access any group in the folder", func(t *testing.T) {
 				ruleStore := initFakeRuleStore(t)
-				ruleStore.PutRule(context.Background(), models.GenerateAlertRulesSmallNonEmpty(models.AlertRuleGen(withOrgID(orgID), withNamespace(folder)))...)
+				ruleStore.PutRule(context.Background(), gen.With(gen.WithNamespace(folder)).GenerateManyRef(1, 5)...)
 
 				request := createRequestContextWithPerms(orgID, map[int64]map[string][]string{}, nil)
 
@@ -93,16 +93,20 @@ func TestRouteDeleteAlertRules(t *testing.T) {
 				ruleStore := initFakeRuleStore(t)
 				provisioningStore := fakes.NewFakeProvisioningStore()
 
-				authorizedRulesInFolder := models.GenerateAlertRulesSmallNonEmpty(models.AlertRuleGen(withOrgID(orgID), withNamespace(folder), withGroup("authz_"+util.GenerateShortUID())))
+				folderGen := gen.With(gen.WithNamespace(folder))
 
-				provisionedRulesInFolder := models.GenerateAlertRulesSmallNonEmpty(models.AlertRuleGen(withOrgID(orgID), withNamespace(folder), withGroup("provisioned_"+util.GenerateShortUID())))
-				err := provisioningStore.SetProvenance(context.Background(), provisionedRulesInFolder[0], orgID, models.ProvenanceAPI)
-				require.NoError(t, err)
+				authorizedRulesInFolder := folderGen.With(gen.WithGroupPrefix("authz-")).GenerateManyRef(1, 5)
+
+				provisionedRulesInFolder := folderGen.With(gen.WithGroupPrefix("provisioned-")).GenerateManyRef(1, 5)
+				for _, rule := range provisionedRulesInFolder {
+					err := provisioningStore.SetProvenance(context.Background(), rule, orgID, models.ProvenanceAPI)
+					require.NoError(t, err)
+				}
 
 				ruleStore.PutRule(context.Background(), authorizedRulesInFolder...)
 				ruleStore.PutRule(context.Background(), provisionedRulesInFolder...)
 				// more rules in the same namespace but user does not have access to them
-				ruleStore.PutRule(context.Background(), models.GenerateAlertRulesSmallNonEmpty(models.AlertRuleGen(withOrgID(orgID), withNamespace(folder), withGroup("unauthz"+util.GenerateShortUID())))...)
+				ruleStore.PutRule(context.Background(), folderGen.With(gen.WithGroupPrefix("unauthz")).GenerateManyRef(1, 5)...)
 
 				permissions := createPermissionsForRules(append(authorizedRulesInFolder, provisionedRulesInFolder...), orgID)
 				requestCtx := createRequestContextWithPerms(orgID, permissions, nil)
@@ -116,13 +120,15 @@ func TestRouteDeleteAlertRules(t *testing.T) {
 				ruleStore := initFakeRuleStore(t)
 				provisioningStore := fakes.NewFakeProvisioningStore()
 
-				provisionedRulesInFolder := models.GenerateAlertRulesSmallNonEmpty(models.AlertRuleGen(withOrgID(orgID), withNamespace(folder), withGroup(util.GenerateShortUID())))
+				folderGen := gen.With(gen.WithNamespace(folder))
+
+				provisionedRulesInFolder := folderGen.With(gen.WithSameGroup()).GenerateManyRef(1, 5)
 				err := provisioningStore.SetProvenance(context.Background(), provisionedRulesInFolder[0], orgID, models.ProvenanceAPI)
 				require.NoError(t, err)
 
 				ruleStore.PutRule(context.Background(), provisionedRulesInFolder...)
 				// more rules in the same namespace but user does not have access to them
-				ruleStore.PutRule(context.Background(), models.GenerateAlertRulesSmallNonEmpty(models.AlertRuleGen(withOrgID(orgID), withNamespace(folder), withGroup(util.GenerateShortUID())))...)
+				ruleStore.PutRule(context.Background(), folderGen.With(gen.WithSameGroup()).GenerateManyRef(1, 5)...)
 
 				permissions := createPermissionsForRules(provisionedRulesInFolder, orgID)
 				requestCtx := createRequestContextWithPerms(orgID, permissions, nil)
@@ -143,19 +149,20 @@ func TestRouteDeleteAlertRules(t *testing.T) {
 			})
 		})
 		t.Run("and group argument is not empty", func(t *testing.T) {
-			groupName := util.GenerateShortUID()
 			t.Run("return Forbidden if user is not authorized to access the group", func(t *testing.T) {
 				ruleStore := initFakeRuleStore(t)
 
-				authorizedRulesInGroup := models.GenerateAlertRulesSmallNonEmpty(models.AlertRuleGen(withOrgID(orgID), withNamespace(folder), withGroup(groupName)))
+				groupGen := gen.With(gen.WithNamespace(folder), gen.WithSameGroup())
+
+				authorizedRulesInGroup := groupGen.GenerateManyRef(1, 5)
 				ruleStore.PutRule(context.Background(), authorizedRulesInGroup...)
 				// more rules in the same group but user is not authorized to access them
-				ruleStore.PutRule(context.Background(), models.GenerateAlertRulesSmallNonEmpty(models.AlertRuleGen(withOrgID(orgID), withNamespace(folder), withGroup(groupName)))...)
+				ruleStore.PutRule(context.Background(), groupGen.GenerateManyRef(1, 5)...)
 
 				permissions := createPermissionsForRules(authorizedRulesInGroup, orgID)
 				requestCtx := createRequestContextWithPerms(orgID, permissions, nil)
 
-				response := createService(ruleStore).RouteDeleteAlertRules(requestCtx, folder.UID, groupName)
+				response := createService(ruleStore).RouteDeleteAlertRules(requestCtx, folder.UID, authorizedRulesInGroup[0].RuleGroup)
 
 				require.Equalf(t, http.StatusForbidden, response.Status(), "Expected 403 but got %d: %v", response.Status(), string(response.Body()))
 				deleteCommands := getRecordedCommand(ruleStore)
@@ -165,7 +172,9 @@ func TestRouteDeleteAlertRules(t *testing.T) {
 				ruleStore := initFakeRuleStore(t)
 				provisioningStore := fakes.NewFakeProvisioningStore()
 
-				provisionedRulesInFolder := models.GenerateAlertRulesSmallNonEmpty(models.AlertRuleGen(withOrgID(orgID), withNamespace(folder), withGroup(groupName)))
+				groupGen := gen.With(gen.WithNamespace(folder), gen.WithSameGroup())
+
+				provisionedRulesInFolder := groupGen.GenerateManyRef(1, 5)
 				err := provisioningStore.SetProvenance(context.Background(), provisionedRulesInFolder[0], orgID, models.ProvenanceAPI)
 				require.NoError(t, err)
 
@@ -174,7 +183,7 @@ func TestRouteDeleteAlertRules(t *testing.T) {
 				permissions := createPermissionsForRules(provisionedRulesInFolder, orgID)
 				requestCtx := createRequestContextWithPerms(orgID, permissions, nil)
 
-				response := createServiceWithProvenanceStore(ruleStore, provisioningStore).RouteDeleteAlertRules(requestCtx, folder.UID, groupName)
+				response := createServiceWithProvenanceStore(ruleStore, provisioningStore).RouteDeleteAlertRules(requestCtx, folder.UID, provisionedRulesInFolder[0].RuleGroup)
 
 				require.Equalf(t, 400, response.Status(), "Expected 400 but got %d: %v", response.Status(), string(response.Body()))
 				deleteCommands := getRecordedCommand(ruleStore)
@@ -185,17 +194,24 @@ func TestRouteDeleteAlertRules(t *testing.T) {
 }
 
 func TestRouteGetNamespaceRulesConfig(t *testing.T) {
+	gen := models.RuleGen
 	t.Run("fine-grained access is enabled", func(t *testing.T) {
-		t.Run("should return rules for which user has access to data source", func(t *testing.T) {
+		t.Run("should return all rules, with or without data source access", func(t *testing.T) {
 			orgID := rand.Int63()
 			folder := randFolder()
 			ruleStore := fakes.NewRuleStore(t)
 			ruleStore.Folders[orgID] = append(ruleStore.Folders[orgID], folder)
-			expectedRules := models.GenerateAlertRules(rand.Intn(4)+2, models.AlertRuleGen(withOrgID(orgID), withNamespace(folder)))
-			ruleStore.PutRule(context.Background(), expectedRules...)
-			ruleStore.PutRule(context.Background(), models.GenerateAlertRules(rand.Intn(4)+2, models.AlertRuleGen(withOrgID(orgID), withNamespace(folder)))...)
+			folderGen := gen.With(gen.WithOrgID(orgID), gen.WithNamespace(folder))
+			queryAccessRules := folderGen.GenerateManyRef(2, 6)
+			ruleStore.PutRule(context.Background(), queryAccessRules...)
+			noQueryAccessRules := folderGen.GenerateManyRef(2, 6)
+			ruleStore.PutRule(context.Background(), noQueryAccessRules...)
 
-			permissions := createPermissionsForRules(expectedRules, orgID)
+			allRules := make([]*models.AlertRule, 0, len(queryAccessRules)+len(noQueryAccessRules))
+			allRules = append(allRules, queryAccessRules...)
+			allRules = append(allRules, noQueryAccessRules...)
+
+			permissions := createPermissionsForRules(queryAccessRules, orgID)
 			req := createRequestContextWithPerms(orgID, permissions, nil)
 
 			response := createService(ruleStore).RouteGetNamespaceRulesConfig(req, folder.UID)
@@ -209,9 +225,9 @@ func TestRouteGetNamespaceRulesConfig(t *testing.T) {
 				for _, group := range groups {
 				grouploop:
 					for _, actualRule := range group.Rules {
-						for i, expected := range expectedRules {
+						for i, expected := range allRules {
 							if actualRule.GrafanaManagedAlert.UID == expected.UID {
-								expectedRules = append(expectedRules[:i], expectedRules[i+1:]...)
+								allRules = append(allRules[:i], allRules[i+1:]...)
 								continue grouploop
 							}
 						}
@@ -219,7 +235,7 @@ func TestRouteGetNamespaceRulesConfig(t *testing.T) {
 					}
 				}
 			}
-			assert.Emptyf(t, expectedRules, "not all expected rules were returned")
+			assert.Emptyf(t, allRules, "not all expected rules were returned")
 		})
 	})
 	t.Run("should return the provenance of the alert rules", func(t *testing.T) {
@@ -227,7 +243,7 @@ func TestRouteGetNamespaceRulesConfig(t *testing.T) {
 		folder := randFolder()
 		ruleStore := fakes.NewRuleStore(t)
 		ruleStore.Folders[orgID] = append(ruleStore.Folders[orgID], folder)
-		expectedRules := models.GenerateAlertRules(rand.Intn(4)+2, models.AlertRuleGen(withOrgID(orgID), withNamespace(folder)))
+		expectedRules := gen.With(gen.WithOrgID(orgID), gen.WithNamespace(folder)).GenerateManyRef(2, 6)
 		ruleStore.PutRule(context.Background(), expectedRules...)
 
 		svc := createService(ruleStore)
@@ -271,7 +287,7 @@ func TestRouteGetNamespaceRulesConfig(t *testing.T) {
 		groupKey := models.GenerateGroupKey(orgID)
 		groupKey.NamespaceUID = folder.UID
 
-		expectedRules := models.GenerateAlertRules(rand.Intn(5)+5, models.AlertRuleGen(withGroupKey(groupKey), models.WithUniqueGroupIndex()))
+		expectedRules := gen.With(gen.WithGroupKey(groupKey), gen.WithUniqueGroupIndex()).GenerateManyRef(5, 10)
 		ruleStore.PutRule(context.Background(), expectedRules...)
 
 		perms := createPermissionsForRules(expectedRules, orgID)
@@ -307,7 +323,65 @@ func TestRouteGetNamespaceRulesConfig(t *testing.T) {
 	})
 }
 
+func TestRouteGetRuleByUID(t *testing.T) {
+	t.Run("rule is successfully fetched with the correct UID", func(t *testing.T) {
+		orgID := rand.Int63()
+		folder := randFolder()
+		ruleStore := fakes.NewRuleStore(t)
+		ruleStore.Folders[orgID] = append(ruleStore.Folders[orgID], folder)
+		groupKey := models.GenerateGroupKey(orgID)
+		groupKey.NamespaceUID = folder.UID
+		gen := models.RuleGen.With(models.RuleGen.WithGroupKey(groupKey))
+
+		createdRules := gen.With(
+			gen.WithUniqueGroupIndex(), gen.WithUniqueID(),
+			gen.WithEditorSettingsSimplifiedQueryAndExpressionsSection(true),
+			gen.WithEditorSettingsSimplifiedNotificationsSection(true),
+		).GenerateManyRef(3)
+		require.Len(t, createdRules, 3)
+		ruleStore.PutRule(context.Background(), createdRules...)
+
+		perms := createPermissionsForRules(createdRules, orgID)
+		req := createRequestContextWithPerms(orgID, perms, nil)
+
+		expectedRule := createdRules[1]
+		response := createService(ruleStore).RouteGetRuleByUID(req, expectedRule.UID)
+
+		require.Equal(t, http.StatusOK, response.Status())
+		result := &apimodels.GettableExtendedRuleNode{}
+		require.NoError(t, json.Unmarshal(response.Body(), result))
+		require.NotNil(t, result)
+
+		require.Equal(t, expectedRule.UID, result.GrafanaManagedAlert.UID)
+		require.Equal(t, expectedRule.RuleGroup, result.GrafanaManagedAlert.RuleGroup)
+		require.Equal(t, expectedRule.Title, result.GrafanaManagedAlert.Title)
+		require.True(t, result.GrafanaManagedAlert.Metadata.EditorSettings.SimplifiedQueryAndExpressionsSection)
+		require.True(t, result.GrafanaManagedAlert.Metadata.EditorSettings.SimplifiedNotificationsSection)
+	})
+
+	t.Run("error when fetching rule with non-existent UID", func(t *testing.T) {
+		orgID := rand.Int63()
+		folder := randFolder()
+		ruleStore := fakes.NewRuleStore(t)
+		ruleStore.Folders[orgID] = append(ruleStore.Folders[orgID], folder)
+		groupKey := models.GenerateGroupKey(orgID)
+		groupKey.NamespaceUID = folder.UID
+		gen := models.RuleGen.With(models.RuleGen.WithGroupKey(groupKey))
+
+		createdRules := gen.With(gen.WithUniqueGroupIndex(), gen.WithUniqueID()).GenerateManyRef(3)
+		require.Len(t, createdRules, 3)
+		ruleStore.PutRule(context.Background(), createdRules...)
+
+		perms := createPermissionsForRules(createdRules, orgID)
+		req := createRequestContextWithPerms(orgID, perms, nil)
+		response := createService(ruleStore).RouteGetRuleByUID(req, "foobar")
+
+		require.Equal(t, http.StatusNotFound, response.Status())
+	})
+}
+
 func TestRouteGetRulesConfig(t *testing.T) {
+	gen := models.RuleGen
 	t.Run("fine-grained access is enabled", func(t *testing.T) {
 		t.Run("should check access to data source", func(t *testing.T) {
 			orgID := rand.Int63()
@@ -321,8 +395,8 @@ func TestRouteGetRulesConfig(t *testing.T) {
 			group2Key := models.GenerateGroupKey(orgID)
 			group2Key.NamespaceUID = folder2.UID
 
-			group1 := models.GenerateAlertRules(rand.Intn(4)+2, models.AlertRuleGen(withGroupKey(group1Key)))
-			group2 := models.GenerateAlertRules(rand.Intn(4)+2, models.AlertRuleGen(withGroupKey(group2Key)))
+			group1 := gen.With(gen.WithGroupKey(group1Key)).GenerateManyRef(2, 6)
+			group2 := gen.With(gen.WithGroupKey(group2Key)).GenerateManyRef(2, 6)
 			ruleStore.PutRule(context.Background(), append(group1, group2...)...)
 
 			t.Run("and do not return group if user does not have access to one of rules", func(t *testing.T) {
@@ -355,7 +429,7 @@ func TestRouteGetRulesConfig(t *testing.T) {
 		groupKey := models.GenerateGroupKey(orgID)
 		groupKey.NamespaceUID = folder.UID
 
-		expectedRules := models.GenerateAlertRules(rand.Intn(5)+5, models.AlertRuleGen(withGroupKey(groupKey), models.WithUniqueGroupIndex()))
+		expectedRules := gen.With(gen.WithGroupKey(groupKey), gen.WithUniqueGroupIndex()).GenerateManyRef(5, 10)
 		ruleStore.PutRule(context.Background(), expectedRules...)
 
 		perms := createPermissionsForRules(expectedRules, orgID)
@@ -392,45 +466,7 @@ func TestRouteGetRulesConfig(t *testing.T) {
 }
 
 func TestRouteGetRulesGroupConfig(t *testing.T) {
-	t.Run("fine-grained access is enabled", func(t *testing.T) {
-		t.Run("should check access to data source", func(t *testing.T) {
-			orgID := rand.Int63()
-			folder := randFolder()
-			ruleStore := fakes.NewRuleStore(t)
-			ruleStore.Folders[orgID] = append(ruleStore.Folders[orgID], folder)
-			groupKey := models.GenerateGroupKey(orgID)
-			groupKey.NamespaceUID = folder.UID
-
-			expectedRules := models.GenerateAlertRules(rand.Intn(4)+2, models.AlertRuleGen(withGroupKey(groupKey)))
-			ruleStore.PutRule(context.Background(), expectedRules...)
-
-			t.Run("and return Forbidden if user does not have access one of rules", func(t *testing.T) {
-				permissions := createPermissionsForRules(expectedRules[1:], orgID)
-				request := createRequestContextWithPerms(orgID, permissions, map[string]string{
-					":Namespace": folder.UID,
-					":Groupname": groupKey.RuleGroup,
-				})
-				response := createService(ruleStore).RouteGetRulesGroupConfig(request, folder.UID, groupKey.RuleGroup)
-				require.Equal(t, http.StatusForbidden, response.Status())
-			})
-
-			t.Run("and return rules if user has access to all of them", func(t *testing.T) {
-				permissions := createPermissionsForRules(expectedRules, orgID)
-				request := createRequestContextWithPerms(orgID, permissions, map[string]string{
-					":Namespace": folder.UID,
-					":Groupname": groupKey.RuleGroup,
-				})
-				response := createService(ruleStore).RouteGetRulesGroupConfig(request, folder.UID, groupKey.RuleGroup)
-
-				require.Equal(t, http.StatusAccepted, response.Status())
-				result := &apimodels.RuleGroupConfigResponse{}
-				require.NoError(t, json.Unmarshal(response.Body(), result))
-				require.NotNil(t, result)
-				require.Len(t, result.Rules, len(expectedRules))
-			})
-		})
-	})
-
+	gen := models.RuleGen
 	t.Run("should return rules in group sorted by group index", func(t *testing.T) {
 		orgID := rand.Int63()
 		folder := randFolder()
@@ -439,7 +475,7 @@ func TestRouteGetRulesGroupConfig(t *testing.T) {
 		groupKey := models.GenerateGroupKey(orgID)
 		groupKey.NamespaceUID = folder.UID
 
-		expectedRules := models.GenerateAlertRules(rand.Intn(5)+5, models.AlertRuleGen(withGroupKey(groupKey), models.WithUniqueGroupIndex()))
+		expectedRules := gen.With(gen.WithGroupKey(groupKey), gen.WithUniqueGroupIndex()).GenerateManyRef(5, 10)
 		ruleStore.PutRule(context.Background(), expectedRules...)
 
 		perms := createPermissionsForRules(expectedRules, orgID)
@@ -475,14 +511,15 @@ func TestVerifyProvisionedRulesNotAffected(t *testing.T) {
 	orgID := rand.Int63()
 	group := models.GenerateGroupKey(orgID)
 	affectedGroups := make(map[models.AlertRuleGroupKey]models.RulesGroup)
+	gen := models.RuleGen
 	var allRules []*models.AlertRule
 	{
-		rules := models.GenerateAlertRules(rand.Intn(3)+1, models.AlertRuleGen(withGroupKey(group)))
+		rules := gen.With(gen.WithGroupKey(group)).GenerateManyRef(1, 4)
 		allRules = append(allRules, rules...)
 		affectedGroups[group] = rules
 		for i := 0; i < rand.Intn(3)+1; i++ {
 			g := models.GenerateGroupKey(orgID)
-			rules := models.GenerateAlertRules(rand.Intn(3)+1, models.AlertRuleGen(withGroupKey(g)))
+			rules := gen.With(gen.WithGroupKey(g)).GenerateManyRef(1, 4)
 			allRules = append(allRules, rules...)
 			affectedGroups[g] = rules
 		}
@@ -533,20 +570,15 @@ func TestVerifyProvisionedRulesNotAffected(t *testing.T) {
 }
 
 func TestValidateQueries(t *testing.T) {
+	gen := models.RuleGen
 	delta := store.GroupDelta{
 		New: []*models.AlertRule{
-			models.AlertRuleGen(func(rule *models.AlertRule) {
-				rule.Condition = "New"
-			})(),
+			gen.With(gen.WithCondition("New")).GenerateRef(),
 		},
 		Update: []store.RuleDelta{
 			{
-				Existing: models.AlertRuleGen(func(rule *models.AlertRule) {
-					rule.Condition = "Update_Existing"
-				})(),
-				New: models.AlertRuleGen(func(rule *models.AlertRule) {
-					rule.Condition = "Update_New"
-				})(),
+				Existing: gen.With(gen.WithCondition("New")).GenerateRef(),
+				New:      gen.With(gen.WithCondition("Update_New")).GenerateRef(),
 				Diff: cmputil.DiffReport{
 					cmputil.Diff{
 						Path: "SomeField",
@@ -554,12 +586,8 @@ func TestValidateQueries(t *testing.T) {
 				},
 			},
 			{
-				Existing: models.AlertRuleGen(func(rule *models.AlertRule) {
-					rule.Condition = "Update_Index_Existing"
-				})(),
-				New: models.AlertRuleGen(func(rule *models.AlertRule) {
-					rule.Condition = "Update_Index_New"
-				})(),
+				Existing: gen.With(gen.WithCondition("Update_Index_Existing")).GenerateRef(),
+				New:      gen.With(gen.WithCondition("Update_Index_New")).GenerateRef(),
 				Diff: cmputil.DiffReport{
 					cmputil.Diff{
 						Path: "RuleGroupIndex",
@@ -567,11 +595,7 @@ func TestValidateQueries(t *testing.T) {
 				},
 			},
 		},
-		Delete: []*models.AlertRule{
-			models.AlertRuleGen(func(rule *models.AlertRule) {
-				rule.Condition = "Deleted"
-			})(),
-		},
+		Delete: gen.With(gen.WithCondition("Deleted")).GenerateManyRef(1),
 	}
 
 	t.Run("should not validate deleted rules or updated rules with ignored fields", func(t *testing.T) {
@@ -631,10 +655,10 @@ func createService(store *fakes.RuleStore) *RulerSrv {
 		cfg: &setting.UnifiedAlertingSettings{
 			BaseInterval: 10 * time.Second,
 		},
-		authz:          accesscontrol.NewRuleService(acimpl.ProvideAccessControl(setting.NewCfg())),
+		authz:          accesscontrol.NewRuleService(acimpl.ProvideAccessControl(featuremgmt.WithFeatures())),
 		amConfigStore:  &fakeAMRefresher{},
 		amRefresher:    &fakeAMRefresher{},
-		featureManager: &featuremgmt.FeatureManager{},
+		featureManager: featuremgmt.WithFeatures(featuremgmt.FlagGrafanaManagedRecordingRules),
 	}
 }
 
@@ -694,29 +718,3 @@ func createPermissionsForRules(rules []*models.AlertRule, orgID int64) map[int64
 	}
 	return map[int64]map[string][]string{orgID: permissions}
 }
-
-func withOrgID(orgId int64) func(rule *models.AlertRule) {
-	return func(rule *models.AlertRule) {
-		rule.OrgID = orgId
-	}
-}
-
-func withGroup(groupName string) func(rule *models.AlertRule) {
-	return func(rule *models.AlertRule) {
-		rule.RuleGroup = groupName
-	}
-}
-
-func withNamespace(namespace *folder.Folder) func(rule *models.AlertRule) {
-	return func(rule *models.AlertRule) {
-		rule.NamespaceUID = namespace.UID
-	}
-}
-
-func withGroupKey(groupKey models.AlertRuleGroupKey) func(rule *models.AlertRule) {
-	return func(rule *models.AlertRule) {
-		rule.RuleGroup = groupKey.RuleGroup
-		rule.OrgID = groupKey.OrgID
-		rule.NamespaceUID = groupKey.NamespaceUID
-	}
-}
