@@ -4,7 +4,10 @@ import (
 	"net/http"
 )
 
-const mimirTenantHeader = "X-Scope-OrgID"
+const (
+	MimirTenantHeader        = "X-Scope-OrgID"
+	RemoteAlertmanagerHeader = "X-Remote-Alertmanager"
+)
 
 type MimirAuthRoundTripper struct {
 	TenantID string
@@ -16,8 +19,9 @@ type MimirAuthRoundTripper struct {
 // It adds an `X-Scope-OrgID` header with the TenantID if only provided with a tenantID or sets HTTP Basic Authentication if both
 // a tenantID and a password are provided.
 func (r *MimirAuthRoundTripper) RoundTrip(req *http.Request) (*http.Response, error) {
+	req.Header.Set(RemoteAlertmanagerHeader, "true")
 	if r.TenantID != "" && r.Password == "" {
-		req.Header.Set(mimirTenantHeader, r.TenantID)
+		req.Header.Set(MimirTenantHeader, r.TenantID)
 	}
 
 	if r.TenantID != "" && r.Password != "" {
