@@ -9,12 +9,20 @@ import (
 
 // InstanceStore represents the ability to fetch and write alert instances.
 type InstanceStore interface {
-	FetchOrgIds(ctx context.Context) ([]int64, error)
-	ListAlertInstances(ctx context.Context, cmd *models.ListAlertInstancesQuery) ([]*models.AlertInstance, error)
+	InstanceReader
+
 	SaveAlertInstance(ctx context.Context, instance models.AlertInstance) error
 	DeleteAlertInstances(ctx context.Context, keys ...models.AlertInstanceKey) error
-	DeleteAlertInstancesByRule(ctx context.Context, key models.AlertRuleKey) error
-	FullSync(ctx context.Context, instances []models.AlertInstance) error
+	// SaveAlertInstancesForRule overwrites the state for the given rule.
+	SaveAlertInstancesForRule(ctx context.Context, key models.AlertRuleKeyWithGroup, instances []models.AlertInstance) error
+	DeleteAlertInstancesByRule(ctx context.Context, key models.AlertRuleKeyWithGroup) error
+	FullSync(ctx context.Context, instances []models.AlertInstance, batchSize int) error
+}
+
+// InstanceReader provides methods to fetch alert instances.
+type InstanceReader interface {
+	FetchOrgIds(ctx context.Context) ([]int64, error)
+	ListAlertInstances(ctx context.Context, cmd *models.ListAlertInstancesQuery) ([]*models.AlertInstance, error)
 }
 
 // RuleReader represents the ability to fetch alert rules.
