@@ -59,6 +59,11 @@ func (f *FakeOrgService) GetByID(ctx context.Context, query *org.GetOrgByIDQuery
 }
 
 func (f *FakeOrgService) GetByName(ctx context.Context, query *org.GetOrgByNameQuery) (*org.Org, error) {
+	for _, expectedOrg := range f.ExpectedOrgs {
+		if expectedOrg != nil && expectedOrg.Name == query.Name {
+			return &org.Org{ID: expectedOrg.ID, Name: expectedOrg.Name}, nil
+		}
+	}
 	return f.ExpectedOrg, f.ExpectedError
 }
 
@@ -70,10 +75,6 @@ func (f *FakeOrgService) UpdateAddress(ctx context.Context, cmd *org.UpdateOrgAd
 	return f.ExpectedError
 }
 
-func (f *FakeOrgService) Delete(ctx context.Context, cmd *org.DeleteOrgCommand) error {
-	return f.ExpectedError
-}
-
 func (f *FakeOrgService) GetOrCreate(ctx context.Context, orgName string) (int64, error) {
 	return f.ExpectedOrg.ID, f.ExpectedError
 }
@@ -102,3 +103,15 @@ func (f *FakeOrgService) SearchOrgUsers(ctx context.Context, query *org.SearchOr
 
 func (f *FakeOrgService) RegisterDelete(query string) {
 }
+
+type FakeOrgDeletionService struct {
+	ExpectedError error
+}
+
+func NewOrgDeletionServiceFake() *FakeOrgDeletionService {
+	return &FakeOrgDeletionService{}
+}
+
+func (f *FakeOrgDeletionService) Delete(ctx context.Context, cmd *org.DeleteOrgCommand) error {
+	return f.ExpectedError
+}
