@@ -9,40 +9,19 @@ import (
 	"github.com/grafana/grafana/pkg/infra/kvstore"
 	"github.com/grafana/grafana/pkg/plugins/manager/loader/angular/angulardetector"
 	"github.com/grafana/grafana/pkg/plugins/manager/loader/angular/angularinspector"
-	"github.com/grafana/grafana/pkg/services/featuremgmt"
 	"github.com/grafana/grafana/pkg/services/pluginsintegration/angulardetectorsprovider"
 	"github.com/grafana/grafana/pkg/services/pluginsintegration/angularpatternsstore"
 	"github.com/grafana/grafana/pkg/setting"
 )
 
 func TestProvideService(t *testing.T) {
-	t.Run("uses hardcoded inspector if feature flag is not present", func(t *testing.T) {
-		features := featuremgmt.WithFeatures()
+	t.Run("uses dynamic inspector with hardcoded fallback", func(t *testing.T) {
 		dynamic, err := angulardetectorsprovider.ProvideDynamic(
 			setting.NewCfg(),
 			angularpatternsstore.ProvideService(kvstore.NewFakeKVStore()),
-			features,
 		)
 		require.NoError(t, err)
-		inspector, err := ProvideService(features, dynamic)
-		require.NoError(t, err)
-		require.IsType(t, inspector.Inspector, &angularinspector.PatternsListInspector{})
-		patternsListInspector := inspector.Inspector.(*angularinspector.PatternsListInspector)
-		detectors := patternsListInspector.DetectorsProvider.ProvideDetectors(context.Background())
-		require.NotEmpty(t, detectors, "provided detectors should not be empty")
-	})
-
-	t.Run("uses dynamic inspector with hardcoded fallback if feature flag is present", func(t *testing.T) {
-		features := featuremgmt.WithFeatures(
-			featuremgmt.FlagPluginsDynamicAngularDetectionPatterns,
-		)
-		dynamic, err := angulardetectorsprovider.ProvideDynamic(
-			setting.NewCfg(),
-			angularpatternsstore.ProvideService(kvstore.NewFakeKVStore()),
-			features,
-		)
-		require.NoError(t, err)
-		inspector, err := ProvideService(features, dynamic)
+		inspector, err := ProvideService(dynamic)
 		require.NoError(t, err)
 		require.IsType(t, inspector.Inspector, &angularinspector.PatternsListInspector{})
 		require.IsType(t, inspector.Inspector.(*angularinspector.PatternsListInspector).DetectorsProvider, angulardetector.SequenceDetectorsProvider{})
