@@ -6,7 +6,6 @@ import (
 
 	"github.com/grafana/grafana/pkg/infra/kvstore"
 	"github.com/grafana/grafana/pkg/plugins/manager/signature/statickey"
-	"github.com/grafana/grafana/pkg/services/featuremgmt"
 	"github.com/grafana/grafana/pkg/services/pluginsintegration/keyretriever/dynamic"
 	"github.com/grafana/grafana/pkg/services/pluginsintegration/keystore"
 	"github.com/grafana/grafana/pkg/setting"
@@ -16,7 +15,7 @@ import (
 func Test_GetPublicKey(t *testing.T) {
 	t.Run("it should return a static key", func(t *testing.T) {
 		cfg := &setting.Cfg{}
-		kr := ProvideService(dynamic.ProvideService(cfg, keystore.ProvideService(kvstore.NewFakeKVStore()), featuremgmt.WithFeatures()))
+		kr := ProvideService(dynamic.ProvideService(cfg, keystore.ProvideService(kvstore.NewFakeKVStore())))
 		key, err := kr.GetPublicKey(context.Background(), statickey.GetDefaultKeyID())
 		require.NoError(t, err)
 		require.Equal(t, statickey.GetDefaultKey(), key)
