@@ -10,21 +10,23 @@ import (
 type Plugin struct {
 	plugins.JSONData
 
-	fs                plugins.FS
+	FS                plugins.FS
 	supportsStreaming bool
 
 	Class plugins.Class
 
 	// App fields
+	Parent          *ParentPlugin
 	IncludedInAppID string
 	DefaultNavURL   string
 	Pinned          bool
 
 	// Signature fields
-	Signature      plugins.SignatureStatus
-	SignatureType  plugins.SignatureType
-	SignatureOrg   string
-	SignatureError *plugins.SignatureError
+	Signature     plugins.SignatureStatus
+	SignatureType plugins.SignatureType
+	SignatureOrg  string
+
+	Error *plugins.Error
 
 	// SystemJS fields
 	Module  string
@@ -40,7 +42,7 @@ func (p Plugin) SupportsStreaming() bool {
 }
 
 func (p Plugin) Base() string {
-	return p.fs.Base()
+	return p.FS.Base()
 }
 
 func (p Plugin) IsApp() bool {
@@ -58,8 +60,8 @@ func ToGrafanaDTO(p *plugins.Plugin) Plugin {
 		supportsStreaming = true
 	}
 
-	return Plugin{
-		fs:                p.FS,
+	dto := Plugin{
+		FS:                p.FS,
 		supportsStreaming: supportsStreaming,
 		Class:             p.Class,
 		JSONData:          p.JSONData,
@@ -69,11 +71,20 @@ func ToGrafanaDTO(p *plugins.Plugin) Plugin {
 		Signature:         p.Signature,
 		SignatureType:     p.SignatureType,
 		SignatureOrg:      p.SignatureOrg,
-		SignatureError:    p.SignatureError,
+		Error:             p.Error,
 		Module:            p.Module,
 		BaseURL:           p.BaseURL,
 		ExternalService:   p.ExternalService,
-
-		Angular: p.Angular,
+		Angular:           p.Angular,
 	}
+
+	if p.Parent != nil {
+		dto.Parent = &ParentPlugin{ID: p.Parent.ID}
+	}
+
+	return dto
+}
+
+type ParentPlugin struct {
+	ID string
 }
