@@ -55,14 +55,10 @@ func ProvideApi(
 	}
 
 	// register endpoints if the feature is enabled
-	if features.IsEnabledGlobally(featuremgmt.FlagPublicDashboards) && cfg.PublicDashboardsEnabled {
+	if cfg.PublicDashboardsEnabled {
 		api.RegisterAPIEndpoints()
 	}
 
-	if !features.IsEnabledGlobally(featuremgmt.FlagPublicDashboards) {
-		api.log.Warn("[Deprecated] The publicDashboards feature toggle will be removed in Grafana v11. To disable the public dashboards feature, use the public_dashboards.enabled setting.")
-	}
-
 	return api
 }
 
@@ -297,20 +293,16 @@ func (api *Api) DeletePublicDashboard(c *contextmodel.ReqContext) response.Respo
 		return response.Err(err)
 	}
 
-	return response.JSON(http.StatusOK, nil)
+	return response.Empty(http.StatusOK)
 }
 
 // Copied from pkg/api/metrics.go
 func toJsonStreamingResponse(ctx context.Context, features featuremgmt.FeatureToggles, qdr *backend.QueryDataResponse) response.Response {
-	statusWhenError := http.StatusBadRequest
-	if features.IsEnabled(ctx, featuremgmt.FlagDatasourceQueryMultiStatus) {
-		statusWhenError = http.StatusMultiStatus
-	}
-
 	statusCode := http.StatusOK
 	for _, res := range qdr.Responses {
 		if res.Error != nil {
-			statusCode = statusWhenError
+			statusCode = http.StatusBadRequest
+			break
 		}
 	}
 
