@@ -7,13 +7,16 @@ import (
 	"github.com/stretchr/testify/mock"
 	"github.com/stretchr/testify/require"
 
+	"github.com/grafana/grafana/pkg/apimachinery/identity"
+	"github.com/grafana/grafana/pkg/components/satokengen"
 	"github.com/grafana/grafana/pkg/infra/localcache"
 	"github.com/grafana/grafana/pkg/infra/log"
 	"github.com/grafana/grafana/pkg/infra/tracing"
-	"github.com/grafana/grafana/pkg/models/roletype"
 	ac "github.com/grafana/grafana/pkg/services/accesscontrol"
 	"github.com/grafana/grafana/pkg/services/accesscontrol/acimpl"
 	"github.com/grafana/grafana/pkg/services/accesscontrol/actest"
+	"github.com/grafana/grafana/pkg/services/accesscontrol/permreg"
+	"github.com/grafana/grafana/pkg/services/accesscontrol/resourcepermissions"
 	"github.com/grafana/grafana/pkg/services/apikey"
 	"github.com/grafana/grafana/pkg/services/extsvcauth"
 	"github.com/grafana/grafana/pkg/services/featuremgmt"
@@ -23,6 +26,10 @@ import (
 	"github.com/grafana/grafana/pkg/setting"
 )
 
+var (
+	autoAssignOrgID = int64(2)
+)
+
 type TestEnv struct {
 	S        *ExtSvcAccountsService
 	AcStore  *actest.MockStore
@@ -34,6 +41,7 @@ func setupTestEnv(t *testing.T) *TestEnv {
 	t.Helper()
 
 	cfg := setting.NewCfg()
+	cfg.ManagedServiceAccountsEnabled = true
 	fmgt := featuremgmt.WithFeatures(featuremgmt.FlagExternalServiceAccounts)
 
 	env := &TestEnv{
@@ -43,13 +51,18 @@ func setupTestEnv(t *testing.T) *TestEnv {
 	}
 	logger := log.New("extsvcaccounts.test")
 	env.S = &ExtSvcAccountsService{
-		acSvc:    acimpl.ProvideOSSService(cfg, env.AcStore, localcache.New(0, 0), fmgt),
-		features: fmgt,
-		logger:   logger,
-		metrics:  newMetrics(nil, env.SaSvc, logger),
-		saSvc:    env.SaSvc,
-		skvStore: env.SkvStore,
-		tracer:   tracing.InitializeTracerForTest(),
+		enabled: true,
+		acSvc: acimpl.ProvideOSSService(
+			cfg, env.AcStore, &resourcepermissions.FakeActionSetSvc{},
+			localcache.New(0, 0), fmgt, tracing.InitializeTracerForTest(), nil, nil,
+			permreg.ProvidePermissionRegistry(), nil, nil,
+		),
+		defaultOrgID: autoAssignOrgID,
+		logger:       logger,
+		metrics:      newMetrics(nil, autoAssignOrgID, env.SaSvc, logger),
+		saSvc:        env.SaSvc,
+		skvStore:     env.SkvStore,
+		tracer:       tracing.InitializeTracerForTest(),
 	}
 	return env
 }
@@ -65,7 +78,7 @@ func TestExtSvcAccountsService_ManageExtSvcAccount(t *testing.T) {
 		Login:      extSvcSlug,
 		OrgId:      extSvcOrgID,
 		IsDisabled: false,
-		Role:       string(roletype.RoleNone),
+		Role:       string(identity.RoleNone),
 	}
 
 	tests := []struct {
@@ -126,7 +139,7 @@ func TestExtSvcAccountsService_ManageExtSvcAccount(t *testing.T) {
 					mock.Anything,
 					extSvcOrgID,
 					mock.MatchedBy(func(cmd *sa.CreateServiceAccountForm) bool {
-						return cmd.Name == sa.ExtSvcPrefix+extSvcSlug && *cmd.Role == roletype.RoleNone
+						return cmd.Name == sa.ExtSvcPrefix+extSvcSlug && *cmd.Role == identity.RoleNone
 					})).
 					Return(extSvcAccount, nil)
 				env.SaSvc.On("EnableServiceAccount", mock.Anything, extSvcOrgID, extSvcAccount.Id, true).Return(nil)
@@ -198,16 +211,17 @@ func TestExtSvcAccountsService_ManageExtSvcAccount(t *testing.T) {
 
 func TestExtSvcAccountsService_SaveExternalService(t *testing.T) {
 	extSvcSlug := "grafana-test-app"
-	tmpOrgID := int64(1)
+	validToken, err := satokengen.New(extSvcSlug)
+	require.NoError(t, err, "failed to generate a valid token for the tests")
 	extSvcAccID := int64(10)
 	extSvcPerms := []ac.Permission{{Action: ac.ActionUsersRead, Scope: ac.ScopeUsersAll}}
 	extSvcAccount := &sa.ServiceAccountDTO{
 		Id:         extSvcAccID,
 		Name:       extSvcSlug,
 		Login:      extSvcSlug,
-		OrgId:      tmpOrgID,
+		OrgId:      autoAssignOrgID,
 		IsDisabled: false,
-		Role:       string(roletype.RoleNone),
+		Role:       string(identity.RoleNone),
 	}
 
 	tests := []struct {
@@ -222,19 +236,19 @@ func TestExtSvcAccountsService_SaveExternalService(t *testing.T) {
 			name: "should disable service account",
 			init: func(env *TestEnv) {
 				// A previous service account was attached to this slug
-				env.SaSvc.On("RetrieveServiceAccountIdByName", mock.Anything, tmpOrgID, sa.ExtSvcPrefix+extSvcSlug).
+				env.SaSvc.On("RetrieveServiceAccountIdByName", mock.Anything, autoAssignOrgID, sa.ExtSvcPrefix+extSvcSlug).
 					Return(extSvcAccID, nil)
-				env.SaSvc.On("EnableServiceAccount", mock.Anything, tmpOrgID, extSvcAccID, false).Return(nil)
+				env.SaSvc.On("EnableServiceAccount", mock.Anything, autoAssignOrgID, extSvcAccID, false).Return(nil)
 				env.AcStore.On("SaveExternalServiceRole",
 					mock.Anything,
 					mock.MatchedBy(func(cmd ac.SaveExternalServiceRoleCommand) bool {
 						return cmd.ServiceAccountID == extSvcAccID && cmd.ExternalServiceID == extSvcSlug &&
-							cmd.AssignmentOrgID == tmpOrgID && len(cmd.Permissions) == 1 &&
+							cmd.AssignmentOrgID == autoAssignOrgID && len(cmd.Permissions) == 1 &&
 							cmd.Permissions[0] == extSvcPerms[0]
 					})).
 					Return(nil)
 				// A token was previously stored in the secret store
-				_ = env.SkvStore.Set(context.Background(), tmpOrgID, extSvcSlug, kvStoreType, "ExtSvcSecretToken")
+				_ = env.SkvStore.Set(context.Background(), autoAssignOrgID, extSvcSlug, kvStoreType, validToken.ClientSecret)
 			},
 			cmd: extsvcauth.ExternalServiceRegistration{
 				Name: extSvcSlug,
@@ -244,7 +258,7 @@ func TestExtSvcAccountsService_SaveExternalService(t *testing.T) {
 				},
 			},
 			checks: func(t *testing.T, env *TestEnv) {
-				_, ok, _ := env.SkvStore.Get(context.Background(), tmpOrgID, extSvcSlug, kvStoreType)
+				_, ok, _ := env.SkvStore.Get(context.Background(), autoAssignOrgID, extSvcSlug, kvStoreType)
 				require.True(t, ok, "secret should have been kept in store")
 			},
 			want: &extsvcauth.ExternalService{
@@ -258,12 +272,12 @@ func TestExtSvcAccountsService_SaveExternalService(t *testing.T) {
 			name: "should remove service account when no permission",
 			init: func(env *TestEnv) {
 				// A previous service account was attached to this slug
-				env.SaSvc.On("RetrieveServiceAccountIdByName", mock.Anything, tmpOrgID, sa.ExtSvcPrefix+extSvcSlug).
+				env.SaSvc.On("RetrieveServiceAccountIdByName", mock.Anything, autoAssignOrgID, sa.ExtSvcPrefix+extSvcSlug).
 					Return(extSvcAccID, nil)
-				env.SaSvc.On("DeleteServiceAccount", mock.Anything, tmpOrgID, extSvcAccID).Return(nil)
+				env.SaSvc.On("DeleteServiceAccount", mock.Anything, autoAssignOrgID, extSvcAccID).Return(nil)
 				env.AcStore.On("DeleteExternalServiceRole", mock.Anything, extSvcSlug).Return(nil)
 				// A token was previously stored in the secret store
-				_ = env.SkvStore.Set(context.Background(), tmpOrgID, extSvcSlug, kvStoreType, "ExtSvcSecretToken")
+				_ = env.SkvStore.Set(context.Background(), autoAssignOrgID, extSvcSlug, kvStoreType, validToken.ClientSecret)
 			},
 			cmd: extsvcauth.ExternalServiceRegistration{
 				Name: extSvcSlug,
@@ -273,7 +287,7 @@ func TestExtSvcAccountsService_SaveExternalService(t *testing.T) {
 				},
 			},
 			checks: func(t *testing.T, env *TestEnv) {
-				_, ok, _ := env.SkvStore.Get(context.Background(), tmpOrgID, extSvcSlug, kvStoreType)
+				_, ok, _ := env.SkvStore.Get(context.Background(), autoAssignOrgID, extSvcSlug, kvStoreType)
 				require.False(t, ok, "secret should have been removed from store")
 			},
 			want:    nil,
@@ -283,23 +297,23 @@ func TestExtSvcAccountsService_SaveExternalService(t *testing.T) {
 			name: "should create new service account",
 			init: func(env *TestEnv) {
 				// No previous service account was attached to this slug
-				env.SaSvc.On("RetrieveServiceAccountIdByName", mock.Anything, tmpOrgID, sa.ExtSvcPrefix+extSvcSlug).
+				env.SaSvc.On("RetrieveServiceAccountIdByName", mock.Anything, autoAssignOrgID, sa.ExtSvcPrefix+extSvcSlug).
 					Return(int64(0), sa.ErrServiceAccountNotFound.Errorf("mock"))
 				env.SaSvc.On("CreateServiceAccount",
 					mock.Anything,
-					tmpOrgID,
+					autoAssignOrgID,
 					mock.MatchedBy(func(cmd *sa.CreateServiceAccountForm) bool {
-						return cmd.Name == sa.ExtSvcPrefix+extSvcSlug && *cmd.Role == roletype.RoleNone
+						return cmd.Name == sa.ExtSvcPrefix+extSvcSlug && *cmd.Role == identity.RoleNone
 					})).
 					Return(extSvcAccount, nil)
-				env.SaSvc.On("EnableServiceAccount", mock.Anything, tmpOrgID, extSvcAccID, true).Return(nil)
+				env.SaSvc.On("EnableServiceAccount", mock.Anything, autoAssignOrgID, extSvcAccID, true).Return(nil)
 				// Api Key was added without problem
 				env.SaSvc.On("AddServiceAccountToken", mock.Anything, mock.Anything, mock.Anything).Return(&apikey.APIKey{}, nil)
 				env.AcStore.On("SaveExternalServiceRole",
 					mock.Anything,
 					mock.MatchedBy(func(cmd ac.SaveExternalServiceRoleCommand) bool {
 						return cmd.ServiceAccountID == extSvcAccount.Id && cmd.ExternalServiceID == extSvcSlug &&
-							cmd.AssignmentOrgID == tmpOrgID && len(cmd.Permissions) == 1 &&
+							cmd.AssignmentOrgID == autoAssignOrgID && len(cmd.Permissions) == 1 &&
 							cmd.Permissions[0] == extSvcPerms[0]
 					})).
 					Return(nil)
@@ -322,19 +336,64 @@ func TestExtSvcAccountsService_SaveExternalService(t *testing.T) {
 			name: "should update service account",
 			init: func(env *TestEnv) {
 				// A previous service account was attached to this slug
-				env.SaSvc.On("RetrieveServiceAccountIdByName", mock.Anything, tmpOrgID, sa.ExtSvcPrefix+extSvcSlug).
+				env.SaSvc.On("RetrieveServiceAccountIdByName", mock.Anything, autoAssignOrgID, sa.ExtSvcPrefix+extSvcSlug).
 					Return(int64(11), nil)
 				env.AcStore.On("SaveExternalServiceRole",
 					mock.Anything,
 					mock.MatchedBy(func(cmd ac.SaveExternalServiceRoleCommand) bool {
 						return cmd.ServiceAccountID == int64(11) && cmd.ExternalServiceID == extSvcSlug &&
-							cmd.AssignmentOrgID == tmpOrgID && len(cmd.Permissions) == 1 &&
+							cmd.AssignmentOrgID == autoAssignOrgID && len(cmd.Permissions) == 1 &&
 							cmd.Permissions[0] == extSvcPerms[0]
 					})).
 					Return(nil)
-				env.SaSvc.On("EnableServiceAccount", mock.Anything, extsvcauth.TmpOrgID, int64(11), true).Return(nil)
+				env.SaSvc.On("EnableServiceAccount", mock.Anything, autoAssignOrgID, int64(11), true).Return(nil)
 				// This time we don't add a token but rely on the secret store
-				_ = env.SkvStore.Set(context.Background(), tmpOrgID, extSvcSlug, kvStoreType, "ExtSvcSecretToken")
+				_ = env.SkvStore.Set(context.Background(), autoAssignOrgID, extSvcSlug, kvStoreType, validToken.ClientSecret)
+			},
+			cmd: extsvcauth.ExternalServiceRegistration{
+				Name: extSvcSlug,
+				Self: extsvcauth.SelfCfg{
+					Enabled:     true,
+					Permissions: extSvcPerms,
+				},
+			},
+			want: &extsvcauth.ExternalService{
+				Name:   extSvcSlug,
+				ID:     extSvcSlug,
+				Secret: "not empty",
+			},
+			wantErr: false,
+		},
+		{
+			name: "should recover from a failed token encryption",
+			init: func(env *TestEnv) {
+				// A previous service account was attached to this slug
+				env.SaSvc.On("RetrieveServiceAccountIdByName", mock.Anything, autoAssignOrgID, sa.ExtSvcPrefix+extSvcSlug).
+					Return(int64(11), nil)
+				env.AcStore.On("SaveExternalServiceRole",
+					mock.Anything,
+					mock.MatchedBy(func(cmd ac.SaveExternalServiceRoleCommand) bool {
+						return cmd.ServiceAccountID == int64(11) && cmd.ExternalServiceID == extSvcSlug &&
+							cmd.AssignmentOrgID == autoAssignOrgID && len(cmd.Permissions) == 1 &&
+							cmd.Permissions[0] == extSvcPerms[0]
+					})).
+					Return(nil)
+				env.SaSvc.On("EnableServiceAccount", mock.Anything, autoAssignOrgID, int64(11), true).Return(nil)
+
+				// This time the token in the secret store is invalid
+				_ = env.SkvStore.Set(context.Background(), autoAssignOrgID, extSvcSlug, kvStoreType, "failedTokenEncryption")
+				// Delete the API key and entry in the skv store
+				env.SaSvc.On("ListTokens", mock.Anything, mock.Anything).
+					Return([]apikey.APIKey{{ID: 3, Name: tokenNamePrefix + "-" + extSvcSlug}}, nil)
+				env.SaSvc.On("DeleteServiceAccountToken", mock.Anything, mock.Anything, int64(11), int64(3)).Return(nil)
+				// Recreate the API key
+				env.SaSvc.On("AddServiceAccountToken", mock.Anything, mock.Anything, mock.Anything).Return(&apikey.APIKey{}, nil)
+			},
+			checks: func(t *testing.T, env *TestEnv) {
+				// Make sure the secret was updated
+				v, ok, _ := env.SkvStore.Get(context.Background(), autoAssignOrgID, extSvcSlug, kvStoreType)
+				require.True(t, ok, "secret should have been removed from store")
+				require.NotEqual(t, "failedTokenEncryption", v)
 			},
 			cmd: extsvcauth.ExternalServiceRegistration{
 				Name: extSvcSlug,
@@ -385,7 +444,7 @@ func TestExtSvcAccountsService_SaveExternalService(t *testing.T) {
 
 func TestExtSvcAccountsService_RemoveExtSvcAccount(t *testing.T) {
 	extSvcSlug := "grafana-test-app"
-	tmpOrgID := int64(1)
+	autoAssignOrgID := int64(1)
 	extSvcAccID := int64(10)
 	tests := []struct {
 		name   string
@@ -398,7 +457,7 @@ func TestExtSvcAccountsService_RemoveExtSvcAccount(t *testing.T) {
 			name: "should not fail if the service account does not exist",
 			init: func(env *TestEnv) {
 				// No previous service account was attached to this slug
-				env.SaSvc.On("RetrieveServiceAccountIdByName", mock.Anything, tmpOrgID, sa.ExtSvcPrefix+extSvcSlug).
+				env.SaSvc.On("RetrieveServiceAccountIdByName", mock.Anything, autoAssignOrgID, sa.ExtSvcPrefix+extSvcSlug).
 					Return(int64(0), sa.ErrServiceAccountNotFound.Errorf("not found"))
 			},
 			slug: extSvcSlug,
@@ -408,16 +467,16 @@ func TestExtSvcAccountsService_RemoveExtSvcAccount(t *testing.T) {
 			name: "should remove service account",
 			init: func(env *TestEnv) {
 				// A previous service account was attached to this slug
-				env.SaSvc.On("RetrieveServiceAccountIdByName", mock.Anything, tmpOrgID, sa.ExtSvcPrefix+extSvcSlug).
+				env.SaSvc.On("RetrieveServiceAccountIdByName", mock.Anything, autoAssignOrgID, sa.ExtSvcPrefix+extSvcSlug).
 					Return(extSvcAccID, nil)
-				env.SaSvc.On("DeleteServiceAccount", mock.Anything, tmpOrgID, extSvcAccID).Return(nil)
+				env.SaSvc.On("DeleteServiceAccount", mock.Anything, autoAssignOrgID, extSvcAccID).Return(nil)
 				env.AcStore.On("DeleteExternalServiceRole", mock.Anything, extSvcSlug).Return(nil)
 				// A token was previously stored in the secret store
-				_ = env.SkvStore.Set(context.Background(), tmpOrgID, extSvcSlug, kvStoreType, "ExtSvcSecretToken")
+				_ = env.SkvStore.Set(context.Background(), autoAssignOrgID, extSvcSlug, kvStoreType, "ExtSvcSecretToken")
 			},
 			slug: extSvcSlug,
 			checks: func(t *testing.T, env *TestEnv) {
-				_, ok, _ := env.SkvStore.Get(context.Background(), tmpOrgID, extSvcSlug, kvStoreType)
+				_, ok, _ := env.SkvStore.Get(context.Background(), autoAssignOrgID, extSvcSlug, kvStoreType)
 				require.False(t, ok, "secret should have been removed from store")
 			},
 			want: nil,
@@ -432,7 +491,7 @@ func TestExtSvcAccountsService_RemoveExtSvcAccount(t *testing.T) {
 				tt.init(env)
 			}
 
-			err := env.S.RemoveExtSvcAccount(ctx, tmpOrgID, tt.slug)
+			err := env.S.RemoveExtSvcAccount(ctx, autoAssignOrgID, tt.slug)
 			require.NoError(t, err)
 
 			if tt.checks != nil {
@@ -447,15 +506,15 @@ func TestExtSvcAccountsService_RemoveExtSvcAccount(t *testing.T) {
 func TestExtSvcAccountsService_GetExternalServiceNames(t *testing.T) {
 	sa1 := sa.ServiceAccountDTO{
 		Id:    1,
-		Name:  sa.ExtSvcPrefix + "sa-svc-1",
-		Login: sa.ExtSvcLoginPrefix + "sa-svc-1",
-		OrgId: extsvcauth.TmpOrgID,
+		Name:  sa.ExtSvcPrefix + "svc-1",
+		Login: sa.ExtSvcLoginPrefix(autoAssignOrgID) + "svc-1",
+		OrgId: autoAssignOrgID,
 	}
 	sa2 := sa.ServiceAccountDTO{
 		Id:    2,
-		Name:  sa.ExtSvcPrefix + "sa-svc-2",
-		Login: sa.ExtSvcLoginPrefix + "sa-svc-2",
-		OrgId: extsvcauth.TmpOrgID,
+		Name:  sa.ExtSvcPrefix + "svc-2",
+		Login: sa.ExtSvcLoginPrefix(autoAssignOrgID) + "svc-2",
+		OrgId: autoAssignOrgID,
 	}
 	tests := []struct {
 		name string
@@ -466,7 +525,7 @@ func TestExtSvcAccountsService_GetExternalServiceNames(t *testing.T) {
 			name: "should return names",
 			init: func(env *TestEnv) {
 				env.SaSvc.On("SearchOrgServiceAccounts", mock.Anything, mock.MatchedBy(func(cmd *sa.SearchOrgServiceAccountsQuery) bool {
-					return cmd.OrgID == extsvcauth.TmpOrgID &&
+					return cmd.OrgID == autoAssignOrgID &&
 						cmd.Filter == sa.FilterOnlyExternal &&
 						len(cmd.SignedInUser.GetPermissions()[sa.ActionRead]) > 0
 				})).Return(&sa.SearchOrgServiceAccountsResult{
@@ -476,13 +535,13 @@ func TestExtSvcAccountsService_GetExternalServiceNames(t *testing.T) {
 					PerPage:         2,
 				}, nil)
 			},
-			want: []string{"sa-svc-1", "sa-svc-2"},
+			want: []string{"svc-1", "svc-2"},
 		},
 		{
 			name: "should handle nil search",
 			init: func(env *TestEnv) {
 				env.SaSvc.On("SearchOrgServiceAccounts", mock.Anything, mock.MatchedBy(func(cmd *sa.SearchOrgServiceAccountsQuery) bool {
-					return cmd.OrgID == extsvcauth.TmpOrgID &&
+					return cmd.OrgID == autoAssignOrgID &&
 						cmd.Filter == sa.FilterOnlyExternal &&
 						len(cmd.SignedInUser.GetPermissions()[sa.ActionRead]) > 0
 				})).Return(nil, nil)
