@@ -1,6 +1,7 @@
 package signingkeysimpl
 
 import (
+	"bytes"
 	"context"
 	"crypto"
 	"crypto/ecdsa"
@@ -155,13 +156,13 @@ func (s *Service) getPrivateKey(ctx context.Context, keyID string) (crypto.Signe
 		return nil, err
 	}
 
-	singer, err := s.decodePrivateKey(ctx, key.PrivateKey)
+	signer, err := s.decodePrivateKey(ctx, key.PrivateKey)
 	if err != nil {
 		return nil, err
 	}
 
-	s.localCache.Set(keyID, singer, privateKeyTTL)
-	return singer, nil
+	s.localCache.Set(keyID, signer, privateKeyTTL)
+	return signer, nil
 }
 
 func (s *Service) addPrivateKey(ctx context.Context, keyID string, alg jose.SignatureAlgorithm, force bool) (crypto.Signer, error) {
@@ -226,8 +227,8 @@ func (s *Service) encodePrivateKey(ctx context.Context, privateKey crypto.Signer
 		return nil, err
 	}
 
-	encoded := make([]byte, base64.StdEncoding.EncodedLen(len(encrypted)))
-	base64.StdEncoding.Encode(encoded, encrypted)
+	encoded := make([]byte, base64.RawStdEncoding.EncodedLen(len(encrypted)))
+	base64.RawStdEncoding.Encode(encoded, encrypted)
 	return encoded, nil
 }
 
@@ -237,8 +238,12 @@ func (s *Service) decodePrivateKey(ctx context.Context, privateKey []byte) (cryp
 		return nil, errors.New("private key is empty")
 	}
 
-	payload := make([]byte, base64.StdEncoding.DecodedLen(len(privateKey)))
-	_, err := base64.StdEncoding.Decode(payload, privateKey)
+	// Backwards compatibility with old base64 encoding
+	// Can be removed in the future
+	privateKey = bytes.TrimRight(privateKey, "=")
+
+	payload := make([]byte, base64.RawStdEncoding.DecodedLen(len(privateKey)))
+	_, err := base64.RawStdEncoding.Decode(payload, privateKey)
 	if err != nil {
 		return nil, err
 	}
