@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"strings"
 
+	"github.com/grafana/grafana/pkg/services/accesscontrol"
 	"github.com/grafana/grafana/pkg/services/folder"
 	"github.com/grafana/grafana/pkg/services/search/model"
 	"github.com/grafana/grafana/pkg/services/sqlstore/migrator"
@@ -101,11 +102,20 @@ func (f FolderUIDFilter) Where() (string, []any) {
 
 	if includeGeneral {
 		if q == "" {
-			q = "dashboard.folder_id = ? "
+			if f.NestedFoldersEnabled {
+				q = "dashboard.folder_uid IS NULL "
+			} else {
+				q = "dashboard.folder_id = ? "
+				params = append(params, 0)
+			}
 		} else {
-			q = "(" + q + " OR dashboard.folder_id = ?)"
+			if f.NestedFoldersEnabled {
+				q = "(" + q + " OR dashboard.folder_uid IS NULL)"
+			} else {
+				q = "(" + q + " OR dashboard.folder_id = ?)"
+				params = append(params, 0)
+			}
 		}
-		params = append(params, 0)
 	}
 
 	return q, params
@@ -127,6 +137,14 @@ func (f DashboardFilter) Where() (string, []any) {
 	return sqlUIDin("dashboard.uid", f.UIDs)
 }
 
+type K6FolderFilter struct{}
+
+func (f K6FolderFilter) Where() (string, []any) {
+	filter := "dashboard.uid != ? AND (dashboard.folder_uid != ? OR dashboard.folder_uid IS NULL)"
+	params := []any{accesscontrol.K6FolderUID, accesscontrol.K6FolderUID}
+	return filter, params
+}
+
 type TagsFilter struct {
 	Tags []string
 }
@@ -198,3 +216,15 @@ var _ model.FilterWhere = &FolderWithAlertsFilter{}
 func (f FolderWithAlertsFilter) Where() (string, []any) {
 	return "EXISTS (SELECT 1 FROM alert_rule WHERE alert_rule.namespace_uid = dashboard.uid)", nil
 }
+
+type DeletedFilter struct {
+	Deleted bool
+}
+
+func (f DeletedFilter) Where() (string, []any) {
+	if f.Deleted {
+		return "dashboard.deleted IS NOT NULL", nil
+	}
+
+	return "dashboard.deleted IS NULL", nil
+}
