@@ -17,6 +17,7 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
+	"github.com/grafana/grafana/pkg/services/featuremgmt"
 	apimodels "github.com/grafana/grafana/pkg/services/ngalert/api/tooling/definitions"
 	"github.com/grafana/grafana/pkg/services/org"
 	"github.com/grafana/grafana/pkg/services/org/orgimpl"
@@ -32,8 +33,8 @@ func TestIntegrationAlertmanagerConfiguration(t *testing.T) {
 		EnableUnifiedAlerting: true,
 		AppModeProduction:     true,
 	})
-	grafanaListedAddr, store := testinfra.StartGrafana(t, dir, path)
-	createUser(t, store, user.CreateUserCommand{
+	grafanaListedAddr, env := testinfra.StartGrafanaEnv(t, dir, path)
+	createUser(t, env.SQLStore, env.Cfg, user.CreateUserCommand{
 		DefaultOrgRole: string(org.RoleAdmin),
 		Password:       "admin",
 		Login:          "admin",
@@ -283,16 +284,16 @@ func TestIntegrationAlertmanagerConfigurationIsTransactional(t *testing.T) {
 		AppModeProduction:                     true,
 	})
 
-	grafanaListedAddr, store := testinfra.StartGrafana(t, dir, path)
+	grafanaListedAddr, env := testinfra.StartGrafanaEnv(t, dir, path)
 
-	orgService, err := orgimpl.ProvideService(store, store.Cfg, quotatest.New(false, nil))
+	orgService, err := orgimpl.ProvideService(env.SQLStore, env.Cfg, quotatest.New(false, nil))
 	require.NoError(t, err)
 
 	// editor from main organisation requests configuration
 	alertConfigURL := fmt.Sprintf("http://editor:editor@%s/api/alertmanager/grafana/config/api/v1/alerts", grafanaListedAddr)
 
 	// create user under main organisation
-	userID := createUser(t, store, user.CreateUserCommand{
+	userID := createUser(t, env.SQLStore, env.Cfg, user.CreateUserCommand{
 		DefaultOrgRole: string(org.RoleEditor),
 		Password:       "editor",
 		Login:          "editor",
@@ -304,7 +305,7 @@ func TestIntegrationAlertmanagerConfigurationIsTransactional(t *testing.T) {
 	orgID := newOrg.ID
 
 	// create user under different organisation
-	createUser(t, store, user.CreateUserCommand{
+	createUser(t, env.SQLStore, env.Cfg, user.CreateUserCommand{
 		DefaultOrgRole: string(org.RoleEditor),
 		Password:       "editor-42",
 		Login:          "editor-42",
@@ -326,7 +327,6 @@ func TestIntegrationAlertmanagerConfigurationIsTransactional(t *testing.T) {
 		"route": {
 			"receiver": "slack.receiver"
 		},
-		"templates": null,
 		"receivers": [{
 			"name": "slack.receiver",
 			"grafana_managed_receiver_configs": [{
@@ -399,12 +399,13 @@ func TestIntegrationAlertmanagerConfigurationPersistSecrets(t *testing.T) {
 		EnableUnifiedAlerting: true,
 		DisableAnonymous:      true,
 		AppModeProduction:     true,
+		DisableFeatureToggles: []string{featuremgmt.FlagAlertingApiServer},
 	})
 
-	grafanaListedAddr, store := testinfra.StartGrafana(t, dir, path)
+	grafanaListedAddr, env := testinfra.StartGrafanaEnv(t, dir, path)
 	alertConfigURL := fmt.Sprintf("http://editor:editor@%s/api/alertmanager/grafana/config/api/v1/alerts", grafanaListedAddr)
 
-	createUser(t, store, user.CreateUserCommand{
+	createUser(t, env.SQLStore, env.Cfg, user.CreateUserCommand{
 		DefaultOrgRole: string(org.RoleEditor),
 		Password:       "editor",
 		Login:          "editor",
@@ -420,7 +421,6 @@ func TestIntegrationAlertmanagerConfigurationPersistSecrets(t *testing.T) {
 		"route": {
 			"receiver": "slack.receiver"
 		},
-		"templates": null,
 		"receivers": [{
 			"name": "slack.receiver",
 			"grafana_managed_receiver_configs": [{
@@ -452,7 +452,6 @@ func TestIntegrationAlertmanagerConfigurationPersistSecrets(t *testing.T) {
 			"route": {
 				"receiver": "slack.receiver"
 			},
-			"templates": null,
 			"receivers": [{
 				"name": "slack.receiver",
 				"grafana_managed_receiver_configs": [{
@@ -500,7 +499,6 @@ func TestIntegrationAlertmanagerConfigurationPersistSecrets(t *testing.T) {
 		"route": {
 			"receiver": "slack.receiver"
 		},
-		"templates": null,
 		"receivers": [{
 			"name": "slack.receiver",
 			"grafana_managed_receiver_configs": [{
@@ -534,7 +532,6 @@ func TestIntegrationAlertmanagerConfigurationPersistSecrets(t *testing.T) {
 		"route": {
 			"receiver": "slack.receiver"
 		},
-		"templates": null,
 		"receivers": [{
 			"name": "slack.receiver",
 			"grafana_managed_receiver_configs": [{
