@@ -342,6 +342,7 @@ func (s *Service) QueryData(ctx context.Context, req *backend.QueryDataRequest)
 		return nil, err
 	}
 
+	// There aren't any possible downstream errors here
 	queries, err := s.buildQueryExecutors(logger, req)
 	if err != nil {
 		return nil, err
@@ -359,16 +360,21 @@ func (s *Service) executeTimeSeriesQuery(ctx context.Context, req *backend.Query
 	*backend.QueryDataResponse, error) {
 	resp := backend.NewQueryDataResponse()
 	for _, queryExecutor := range queries {
-		queryRes, dr, executedQueryString, err := queryExecutor.run(ctx, req, s, dsInfo, logger)
+		dr, queryRes, executedQueryString, err := queryExecutor.run(ctx, req, s, dsInfo, logger)
 		if err != nil {
+			resp.Responses[queryExecutor.getRefID()] = backend.ErrorResponseWithErrorSource(err)
 			return resp, err
 		}
-		err = queryExecutor.parseResponse(queryRes, dr, executedQueryString, logger)
+		err = queryExecutor.parseResponse(dr, queryRes, executedQueryString, logger)
 		if err != nil {
-			queryRes.Error = err
+			dr.Error = err
+			// If the error is a downstream error, set the error source
+			if backend.IsDownstreamError(err) {
+				dr.ErrorSource = backend.ErrorSourceDownstream
+			}
 		}
 
-		resp.Responses[queryExecutor.getRefID()] = *queryRes
+		resp.Responses[queryExecutor.getRefID()] = *dr
 	}
 
 	return resp, nil
@@ -436,7 +442,7 @@ func (s *Service) buildQueryExecutors(logger log.Logger, req *backend.QueryDataR
 			}
 			queryInterface = cmp
 		default:
-			return nil, fmt.Errorf("unrecognized query type %q", query.QueryType)
+			return nil, backend.DownstreamError(fmt.Errorf("unrecognized query type %q", query.QueryType))
 		}
 
 		cloudMonitoringQueryExecutors = append(cloudMonitoringQueryExecutors, queryInterface)
@@ -583,7 +589,11 @@ func (s *Service) ensureProject(ctx context.Context, dsInfo datasourceInfo, proj
 
 func (s *Service) getDefaultProject(ctx context.Context, dsInfo datasourceInfo) (string, error) {
 	if dsInfo.authenticationType == gceAuthentication {
-		return s.gceDefaultProjectGetter(ctx, cloudMonitorScope)
+		project, err := s.gceDefaultProjectGetter(ctx, cloudMonitorScope)
+		if err != nil {
+			return project, backend.DownstreamError(err)
+		}
+		return project, nil
 	}
 	return dsInfo.defaultProject, nil
 }
@@ -601,21 +611,25 @@ func unmarshalResponse(res *http.Response, logger log.Logger) (cloudMonitoringRe
 	}()
 
 	if res.StatusCode/100 != 2 {
-		logger.Error("Request failed", "status", res.Status, "body", string(body))
-		return cloudMonitoringResponse{}, fmt.Errorf("query failed: %s", string(body))
+		logger.Error("Request failed", "status", res.Status, "body", string(body), "statusSource", backend.ErrorSourceDownstream)
+		statusErr := fmt.Errorf("query failed: %s", string(body))
+		if backend.ErrorSourceFromHTTPStatus(res.StatusCode) == backend.ErrorSourceDownstream {
+			return cloudMonitoringResponse{}, backend.DownstreamError(statusErr)
+		}
+		return cloudMonitoringResponse{}, backend.PluginError(statusErr)
 	}
 
 	var data cloudMonitoringResponse
 	err = json.Unmarshal(body, &data)
 	if err != nil {
-		logger.Error("Failed to unmarshal CloudMonitoring response", "error", err, "status", res.Status, "body", string(body))
+		logger.Error("Failed to unmarshal CloudMonitoring response", "error", err, "status", res.Status, "body", string(body), "statusSource", backend.ErrorSourceDownstream)
 		return cloudMonitoringResponse{}, fmt.Errorf("failed to unmarshal query response: %w", err)
 	}
 
 	return data, nil
 }
 
-func addConfigData(frames data.Frames, dl string, unit string, period *string) data.Frames {
+func addConfigData(frames data.Frames, dl string, unit string, period *string, logger log.Logger) data.Frames {
 	for i := range frames {
 		if frames[i].Fields[1].Config == nil {
 			frames[i].Fields[1].Config = &data.FieldConfig{}
@@ -639,7 +653,7 @@ func addConfigData(frames data.Frames, dl string, unit string, period *string) d
 		if period != nil && *period != "" {
 			err := addInterval(*period, frames[i].Fields[0])
 			if err != nil {
-				backend.Logger.Error("Failed to add interval", "error", err)
+				logger.Error("Failed to add interval: %s", err, "statusSource", backend.ErrorSourceDownstream)
 			}
 		}
 	}
