@@ -9,6 +9,8 @@ import (
 const (
 	FlagCloudWatchCrossAccountQuerying = "cloudWatchCrossAccountQuerying"
 	FlagCloudWatchBatchQueries         = "cloudWatchBatchQueries"
+	FlagCloudWatchNewLabelParsing      = "cloudWatchNewLabelParsing"
+	FlagCloudWatchRoundUpEndTime       = "cloudWatchRoundUpEndTime"
 )
 
 func IsEnabled(ctx context.Context, feature string) bool {
