@@ -2,10 +2,13 @@ package cloudwatch
 
 import (
 	"context"
+	"time"
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/service/cloudwatch"
 	"github.com/aws/aws-sdk-go/service/cloudwatch/cloudwatchiface"
+	"github.com/grafana/grafana-plugin-sdk-go/backend"
+	"github.com/grafana/grafana/pkg/tsdb/cloudwatch/features"
 	"github.com/grafana/grafana/pkg/tsdb/cloudwatch/utils"
 )
 
@@ -18,9 +21,14 @@ func (e *cloudWatchExecutor) executeRequest(ctx context.Context, client cloudwat
 		if nextToken != "" {
 			metricDataInput.NextToken = aws.String(nextToken)
 		}
+		// GetMetricData EndTime is exclusive, so we round up to the next minute to get the last data point
+		if features.IsEnabled(ctx, features.FlagCloudWatchRoundUpEndTime) {
+			*metricDataInput.EndTime = metricDataInput.EndTime.Truncate(time.Minute).Add(time.Minute)
+		}
+
 		resp, err := client.GetMetricDataWithContext(ctx, metricDataInput)
 		if err != nil {
-			return mdo, err
+			return mdo, backend.DownstreamError(err)
 		}
 
 		mdo = append(mdo, resp)
