@@ -7,9 +7,9 @@ import (
 	"testing"
 	"time"
 
-	"github.com/apache/arrow/go/v15/arrow"
-	"github.com/apache/arrow/go/v15/arrow/array"
-	"github.com/apache/arrow/go/v15/arrow/memory"
+	"github.com/apache/arrow-go/v18/arrow"
+	"github.com/apache/arrow-go/v18/arrow/array"
+	"github.com/apache/arrow-go/v18/arrow/memory"
 	"github.com/google/go-cmp/cmp"
 	"github.com/grafana/grafana-plugin-sdk-go/data"
 	"github.com/grafana/grafana-plugin-sdk-go/data/sqlutil"
@@ -37,6 +37,8 @@ func TestNewQueryDataResponse(t *testing.T) {
 			{Name: "utf8", Type: &arrow.StringType{}},
 			{Name: "duration", Type: &arrow.DurationType{}},
 			{Name: "timestamp", Type: &arrow.TimestampType{}},
+
+			{Name: "item", Type: arrow.ListOf(&arrow.StringType{})},
 		},
 		nil,
 	)
@@ -58,9 +60,11 @@ func TestNewQueryDataResponse(t *testing.T) {
 		newJSONArray(`["foo", "bar", "baz"]`, &arrow.StringType{}),
 		newJSONArray(`[0, 1, -2]`, &arrow.DurationType{}),
 		newJSONArray(`[0, 1, 2]`, &arrow.TimestampType{}),
+
+		newJSONArray(`[["test", "test1", "test2"],[],[]]`, arrow.ListOf(&arrow.StringType{})),
 	}
 
-	var arr []arrow.Array
+	arr := make([]arrow.Array, 0, len(strValues))
 	for _, v := range strValues {
 		tarr, _, err := array.FromJSON(
 			alloc,
@@ -82,7 +86,7 @@ func TestNewQueryDataResponse(t *testing.T) {
 	resp := newQueryDataResponse(errReader{RecordReader: reader}, query, metadata.MD{})
 	assert.NoError(t, resp.Error)
 	assert.Len(t, resp.Frames, 1)
-	assert.Len(t, resp.Frames[0].Fields, 13)
+	assert.Len(t, resp.Frames[0].Fields, 14)
 
 	frame := resp.Frames[0]
 	f0 := frame.Fields[0]
@@ -156,6 +160,14 @@ func TestNewQueryDataResponse(t *testing.T) {
 		},
 		extractFieldValues[time.Time](t, f12),
 	)
+
+	s1 := "test"
+	s2 := "test1"
+	s3 := "test2"
+	f13 := frame.Fields[13]
+	assert.Equal(t, f13.Name, "item")
+	assert.Equal(t, f13.Type(), data.FieldTypeNullableString)
+	assert.Equal(t, []*string{&s1, &s2, &s3}, extractFieldValues[*string](t, f13))
 }
 
 type jsonArray struct {
@@ -315,7 +327,7 @@ func TestNewFrame(t *testing.T) {
 		},
 	}
 	if !cmp.Equal(expected, actual, cmp.Comparer(cmpFrame)) {
-		log.Fatalf(cmp.Diff(expected, actual))
+		log.Fatal(cmp.Diff(expected, actual))
 	}
 }
 
