@@ -82,7 +82,7 @@ func newInstanceSettings(httpClientProvider httpclient.Provider) datasource.Inst
 			DefaultBucket: jsonData.DefaultBucket,
 			Organization:  jsonData.Organization,
 			MaxSeries:     maxSeries,
-			SecureGrpc:    true,
+			InsecureGrpc:  jsonData.InsecureGrpc,
 			Token:         settings.DecryptedSecureJSONData["token"],
 			Timeout:       opts.Timeouts.Timeout,
 		}
