@@ -1,6 +1,10 @@
 package models
 
-import "time"
+import (
+	"time"
+
+	"github.com/influxdata/influxql"
+)
 
 type Query struct {
 	Measurement  string
@@ -18,6 +22,7 @@ type Query struct {
 	OrderByTime  string
 	RefID        string
 	ResultFormat string
+	Statement    influxql.Statement
 }
 
 type Tag struct {
@@ -32,6 +37,8 @@ type Select []QueryPart
 type Response struct {
 	Results []Result
 	Error   string
+	Code    string
+	Message string
 }
 
 type Result struct {
