@@ -15,12 +15,10 @@ import (
 	"time"
 
 	jsoniter "github.com/json-iterator/go"
-	"go.opentelemetry.io/otel/attribute"
 	"go.opentelemetry.io/otel/codes"
-	"go.opentelemetry.io/otel/trace"
+	"google.golang.org/grpc/metadata"
 
 	"github.com/grafana/grafana-plugin-sdk-go/backend"
-
 	"github.com/grafana/grafana-plugin-sdk-go/backend/log"
 	"github.com/grafana/grafana/pkg/infra/tracing"
 	"github.com/grafana/grafana/pkg/promlib/converter"
@@ -109,6 +107,8 @@ func makeDataRequest(ctx context.Context, lokiDsUrl string, query lokiQuery, cat
 		req.Header.Set("X-Loki-Response-Encoding-Flags", "categorize-labels")
 	}
 
+	setXScopeOrgIDHeader(req, ctx)
+
 	return req, nil
 }
 
@@ -215,23 +215,21 @@ func (api *LokiAPI) DataQuery(ctx context.Context, query lokiQuery, responseOpts
 	}
 
 	start = time.Now()
-	_, span := api.tracer.Start(ctx, "datasource.loki.parseResponse", trace.WithAttributes(
-		attribute.Bool("metricDataplane", responseOpts.metricDataplane),
-	))
+	_, span := api.tracer.Start(ctx, "datasource.loki.parseResponse")
 	defer span.End()
 
 	iter := jsoniter.Parse(jsoniter.ConfigDefault, resp.Body, 1024)
-	res := converter.ReadPrometheusStyleResult(iter, converter.Options{Dataplane: responseOpts.metricDataplane})
+	res := converter.ReadPrometheusStyleResult(iter, converter.Options{Dataplane: true})
 
 	if res.Error != nil {
 		span.RecordError(res.Error)
 		span.SetStatus(codes.Error, res.Error.Error())
 		instrumentation.UpdatePluginParsingResponseDurationSeconds(ctx, time.Since(start), "error")
-		api.log.Error("Error parsing response from loki", "error", res.Error, "metricDataplane", responseOpts.metricDataplane, "duration", time.Since(start), "stage", stageParseResponse)
+		api.log.Error("Error parsing response from loki", "error", res.Error, "duration", time.Since(start), "stage", stageParseResponse)
 		return nil, res.Error
 	}
 	instrumentation.UpdatePluginParsingResponseDurationSeconds(ctx, time.Since(start), "ok")
-	api.log.Info("Response parsed from loki", "duration", time.Since(start), "metricDataplane", responseOpts.metricDataplane, "framesLength", len(res.Frames), "stage", stageParseResponse)
+	api.log.Info("Response parsed from loki", "duration", time.Since(start), "framesLength", len(res.Frames), "stage", stageParseResponse)
 
 	return &res, nil
 }
@@ -257,6 +255,8 @@ func makeRawRequest(ctx context.Context, lokiDsUrl string, resourcePath string)
 		return nil, err
 	}
 
+	setXScopeOrgIDHeader(req, ctx)
+
 	return req, nil
 }
 
@@ -346,3 +346,31 @@ func getSupportingQueryHeaderValue(supportingQueryType SupportingQueryType) stri
 
 	return value
 }
+
+// setXScopeOrgIDHeader sets the `X-Scope-OrgID` header in the provided HTTP request based on the tenant ID retrieved from the context.
+// `X-Scope-OrgID` is needed by the Loki system to work in multi-tenant mode.
+// See https://github.com/grafana/loki/blob/main/docs/sources/operations/multi-tenancy.md
+func setXScopeOrgIDHeader(req *http.Request, ctx context.Context) *http.Request {
+	logger := backend.NewLoggerWith("logger", "tsdb.loki")
+
+	md, ok := metadata.FromIncomingContext(ctx)
+	if !ok {
+		// Metadata are currently set and needed only locally for multi-tenancy, while on cloud
+		// this is set by our stack
+		logger.Debug("Metadata not present in context. Header not set")
+		return req
+	}
+
+	tenantids := md.Get("tenantid")
+	if len(tenantids) == 0 {
+		// We assume we are not using multi-tenant mode, which is fine
+		logger.Debug("Tenant ID not present. Header not set")
+	} else if len(tenantids) > 1 {
+		// Loki supports multiple tenant IDs, but we should receive them from different contexts
+		logger.Error(strconv.Itoa(len(tenantids)) + " tenant IDs found. Header not set")
+	} else {
+		req.Header.Add("X-Scope-OrgID", tenantids[0])
+		logger.Debug("Tenant ID " + tenantids[0] + " added to Loki request")
+	}
+	return req
+}
