@@ -94,6 +94,8 @@ func parseDirection(jsonPointerValue *string) (Direction, error) {
 			return DirectionBackward, nil
 		case "forward":
 			return DirectionForward, nil
+		case "scan":
+			return DirectionBackward, nil
 		default:
 			return DirectionBackward, fmt.Errorf("invalid queryDirection: %s", jsonValue)
 		}
@@ -123,7 +125,7 @@ func parseSupportingQueryType(jsonPointerValue *string) SupportingQueryType {
 	}
 }
 
-func parseQuery(queryContext *backend.QueryDataRequest) ([]*lokiQuery, error) {
+func parseQuery(queryContext *backend.QueryDataRequest, logqlScopesEnabled bool) ([]*lokiQuery, error) {
 	qs := []*lokiQuery{}
 	for _, query := range queryContext.Queries {
 		model, err := parseQueryModel(query.JSON)
@@ -169,6 +171,13 @@ func parseQuery(queryContext *backend.QueryDataRequest) ([]*lokiQuery, error) {
 			legendFormat = *model.LegendFormat
 		}
 
+		if logqlScopesEnabled {
+			rewrittenExpr, err := ApplyScopes(expr, model.Scopes)
+			if err == nil {
+				expr = rewrittenExpr
+			}
+		}
+
 		supportingQueryType := parseSupportingQueryType(model.SupportingQueryType)
 
 		qs = append(qs, &lokiQuery{
@@ -182,6 +191,7 @@ func parseQuery(queryContext *backend.QueryDataRequest) ([]*lokiQuery, error) {
 			End:                 end,
 			RefID:               query.RefID,
 			SupportingQueryType: supportingQueryType,
+			Scopes:              model.Scopes,
 		})
 	}
 
