@@ -3,27 +3,27 @@ import pluralize from 'pluralize';
 import React, { useEffect, useState } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
-import { Stack } from '@grafana/experimental';
-import { logInfo } from '@grafana/runtime';
-import { Badge, ConfirmModal, HorizontalGroup, Icon, Spinner, Tooltip, useStyles2 } from '@grafana/ui';
-import { useDispatch } from 'app/types';
-import { CombinedRuleGroup, CombinedRuleNamespace } from 'app/types/unified-alerting';
+import { selectors } from '@grafana/e2e-selectors';
+import { Badge, ConfirmModal, Icon, Spinner, Stack, Tooltip, useStyles2 } from '@grafana/ui';
+import { CombinedRuleGroup, CombinedRuleNamespace, RuleGroupIdentifier, RulesSource } from 'app/types/unified-alerting';
 
-import { LogMessages } from '../../Analytics';
+import { LogMessages, logInfo } from '../../Analytics';
+import { featureDiscoveryApi } from '../../api/featureDiscoveryApi';
+import { useDeleteRuleGroup } from '../../hooks/ruleGroup/useDeleteRuleGroup';
 import { useFolder } from '../../hooks/useFolder';
 import { useHasRuler } from '../../hooks/useHasRuler';
-import { deleteRulesGroupAction } from '../../state/actions';
 import { useRulesAccess } from '../../utils/accessControlHooks';
-import { GRAFANA_RULES_SOURCE_NAME, isCloudRulesSource } from '../../utils/datasource';
+import { GRAFANA_RULES_SOURCE_NAME, getRulesSourceName, isCloudRulesSource } from '../../utils/datasource';
 import { makeFolderLink, makeFolderSettingsLink } from '../../utils/misc';
 import { isFederatedRuleGroup, isGrafanaRulerRule } from '../../utils/rules';
 import { CollapseToggle } from '../CollapseToggle';
 import { RuleLocation } from '../RuleLocation';
 import { GrafanaRuleFolderExporter } from '../export/GrafanaRuleFolderExporter';
 import { GrafanaRuleGroupExporter } from '../export/GrafanaRuleGroupExporter';
+import { decodeGrafanaNamespace } from '../expressions/util';
 
 import { ActionIcon } from './ActionIcon';
-import { EditCloudGroupModal } from './EditRuleGroupModal';
+import { EditRuleGroupModal } from './EditRuleGroupModal';
 import { ReorderCloudGroupModal } from './ReorderRuleGroupModal';
 import { RuleGroupStats } from './RuleStats';
 import { RulesTable } from './RulesTable';
@@ -37,9 +37,13 @@ interface Props {
   viewMode: ViewMode;
 }
 
+const { useDiscoverDsFeaturesQuery } = featureDiscoveryApi;
+
 export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }: Props) => {
   const { rulesSource } = namespace;
-  const dispatch = useDispatch();
+  const rulesSourceName = getRulesSourceName(rulesSource);
+
+  const [deleteRuleGroup] = useDeleteRuleGroup();
   const styles = useStyles2(getStyles);
 
   const [isEditingGroup, setIsEditingGroup] = useState(false);
@@ -54,14 +58,15 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
     setIsCollapsed(!expandAll);
   }, [expandAll]);
 
-  const { hasRuler, rulerRulesLoaded } = useHasRuler();
+  const { hasRuler, rulerRulesLoaded } = useHasRuler(namespace.rulesSource);
+  const { currentData: dsFeatures } = useDiscoverDsFeaturesQuery({ rulesSourceName });
+
   const rulerRule = group.rules[0]?.rulerRule;
   const folderUID = (rulerRule && isGrafanaRulerRule(rulerRule) && rulerRule.grafana_alert.namespace_uid) || undefined;
   const { folder } = useFolder(folderUID);
 
   // group "is deleting" if rules source has ruler, but this group has no rules that are in ruler
-  const isDeleting =
-    hasRuler(rulesSource) && rulerRulesLoaded(rulesSource) && !group.rules.find((rule) => !!rule.rulerRule);
+  const isDeleting = hasRuler && rulerRulesLoaded && !group.rules.find((rule) => !!rule.rulerRule);
   const isFederated = isFederatedRuleGroup(group);
 
   // check if group has provisioned items
@@ -73,8 +78,13 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
   const isListView = viewMode === 'list';
   const isGroupView = viewMode === 'grouped';
 
-  const deleteGroup = () => {
-    dispatch(deleteRulesGroupAction(namespace, group));
+  const deleteGroup = async () => {
+    const namespaceName = decodeGrafanaNamespace(namespace).name;
+    const groupName = group.name;
+    const dataSourceName = getRulesSourceName(namespace.rulesSource);
+
+    const ruleGroupIdentifier: RuleGroupIdentifier = { namespaceName, groupName, dataSourceName };
+    await deleteRuleGroup.execute(ruleGroupIdentifier);
     setIsDeletingGroup(false);
   };
 
@@ -83,10 +93,10 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
   // for grafana, link to folder views
   if (isDeleting) {
     actionIcons.push(
-      <HorizontalGroup key="is-deleting">
+      <Stack key="is-deleting">
         <Spinner />
         deleting
-      </HorizontalGroup>
+      </Stack>
     );
   } else if (rulesSource === GRAFANA_RULES_SOURCE_NAME) {
     if (folderUID) {
@@ -105,7 +115,6 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
           );
           actionIcons.push(
             <ActionIcon
-              aria-label="re-order rules"
               data-testid="reorder-group"
               key="reorder"
               icon="exchange-alt"
@@ -167,7 +176,7 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
         }
       }
     }
-  } else if (canEditRules(rulesSource.name) && hasRuler(rulesSource)) {
+  } else if (canEditRules(rulesSource.name) && hasRuler) {
     if (!isFederated) {
       actionIcons.push(
         <ActionIcon
@@ -181,11 +190,10 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
       );
       actionIcons.push(
         <ActionIcon
-          aria-label="re-order rules"
           data-testid="reorder-group"
           key="reorder"
           icon="exchange-alt"
-          tooltip="re-order rules"
+          tooltip="reorder rules"
           className={styles.rotate90}
           onClick={() => setIsReorderingGroup(true)}
         />
@@ -206,9 +214,9 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
 
   // ungrouped rules are rules that are in the "default" group name
   const groupName = isListView ? (
-    <RuleLocation namespace={namespace.name} />
+    <RuleLocation namespace={decodeGrafanaNamespace(namespace).name} />
   ) : (
-    <RuleLocation namespace={namespace.name} group={group.name} />
+    <RuleLocation namespace={decodeGrafanaNamespace(namespace).name} group={group.name} />
   );
 
   const closeEditModal = (saved = false) => {
@@ -226,18 +234,10 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
           className={styles.collapseToggle}
           isCollapsed={isCollapsed}
           onToggle={setIsCollapsed}
-          data-testid="group-collapse-toggle"
+          data-testid={selectors.components.AlertRules.groupToggle}
         />
-        <Icon name={isCollapsed ? 'folder' : 'folder-open'} />
-        {isCloudRulesSource(rulesSource) && (
-          <Tooltip content={rulesSource.name} placement="top">
-            <img
-              alt={rulesSource.meta.name}
-              className={styles.dataSourceIcon}
-              src={rulesSource.meta.info.logos.small}
-            />
-          </Tooltip>
-        )}
+        <FolderIcon isCollapsed={isCollapsed} />
+        <CloudSourceLogo rulesSource={rulesSource} />
         {
           // eslint-disable-next-line
           <div className={styles.groupName} onClick={() => setIsCollapsed(!isCollapsed)}>
@@ -275,15 +275,22 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
         />
       )}
       {isEditingGroup && (
-        <EditCloudGroupModal
+        <EditRuleGroupModal
           namespace={namespace}
           group={group}
           onClose={() => closeEditModal()}
-          folderUrl={folder?.canEdit ? makeFolderSettingsLink(folder) : undefined}
+          folderUrl={folder?.canEdit ? makeFolderSettingsLink(folder.uid) : undefined}
+          folderUid={folderUID}
         />
       )}
-      {isReorderingGroup && (
-        <ReorderCloudGroupModal group={group} namespace={namespace} onClose={() => setIsReorderingGroup(false)} />
+      {isReorderingGroup && dsFeatures?.rulerConfig && (
+        <ReorderCloudGroupModal
+          group={group}
+          folderUid={folderUID}
+          namespace={namespace}
+          onClose={() => setIsReorderingGroup(false)}
+          rulerConfig={dsFeatures.rulerConfig}
+        />
       )}
       <ConfirmModal
         isOpen={isDeletingGroup}
@@ -317,79 +324,106 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
 
 RulesGroup.displayName = 'RulesGroup';
 
+// It's a simple component but we render 80 of them on the list page it needs to be fast
+// The Tooltip component is expensive to render and the rulesSource doesn't change often
+// so memoization seems to bring a lot of benefit here
+const CloudSourceLogo = React.memo(({ rulesSource }: { rulesSource: RulesSource | string }) => {
+  const styles = useStyles2(getStyles);
+
+  if (isCloudRulesSource(rulesSource)) {
+    return (
+      <Tooltip content={rulesSource.name} placement="top">
+        <img alt={rulesSource.meta.name} className={styles.dataSourceIcon} src={rulesSource.meta.info.logos.small} />
+      </Tooltip>
+    );
+  }
+
+  return null;
+});
+
+CloudSourceLogo.displayName = 'CloudSourceLogo';
+
+// We render a lot of these on the list page, and the Icon component does quite a bit of work
+// to render its contents
+const FolderIcon = React.memo(({ isCollapsed }: { isCollapsed: boolean }) => {
+  return <Icon name={isCollapsed ? 'folder' : 'folder-open'} />;
+});
+
+FolderIcon.displayName = 'FolderIcon';
+
 export const getStyles = (theme: GrafanaTheme2) => {
   return {
-    wrapper: css``,
-    header: css`
-      display: flex;
-      flex-direction: row;
-      align-items: center;
-      padding: ${theme.spacing(1)} ${theme.spacing(1)} ${theme.spacing(1)} 0;
-      flex-wrap: nowrap;
-      border-bottom: 1px solid ${theme.colors.border.weak};
+    wrapper: css({}),
+    header: css({
+      display: 'flex',
+      flexDirection: 'row',
+      alignItems: 'center',
+      padding: `${theme.spacing(1)} ${theme.spacing(1)} ${theme.spacing(1)} 0`,
+      flexWrap: 'nowrap',
+      borderBottom: `1px solid ${theme.colors.border.weak}`,
 
-      &:hover {
-        background-color: ${theme.components.table.rowHoverBackground};
-      }
-    `,
-    headerStats: css`
-      flex-shrink: 0;
+      '&:hover': {
+        backgroundColor: theme.components.table.rowHoverBackground,
+      },
+    }),
+    headerStats: css({
+      flexShrink: 0,
 
-      span {
-        vertical-align: middle;
-      }
+      span: {
+        verticalAlign: 'middle',
+      },
 
-      ${theme.breakpoints.down('sm')} {
-        order: 2;
-        width: 100%;
-        padding-left: ${theme.spacing(1)};
-      }
-    `,
-    groupName: css`
-      margin-left: ${theme.spacing(1)};
-      margin-bottom: 0;
-      cursor: pointer;
+      [theme.breakpoints.down('sm')]: {
+        order: 2,
+        width: '100%',
+        paddingLeft: theme.spacing(1),
+      },
+    }),
+    groupName: css({
+      marginLeft: theme.spacing(1),
+      marginBottom: 0,
+      cursor: 'pointer',
 
-      white-space: nowrap;
-      overflow: hidden;
-      text-overflow: ellipsis;
-    `,
-    spacer: css`
-      flex: 1;
-    `,
-    collapseToggle: css`
-      background: none;
-      border: none;
-      margin-top: -${theme.spacing(1)};
-      margin-bottom: -${theme.spacing(1)};
+      whiteSpace: 'nowrap',
+      overflow: 'hidden',
+      textOverflow: 'ellipsis',
+    }),
+    spacer: css({
+      flex: 1,
+    }),
+    collapseToggle: css({
+      background: 'none',
+      border: 'none',
+      marginTop: `-${theme.spacing(1)}`,
+      marginBottom: `-${theme.spacing(1)}`,
 
-      svg {
-        margin-bottom: 0;
-      }
-    `,
-    dataSourceIcon: css`
-      width: ${theme.spacing(2)};
-      height: ${theme.spacing(2)};
-      margin-left: ${theme.spacing(2)};
-    `,
-    dataSourceOrigin: css`
-      margin-right: 1em;
-      color: ${theme.colors.text.disabled};
-    `,
-    actionsSeparator: css`
-      margin: 0 ${theme.spacing(2)};
-    `,
-    actionIcons: css`
-      width: 80px;
-      align-items: center;
+      svg: {
+        marginBottom: 0,
+      },
+    }),
+    dataSourceIcon: css({
+      width: theme.spacing(2),
+      height: theme.spacing(2),
+      marginLeft: theme.spacing(2),
+    }),
+    dataSourceOrigin: css({
+      marginRight: '1em',
+      color: theme.colors.text.disabled,
+    }),
+    actionsSeparator: css({
+      margin: `0 ${theme.spacing(2)}`,
+    }),
+    actionIcons: css({
+      width: '80px',
+      alignItems: 'center',
 
-      flex-shrink: 0;
-    `,
-    rulesTable: css`
-      margin: ${theme.spacing(2, 0)};
-    `,
-    rotate90: css`
-      transform: rotate(90deg);
-    `,
+      flexShrink: 0,
+    }),
+    rulesTable: css({
+      margin: theme.spacing(2, 0),
+    }),
+    rotate90: css({
+      transform: 'rotate(90deg)',
+    }),
   };
 };
