@@ -1,12 +1,11 @@
 import { css } from '@emotion/css';
-import React, { PureComponent } from 'react';
+import { PureComponent } from 'react';
 import { connect, ConnectedProps } from 'react-redux';
 import AutoSizer from 'react-virtualized-auto-sizer';
 import { Subscription } from 'rxjs';
 
 import { FieldConfigSource, GrafanaTheme2, NavModel, NavModelItem, PageLayoutType } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
-import { Stack } from '@grafana/experimental';
 import { locationService } from '@grafana/runtime';
 import {
   Button,
@@ -19,6 +18,7 @@ import {
   ToolbarButton,
   ToolbarButtonRow,
   withTheme2,
+  Stack,
 } from '@grafana/ui';
 import { AppChromeUpdate } from 'app/core/components/AppChrome/AppChromeUpdate';
 import { Page } from 'app/core/components/Page/Page';
@@ -33,11 +33,12 @@ import { StoreState } from 'app/types';
 import { PanelOptionsChangedEvent, ShowModalReactEvent } from 'app/types/events';
 
 import { notifyApp } from '../../../../core/actions';
-import { UnlinkModal } from '../../../library-panels/components/UnlinkModal/UnlinkModal';
+import { UnlinkModal } from '../../../dashboard-scene/scene/UnlinkModal';
 import { isPanelModelLibraryPanel } from '../../../library-panels/guard';
 import { getVariablesByKey } from '../../../variables/state/selectors';
 import { DashboardPanel } from '../../dashgrid/DashboardPanel';
-import { DashboardModel, PanelModel } from '../../state';
+import { DashboardModel } from '../../state/DashboardModel';
+import { PanelModel } from '../../state/PanelModel';
 import { DashNavTimeControls } from '../DashNav/DashNavTimeControls';
 import { SaveDashboardDrawer } from '../SaveDashboard/SaveDashboardDrawer';
 
@@ -266,7 +267,7 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
         {panelPane}
         <div
           className={styles.tabsWrapper}
-          aria-label={selectors.components.PanelEditor.DataPane.content}
+          data-testid={selectors.components.PanelEditor.DataPane.content}
           key="panel-editor-tabs"
         >
           <PanelEditorTabs
@@ -309,7 +310,7 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
               id="table-view"
               value={tableViewEnabled}
               onClick={this.onToggleTableView}
-              aria-label={selectors.components.PanelEditor.toggleTableView}
+              data-testid={selectors.components.PanelEditor.toggleTableView}
             />
             <RadioButtonGroup value={uiState.mode} options={displayModes} onChange={this.onDisplayModeChange} />
             <DashNavTimeControls dashboard={dashboard} onChangeTimeZone={updateTimeZoneForSession} isOnCanvas={true} />
@@ -333,27 +334,28 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
       >
         Discard
       </Button>,
-      this.props.panel.libraryPanel ? (
-        <Button
-          onClick={this.onSaveLibraryPanel}
-          variant="primary"
-          size={size}
-          title="Apply changes and save library panel"
-          key="save-panel"
-        >
-          Save library panel
-        </Button>
-      ) : (
-        <Button
-          onClick={this.onSaveDashboard}
-          title="Apply changes and save dashboard"
-          key="save"
-          size={size}
-          variant="secondary"
-        >
-          Save
-        </Button>
-      ),
+      this.props.dashboard.meta.canSave &&
+        (this.props.panel.libraryPanel ? (
+          <Button
+            onClick={this.onSaveLibraryPanel}
+            variant="primary"
+            size={size}
+            title="Apply changes and save library panel"
+            key="save-panel"
+          >
+            Save library panel
+          </Button>
+        ) : (
+          <Button
+            onClick={this.onSaveDashboard}
+            title="Apply changes and save dashboard"
+            key="save"
+            size={size}
+            variant="secondary"
+          >
+            Save
+          </Button>
+        )),
       <Button
         onClick={this.onBack}
         variant="primary"
@@ -429,12 +431,6 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
     this.setState({ showSaveLibraryPanelModal: false });
   };
 
-  renderToolbar() {
-    return (
-      <AppChromeUpdate actions={<ToolbarButtonRow alignment="right">{this.renderEditorActions()}</ToolbarButtonRow>} />
-    );
-  }
-
   render() {
     const { initDone, uiState, theme, sectionNav, pageNav, className, updatePanelEditorUIState } = this.props;
     const styles = getStyles(theme, this.props);
@@ -447,11 +443,13 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
       <Page
         navModel={sectionNav}
         pageNav={pageNav}
-        aria-label={selectors.components.PanelEditor.General.content}
+        data-testid={selectors.components.PanelEditor.General.content}
         layout={PageLayoutType.Custom}
-        toolbar={this.renderToolbar()}
         className={className}
       >
+        <AppChromeUpdate
+          actions={<ToolbarButtonRow alignment="right">{this.renderEditorActions()}</ToolbarButtonRow>}
+        />
         <div className={styles.wrapper}>
           <div className={styles.verticalSplitPanesWrapper}>
             {!uiState.isPanelOptionsVisible ? (
@@ -505,64 +503,64 @@ export const getStyles = stylesFactory((theme: GrafanaTheme2, props: Props) => {
       display: 'flex',
       paddingTop: theme.spacing(2),
     }),
-    verticalSplitPanesWrapper: css`
-      display: flex;
-      flex-direction: column;
-      height: 100%;
-      width: 100%;
-      position: relative;
-    `,
-    mainPaneWrapper: css`
-      display: flex;
-      flex-direction: column;
-      height: 100%;
-      width: 100%;
-      padding-right: ${uiState.isPanelOptionsVisible ? 0 : paneSpacing};
-    `,
-    variablesWrapper: css`
-      label: variablesWrapper;
-      display: flex;
-      flex-grow: 1;
-      flex-wrap: wrap;
-      gap: ${theme.spacing(1, 2)};
-    `,
-    panelWrapper: css`
-      flex: 1 1 0;
-      min-height: 0;
-      width: 100%;
-      padding-left: ${paneSpacing};
-    `,
-    tabsWrapper: css`
-      height: 100%;
-      width: 100%;
-    `,
-    panelToolbar: css`
-      display: flex;
-      padding: 0 0 ${paneSpacing} ${paneSpacing};
-      justify-content: space-between;
-      flex-wrap: wrap;
-    `,
-    angularWarning: css`
-      display: flex;
-      height: theme.spacing(4);
-      align-items: center;
-    `,
-    toolbarLeft: css`
-      padding-left: ${theme.spacing(1)};
-    `,
-    centeringContainer: css`
-      display: flex;
-      justify-content: center;
-      align-items: center;
-      position: relative;
-      flex-direction: column;
-    `,
-    onlyPanel: css`
-      height: 100%;
-      position: absolute;
-      overflow: hidden;
-      width: 100%;
-    `,
+    verticalSplitPanesWrapper: css({
+      display: 'flex',
+      flexDirection: 'column',
+      height: '100%',
+      width: '100%',
+      position: 'relative',
+    }),
+    mainPaneWrapper: css({
+      display: 'flex',
+      flexDirection: 'column',
+      height: '100%',
+      width: '100%',
+      paddingRight: `${uiState.isPanelOptionsVisible ? 0 : paneSpacing}`,
+    }),
+    variablesWrapper: css({
+      label: 'variablesWrapper',
+      display: 'flex',
+      flexGrow: 1,
+      flexWrap: 'wrap',
+      gap: theme.spacing(1, 2),
+    }),
+    panelWrapper: css({
+      flex: '1 1 0',
+      minHeight: 0,
+      width: '100%',
+      paddingLeft: paneSpacing,
+    }),
+    tabsWrapper: css({
+      height: '100%',
+      width: '100%',
+    }),
+    panelToolbar: css({
+      display: 'flex',
+      padding: `0 0 ${paneSpacing} ${paneSpacing}`,
+      justifyContent: 'space-between',
+      flexWrap: 'wrap',
+    }),
+    angularWarning: css({
+      display: 'flex',
+      height: theme.spacing(4),
+      alignItems: 'center',
+    }),
+    toolbarLeft: css({
+      paddingLeft: theme.spacing(1),
+    }),
+    centeringContainer: css({
+      display: 'flex',
+      justifyContent: 'center',
+      alignItems: 'center',
+      position: 'relative',
+      flexDirection: 'column',
+    }),
+    onlyPanel: css({
+      height: '100%',
+      position: 'absolute',
+      overflow: 'hidden',
+      width: '100%',
+    }),
   };
 });
 
