@@ -1,6 +1,6 @@
 import { each, map } from 'lodash';
 
-import { DataLinkBuiltInVars, MappingType } from '@grafana/data';
+import { DataLinkBuiltInVars, MappingType, VariableHide } from '@grafana/data';
 import { getPanelPlugin } from '@grafana/data/test/__mocks__/pluginMocks';
 import { setDataSourceSrv } from '@grafana/runtime';
 import { FieldConfigSource } from '@grafana/schema';
@@ -9,10 +9,11 @@ import { GRID_CELL_HEIGHT, GRID_CELL_VMARGIN } from 'app/core/constants';
 import { mockDataSource, MockDataSourceSrv } from 'app/features/alerting/unified/mocks';
 import { MIXED_DATASOURCE_NAME } from 'app/plugins/datasource/mixed/MixedDataSource';
 
-import { VariableHide } from '../../variables/types';
 import { DashboardModel } from '../state/DashboardModel';
 import { PanelModel } from '../state/PanelModel';
 
+import { DASHBOARD_SCHEMA_VERSION } from './DashboardMigrator';
+
 jest.mock('app/core/services/context_srv', () => ({}));
 
 const dataSources = {
@@ -44,7 +45,7 @@ setDataSourceSrv(new MockDataSourceSrv(dataSources));
 
 describe('DashboardModel', () => {
   describe('when creating dashboard with old schema', () => {
-    let model: any;
+    let model: DashboardModel;
     let graph: any;
     let singlestat: any;
     let table: any;
@@ -69,8 +70,8 @@ describe('DashboardModel', () => {
         panels: [
           {
             type: 'graph',
-            legend: { show: true },
             // @ts-expect-error
+            legend: { show: true },
             aliasYAxis: { test: 2 },
             y_formats: ['kbyte', 'ms'],
             grid: {
@@ -228,7 +229,7 @@ describe('DashboardModel', () => {
     });
 
     it('dashboard schema version should be set to latest', () => {
-      expect(model.schemaVersion).toBe(38);
+      expect(model.schemaVersion).toBe(DASHBOARD_SCHEMA_VERSION);
     });
 
     it('graph thresholds should be migrated', () => {
@@ -515,7 +516,7 @@ describe('DashboardModel', () => {
   });
 
   describe('when migrating panel links', () => {
-    let model: any;
+    let model: DashboardModel;
 
     beforeEach(() => {
       model = new DashboardModel({
@@ -562,24 +563,26 @@ describe('DashboardModel', () => {
     });
 
     it('should add keepTime as variable', () => {
-      expect(model.panels[0].links[0].url).toBe(`http://mylink.com?$${DataLinkBuiltInVars.keepTime}`);
+      expect(model.panels[0].links?.[0].url).toBe(`http://mylink.com?$${DataLinkBuiltInVars.keepTime}`);
     });
 
     it('should add params to url', () => {
-      expect(model.panels[0].links[1].url).toBe('http://mylink.com?existingParam&customParam');
+      expect(model.panels[0].links?.[1].url).toBe('http://mylink.com?existingParam&customParam');
     });
 
     it('should add includeVars to url', () => {
-      expect(model.panels[0].links[2].url).toBe(`http://mylink.com?existingParam&$${DataLinkBuiltInVars.includeVars}`);
+      expect(model.panels[0].links?.[2].url).toBe(
+        `http://mylink.com?existingParam&$${DataLinkBuiltInVars.includeVars}`
+      );
     });
 
     it('should slugify dashboard name', () => {
-      expect(model.panels[0].links[3].url).toBe(`dashboard/db/my-other-dashboard`);
+      expect(model.panels[0].links?.[3].url).toBe(`dashboard/db/my-other-dashboard`);
     });
   });
 
   describe('when migrating variables', () => {
-    let model: any;
+    let model: DashboardModel;
     beforeEach(() => {
       model = new DashboardModel({
         panels: [
@@ -646,7 +649,7 @@ describe('DashboardModel', () => {
   });
 
   describe('when migrating labels from DataFrame to Field', () => {
-    let model: any;
+    let model: DashboardModel;
     beforeEach(() => {
       model = new DashboardModel({
         panels: [
@@ -890,7 +893,7 @@ describe('DashboardModel', () => {
     });
 
     it('should migrate panels with new Text Panel id', () => {
-      const reactPanel: any = model.panels[1];
+      const reactPanel = model.panels[1];
       expect(reactPanel.id).toEqual(3);
       expect(reactPanel.type).toEqual('text');
       expect(reactPanel.title).toEqual('React Text Panel from scratch');
@@ -901,7 +904,7 @@ describe('DashboardModel', () => {
     });
 
     it('should clean up old angular options for panels with new Text Panel id', () => {
-      const reactPanel: any = model.panels[2];
+      const reactPanel = model.panels[2];
       expect(reactPanel.id).toEqual(4);
       expect(reactPanel.type).toEqual('text');
       expect(reactPanel.title).toEqual('React Text Panel from Angular Panel');
@@ -1077,12 +1080,14 @@ describe('DashboardModel', () => {
               type: 'query',
               name: 'variable_with_unknown_refresh_with_options',
               options: [{ text: 'A', value: 'A' }],
+              // @ts-expect-error
               refresh: 2001,
             },
             {
               type: 'query',
               name: 'variable_with_unknown_refresh_without_options',
               options: [],
+              // @ts-expect-error
               refresh: 2001,
             },
             {
@@ -1560,7 +1565,7 @@ describe('DashboardModel', () => {
   });
 
   describe('migrating legacy CloudWatch queries', () => {
-    let model: any;
+    let model: DashboardModel;
     let panelTargets: any;
 
     beforeEach(() => {
@@ -2408,6 +2413,21 @@ describe('when migrating table cell display mode to cell options', () => {
   });
 });
 
+describe('when migrating variable refresh to on dashboard load', () => {
+  let model: DashboardModel;
+
+  beforeEach(() => {
+    model = new DashboardModel({
+      //@ts-ignore
+      refresh: false,
+    });
+  });
+
+  it('should migrate to empty string', () => {
+    expect(model.refresh).toBe('');
+  });
+});
+
 function createRow(options: any, panelDescriptions: any[]) {
   const PANEL_HEIGHT_STEP = GRID_CELL_HEIGHT + GRID_CELL_VMARGIN;
   const { collapse, showTitle, title, repeat, repeatIteration } = options;
