@@ -1,24 +1,30 @@
-import { DataSourcePluginMeta, DataSourceSettings, UrlQueryValue } from '@grafana/data';
-import { DataSourcesState } from '../../../types/datasources';
+import memoizeOne from 'memoize-one';
 
-export const getDataSources = (state: DataSourcesState) => {
+import { DataSourcePluginMeta, DataSourceSettings, UrlQueryValue } from '@grafana/data';
+import { DataSourcesState } from 'app/types/datasources';
+
+export const getDataSources = memoizeOne((state: DataSourcesState) => {
   const regex = new RegExp(state.searchQuery, 'i');
 
-  return state.dataSources.filter((dataSource: DataSourceSettings) => {
-    return regex.test(dataSource.name) || regex.test(dataSource.database);
+  const filteredDataSources = state.dataSources.filter((dataSource: DataSourceSettings) => {
+    return regex.test(dataSource.name) || regex.test(dataSource.database) || regex.test(dataSource.type);
   });
-};
 
-export const getDataSourcePlugins = (state: DataSourcesState) => {
+  return filteredDataSources.sort((a, b) =>
+    state.isSortAscending ? a.name.localeCompare(b.name) : b.name.localeCompare(a.name)
+  );
+});
+
+export const getFilteredDataSourcePlugins = memoizeOne((state: DataSourcesState) => {
   const regex = new RegExp(state.dataSourceTypeSearchQuery, 'i');
 
   return state.plugins.filter((type: DataSourcePluginMeta) => {
     return regex.test(type.name);
   });
-};
+});
 
-export const getDataSource = (state: DataSourcesState, dataSourceId: UrlQueryValue): DataSourceSettings | null => {
-  if (state.dataSource.id === parseInt(dataSourceId as string, 10)) {
+export const getDataSource = (state: DataSourcesState, dataSourceId: UrlQueryValue): DataSourceSettings => {
+  if (state.dataSource.uid === dataSourceId) {
     return state.dataSource;
   }
   return {} as DataSourceSettings;
@@ -35,3 +41,4 @@ export const getDataSourceMeta = (state: DataSourcesState, type: string): DataSo
 export const getDataSourcesSearchQuery = (state: DataSourcesState) => state.searchQuery;
 export const getDataSourcesLayoutMode = (state: DataSourcesState) => state.layoutMode;
 export const getDataSourcesCount = (state: DataSourcesState) => state.dataSourcesCount;
+export const getDataSourcesSort = (state: DataSourcesState) => state.isSortAscending;
