@@ -1,6 +1,6 @@
 import { render, screen, waitFor } from '@testing-library/react';
 import userEvent from '@testing-library/user-event';
-import React, { useState } from 'react';
+import { useState } from 'react';
 
 import { defaultFilters } from '../../../useSearch';
 import { Trace } from '../../types/trace';
@@ -52,12 +52,15 @@ describe('SpanFilters', () => {
   const SpanFiltersWithProps = ({ showFilters = true, matches }: { showFilters?: boolean; matches?: Set<string> }) => {
     const [search, setSearch] = useState(defaultFilters);
     const [showSpanFilterMatchesOnly, setShowSpanFilterMatchesOnly] = useState(false);
+    const [showCriticalPathSpansOnly, setShowCriticalPathSpansOnly] = useState(false);
     const props = {
       trace: trace,
       showSpanFilters: showFilters,
       setShowSpanFilters: jest.fn(),
       showSpanFilterMatchesOnly,
       setShowSpanFilterMatchesOnly,
+      showCriticalPathSpansOnly,
+      setShowCriticalPathSpansOnly,
       search,
       setSearch,
       spanFilterMatches: matches,
@@ -96,9 +99,7 @@ describe('SpanFilters', () => {
     const toValue = screen.getByLabelText('Select max span duration');
     const tagKey = screen.getByLabelText('Select tag key');
     const tagOperator = screen.getByLabelText('Select tag operator');
-    const tagValue = screen.getByLabelText('Select tag value');
-    const addTag = screen.getByLabelText('Add tag');
-    const removeTag = screen.getByLabelText('Remove tag');
+    const tagSelectValue = screen.getByLabelText('Select tag value');
 
     expect(serviceOperator).toBeInTheDocument();
     expect(getElemText(serviceOperator)).toBe('=');
@@ -115,9 +116,7 @@ describe('SpanFilters', () => {
     expect(tagKey).toBeInTheDocument();
     expect(tagOperator).toBeInTheDocument();
     expect(getElemText(tagOperator)).toBe('=');
-    expect(tagValue).toBeInTheDocument();
-    expect(addTag).toBeInTheDocument();
-    expect(removeTag).toBeInTheDocument();
+    expect(tagSelectValue).toBeInTheDocument();
 
     await user.click(serviceValue);
     jest.advanceTimersByTime(1000);
@@ -131,6 +130,13 @@ describe('SpanFilters', () => {
       expect(screen.getByText('Span0')).toBeInTheDocument();
       expect(screen.getByText('Span1')).toBeInTheDocument();
     });
+    await user.click(tagOperator);
+    jest.advanceTimersByTime(1000);
+    await waitFor(() => {
+      expect(screen.getByText('!~')).toBeInTheDocument();
+      expect(screen.getByText('=~')).toBeInTheDocument();
+      expect(screen.getByText('!~')).toBeInTheDocument();
+    });
     await user.click(tagKey);
     jest.advanceTimersByTime(1000);
     await waitFor(() => {
@@ -141,6 +147,7 @@ describe('SpanFilters', () => {
       expect(screen.getByText('ProcessKey1')).toBeInTheDocument();
       expect(screen.getByText('LogKey0')).toBeInTheDocument();
       expect(screen.getByText('LogKey1')).toBeInTheDocument();
+      expect(screen.getByPlaceholderText('Find...')).toBeInTheDocument();
     });
   });
 
@@ -149,6 +156,7 @@ describe('SpanFilters', () => {
     const serviceValue = screen.getByLabelText('Select service name');
     const spanValue = screen.getByLabelText('Select span name');
     const tagKey = screen.getByLabelText('Select tag key');
+    const tagOperator = screen.getByLabelText('Select tag operator');
     const tagValue = screen.getByLabelText('Select tag value');
 
     expect(getElemText(serviceValue)).toBe('All service names');
@@ -164,6 +172,9 @@ describe('SpanFilters', () => {
     await selectAndCheckValue(user, tagKey, 'TagKey0');
     expect(getElemText(tagValue)).toBe('Select value');
     await selectAndCheckValue(user, tagValue, 'TagValue0');
+    expect(screen.queryByLabelText('Input tag value')).toBeNull();
+    await selectAndCheckValue(user, tagOperator, '=~');
+    expect(screen.getByLabelText('Input tag value')).toBeInTheDocument();
   });
 
   it('should order tag filters', async () => {
@@ -174,25 +185,57 @@ describe('SpanFilters', () => {
     jest.advanceTimersByTime(1000);
     await waitFor(() => {
       const container = screen.getByText('TagKey0').parentElement?.parentElement?.parentElement;
-      expect(container?.childNodes[0].textContent).toBe('ProcessKey0');
-      expect(container?.childNodes[1].textContent).toBe('ProcessKey1');
-      expect(container?.childNodes[2].textContent).toBe('TagKey0');
-      expect(container?.childNodes[3].textContent).toBe('TagKey1');
-      expect(container?.childNodes[4].textContent).toBe('id');
-      expect(container?.childNodes[5].textContent).toBe('kind');
-      expect(container?.childNodes[6].textContent).toBe('library.name');
-      expect(container?.childNodes[7].textContent).toBe('library.version');
-      expect(container?.childNodes[8].textContent).toBe('status');
-      expect(container?.childNodes[9].textContent).toBe('status.message');
-      expect(container?.childNodes[10].textContent).toBe('trace.state');
-      expect(container?.childNodes[11].textContent).toBe('LogKey0');
-      expect(container?.childNodes[12].textContent).toBe('LogKey1');
+      expect(container?.childNodes[1].textContent).toBe('ProcessKey0');
+      expect(container?.childNodes[2].textContent).toBe('ProcessKey1');
+      expect(container?.childNodes[3].textContent).toBe('TagKey0');
+      expect(container?.childNodes[4].textContent).toBe('TagKey1');
+      expect(container?.childNodes[5].textContent).toBe('id');
+      expect(container?.childNodes[6].textContent).toBe('kind');
+      expect(container?.childNodes[7].textContent).toBe('library.name');
+      expect(container?.childNodes[8].textContent).toBe('library.version');
+      expect(container?.childNodes[9].textContent).toBe('status');
+      expect(container?.childNodes[10].textContent).toBe('status.message');
+      expect(container?.childNodes[11].textContent).toBe('trace.state');
+      expect(container?.childNodes[12].textContent).toBe('LogKey0');
+      expect(container?.childNodes[13].textContent).toBe('LogKey1');
     });
   });
 
+  it('should only show add/remove tag when necessary', async () => {
+    render(<SpanFiltersWithProps />);
+    expect(screen.queryAllByLabelText('Add tag').length).toBe(0); // not filled in the default tag, so no need to add another one
+    expect(screen.queryAllByLabelText('Remove tag').length).toBe(0); // mot filled in the default tag, so no values to remove
+    expect(screen.getAllByLabelText('Select tag key').length).toBe(1);
+
+    await selectAndCheckValue(user, screen.getByLabelText('Select tag key'), 'TagKey0');
+    expect(screen.getAllByLabelText('Add tag').length).toBe(1);
+    expect(screen.getAllByLabelText('Remove tag').length).toBe(1);
+
+    await user.click(screen.getByLabelText('Add tag'));
+    jest.advanceTimersByTime(1000);
+    expect(screen.queryAllByLabelText('Add tag').length).toBe(0); // not filled in the new tag, so no need to add another one
+    expect(screen.getAllByLabelText('Remove tag').length).toBe(2); // one for each tag
+    expect(screen.getAllByLabelText('Select tag key').length).toBe(2);
+
+    await user.click(screen.getAllByLabelText('Remove tag')[1]);
+    jest.advanceTimersByTime(1000);
+    expect(screen.queryAllByLabelText('Add tag').length).toBe(1); // filled in the default tag, so can add another one
+    expect(screen.queryAllByLabelText('Remove tag').length).toBe(1); // filled in the default tag, so can remove values
+    expect(screen.getAllByLabelText('Select tag key').length).toBe(1);
+
+    await user.click(screen.getAllByLabelText('Remove tag')[0]);
+    jest.advanceTimersByTime(1000);
+    expect(screen.queryAllByLabelText('Add tag').length).toBe(0); // not filled in the default tag, so no need to add another one
+    expect(screen.queryAllByLabelText('Remove tag').length).toBe(0); // mot filled in the default tag, so no values to remove
+    expect(screen.getAllByLabelText('Select tag key').length).toBe(1);
+  });
+
   it('should allow adding/removing tags', async () => {
     render(<SpanFiltersWithProps />);
     expect(screen.getAllByLabelText('Select tag key').length).toBe(1);
+    const tagKey = screen.getByLabelText('Select tag key');
+    await selectAndCheckValue(user, tagKey, 'TagKey0');
+
     await user.click(screen.getByLabelText('Add tag'));
     jest.advanceTimersByTime(1000);
     expect(screen.getAllByLabelText('Select tag key').length).toBe(2);
@@ -217,7 +260,7 @@ describe('SpanFilters', () => {
     await selectAndCheckValue(user, tagKey, 'TagKey0');
     await selectAndCheckValue(user, tagValue, 'TagValue0');
 
-    const matchesSwitch = screen.getByRole('checkbox', { name: 'Show matches only switch' });
+    const matchesSwitch = screen.getByRole('switch', { name: 'Show matches only switch' });
     expect(matchesSwitch).not.toBeChecked();
     await user.click(matchesSwitch);
     expect(matchesSwitch).toBeChecked();
@@ -228,6 +271,8 @@ describe('SpanFilters', () => {
     expect(screen.queryByText('Span0')).not.toBeInTheDocument();
     expect(screen.queryByText('TagKey0')).not.toBeInTheDocument();
     expect(screen.queryByText('TagValue0')).not.toBeInTheDocument();
+    expect(screen.queryByText('Add tag')).not.toBeInTheDocument();
+    expect(screen.queryByText('Remove tag')).not.toBeInTheDocument();
     expect(matchesSwitch).not.toBeChecked();
   });
 
