@@ -6,7 +6,7 @@ import { CustomVariableSupport, DataSourceApi } from '@grafana/data';
 import { config } from '@grafana/runtime';
 
 import { forbiddenElements } from './constants';
-import { isReactClassComponent, logWarning } from './utils';
+import { isReactClassComponent, logWarning, unboxNearMembraneProxies } from './utils';
 
 // IMPORTANT: NEVER export this symbol from a public (e.g `@grafana/*`) package
 const SANDBOX_LIVE_VALUE = Symbol.for('@@SANDBOX_LIVE_VALUE');
@@ -194,9 +194,30 @@ export function patchWebAPIs() {
   if (!nativeAPIsPatched) {
     nativeAPIsPatched = true;
     patchHistoryReplaceState();
+    patchWorkerPostMessage();
   }
 }
 
+/*
+ *
+ * Worker.postMessage uses internally structureClone which won't work with proxies.
+ *
+ * In case where the blue realm code is directly handling proxy objects that
+ * should be send over a post message the blue realm will call postMessage and try to
+ * send the proxy resulting in an error.
+ *
+ * This makes sure all proxies are unboxed before being sent over the post message
+ */
+function patchWorkerPostMessage() {
+  const originalPostMessage = Worker.prototype.postMessage;
+  Object.defineProperty(Worker.prototype, 'postMessage', {
+    value: function (...args: Parameters<typeof Worker.prototype.postMessage>) {
+      // eslint-disable-next-line
+      return originalPostMessage.apply(this, unboxNearMembraneProxies(args) as typeof args);
+    },
+  });
+}
+
 /*
  * window.history.replaceState is a native API that won't work with proxies
  * so we need to patch it to unwrap any possible proxies you pass to it.
