@@ -1,9 +1,10 @@
 import { isFunction } from 'lodash';
-import React, { ComponentType, FC } from 'react';
+import { ComponentType, FC } from 'react';
+import * as React from 'react';
 
-import { PluginConfigPage, PluginExtensionConfig, PluginMeta, PluginType } from '@grafana/data';
+import { GrafanaPlugin, PluginExtensionConfig, PluginType } from '@grafana/data';
 
-import { SandboxedPluginObject } from './types';
+import { SandboxPluginMeta, SandboxedPluginObject } from './types';
 import { isSandboxedPluginObject } from './utils';
 
 /**
@@ -27,7 +28,7 @@ import { isSandboxedPluginObject } from './utils';
  */
 export async function sandboxPluginComponents(
   pluginExports: System.Module,
-  meta: PluginMeta
+  meta: SandboxPluginMeta
 ): Promise<SandboxedPluginObject | System.Module> {
   if (!isSandboxedPluginObject(pluginExports)) {
     // we should monitor these cases. There should not be any plugins without a plugin export loaded inside the sandbox
@@ -70,7 +71,8 @@ export async function sandboxPluginComponents(
 
   // config pages
   if (Reflect.has(pluginObject, 'configPages')) {
-    const configPages: Record<string, PluginConfigPage<any>> = Reflect.get(pluginObject, 'configPages');
+    const configPages: NonNullable<GrafanaPlugin['configPages']> = Reflect.get(pluginObject, 'configPages') ?? [];
+
     for (const [key, value] of Object.entries(configPages)) {
       if (!value.body || !isFunction(value.body)) {
         continue;
@@ -88,7 +90,7 @@ export async function sandboxPluginComponents(
 
 const withSandboxWrapper = <P extends object>(
   WrappedComponent: ComponentType<P>,
-  pluginMeta: PluginMeta
+  pluginMeta: SandboxPluginMeta
 ): React.MemoExoticComponent<FC<P>> => {
   const WithWrapper = React.memo((props: P) => {
     return (
