@@ -1,8 +1,6 @@
 import { css } from '@emotion/css';
-import React from 'react';
 
 import { DataQueryError, GrafanaTheme2 } from '@grafana/data';
-import { config } from '@grafana/runtime';
 import { Icon, useStyles2 } from '@grafana/ui';
 
 export interface Props {
@@ -21,7 +19,7 @@ export function QueryErrorAlert({ error }: Props) {
       </div>
       <div className={styles.message}>
         {message}
-        {config.featureToggles.showTraceId && error.traceId != null && (
+        {error.traceId != null && (
           <>
             <br /> <span>(Trace ID: {error.traceId})</span>
           </>
