@@ -1,7 +1,11 @@
-import React, { PureComponent } from 'react';
+import { PureComponent } from 'react';
+import * as React from 'react';
+
+import { t } from 'app/core/internationalization';
+
 import { NavigationKey } from '../types';
 
-export interface Props {
+export interface Props extends Omit<React.HTMLProps<HTMLInputElement>, 'onChange' | 'value'> {
   onChange: (value: string) => void;
   onNavigate: (key: NavigationKey, clearOthers: boolean) => void;
   value: string | null;
@@ -9,9 +13,9 @@ export interface Props {
 
 export class VariableInput extends PureComponent<Props> {
   onKeyDown = (event: React.KeyboardEvent<HTMLInputElement>) => {
-    if (NavigationKey[event.keyCode]) {
+    if (NavigationKey[event.keyCode] && event.keyCode !== NavigationKey.select) {
       const clearOthers = event.ctrlKey || event.metaKey || event.shiftKey;
-      this.props.onNavigate(event.keyCode as NavigationKey, clearOthers);
+      this.props.onNavigate(event.keyCode, clearOthers);
       event.preventDefault();
     }
   };
@@ -21,19 +25,23 @@ export class VariableInput extends PureComponent<Props> {
   };
 
   render() {
+    const { value, id, onNavigate, ...restProps } = this.props;
     return (
       <input
-        ref={instance => {
+        {...restProps}
+        ref={(instance) => {
           if (instance) {
             instance.focus();
-            instance.setAttribute('style', `width:${Math.max(instance.width, 80)}px`);
+            instance.setAttribute('style', `width:${Math.max(instance.width, 150)}px`);
           }
         }}
+        id={id}
         type="text"
         className="gf-form-input"
-        value={this.props.value ?? ''}
+        value={value ?? ''}
         onChange={this.onChange}
         onKeyDown={this.onKeyDown}
+        placeholder={t('variable.dropdown.placeholder', 'Enter variable value')}
       />
     );
   }
