@@ -1,9 +1,12 @@
-import React, { FunctionComponent } from 'react';
-import { renderHook } from '@testing-library/react-hooks';
-import { render } from '@testing-library/react';
-import { ElasticsearchProvider, useDatasource, useQuery } from './ElasticsearchQueryContext';
-import { ElasticsearchQuery } from '../../types';
+import { render, renderHook } from '@testing-library/react';
+import { PropsWithChildren } from 'react';
+
+import { getDefaultTimeRange } from '@grafana/data';
+
 import { ElasticDatasource } from '../../datasource';
+import { ElasticsearchQuery } from '../../types';
+
+import { ElasticsearchProvider, useQuery } from './ElasticsearchQueryContext';
 
 const query: ElasticsearchQuery = {
   refId: 'A',
@@ -24,6 +27,7 @@ describe('ElasticsearchQueryContext', () => {
         onChange={onChange}
         datasource={datasource}
         onRunQuery={onRunQuery}
+        range={getDefaultTimeRange()}
       />
     );
 
@@ -39,20 +43,24 @@ describe('ElasticsearchQueryContext', () => {
     expect(onRunQuery).toHaveBeenCalled();
   });
 
+  // the following applies to all hooks in ElasticsearchQueryContext as they all share the same code.
   describe('useQuery Hook', () => {
     it('Should throw when used outside of ElasticsearchQueryContext', () => {
-      const { result } = renderHook(() => useQuery());
-
-      expect(result.error).toBeTruthy();
+      jest.spyOn(console, 'error').mockImplementation(() => {});
+      expect(() => {
+        renderHook(() => useQuery());
+      }).toThrow();
+      expect(console.error).toHaveBeenCalled();
     });
 
     it('Should return the current query object', () => {
-      const wrapper: FunctionComponent = ({ children }) => (
+      const wrapper = ({ children }: PropsWithChildren<{}>) => (
         <ElasticsearchProvider
           datasource={{} as ElasticDatasource}
           query={query}
           onChange={() => {}}
           onRunQuery={() => {}}
+          range={getDefaultTimeRange()}
         >
           {children}
         </ElasticsearchProvider>
@@ -65,28 +73,4 @@ describe('ElasticsearchQueryContext', () => {
       expect(result.current).toBe(query);
     });
   });
-
-  describe('useDatasource Hook', () => {
-    it('Should throw when used outside of ElasticsearchQueryContext', () => {
-      const { result } = renderHook(() => useDatasource());
-
-      expect(result.error).toBeTruthy();
-    });
-
-    it('Should return the current datasource instance', () => {
-      const datasource = {} as ElasticDatasource;
-
-      const wrapper: FunctionComponent = ({ children }) => (
-        <ElasticsearchProvider datasource={datasource} query={query} onChange={() => {}} onRunQuery={() => {}}>
-          {children}
-        </ElasticsearchProvider>
-      );
-
-      const { result } = renderHook(() => useDatasource(), {
-        wrapper,
-      });
-
-      expect(result.current).toBe(datasource);
-    });
-  });
 });
