@@ -8,7 +8,7 @@ import { GraphiteParserError } from './types';
  * This function removes all HTML tags and keeps only the last line from the stack
  * trace which should be the most meaningful.
  */
-export function reduceError(error: any): any {
+export function reduceError(error: any) {
   if (error && error.status === 500 && error.data?.message?.startsWith('<body')) {
     // Remove all HTML tags and take the last line from the stack trace
     const newMessage = last<string>(
