@@ -1,26 +1,30 @@
 import { css } from '@emotion/css';
-import React, { useMemo, createRef } from 'react';
+import { useMemo, createRef } from 'react';
 import { useAsync } from 'react-use';
 
-import { PanelProps } from '@grafana/data';
+import { Field, LinkModel, PanelProps } from '@grafana/data';
 import { getDataSourceSrv } from '@grafana/runtime';
 import { TraceView } from 'app/features/explore/TraceView/TraceView';
 import { SpanLinkFunc } from 'app/features/explore/TraceView/components';
-import { TopOfViewRefType } from 'app/features/explore/TraceView/components/TraceTimelineViewer/VirtualizedTraceView';
 import { transformDataFrames } from 'app/features/explore/TraceView/utils/transform';
 
+import { replaceSearchVariables, SearchProps } from '../../../features/explore/TraceView/useSearch';
+
 const styles = {
-  wrapper: css`
-    height: 100%;
-    overflow: scroll;
-  `,
+  wrapper: css({
+    height: '100%',
+    overflow: 'scroll',
+  }),
 };
 
 export interface TracesPanelOptions {
   createSpanLink?: SpanLinkFunc;
+  focusedSpanId?: string;
+  createFocusSpanLink?: (traceId: string, spanId: string) => LinkModel<Field>;
+  spanFilters?: SearchProps;
 }
 
-export const TracesPanel = ({ data, options }: PanelProps<TracesPanelOptions>) => {
+export const TracesPanel = ({ data, options, replaceVariables }: PanelProps<TracesPanelOptions>) => {
   const topOfViewRef = createRef<HTMLDivElement>();
   const traceProp = useMemo(() => transformDataFrames(data.series[0]), [data.series]);
   const dataSource = useAsync(async () => {
@@ -42,11 +46,12 @@ export const TracesPanel = ({ data, options }: PanelProps<TracesPanelOptions>) =
         dataFrames={data.series}
         scrollElementClass={styles.wrapper}
         traceProp={traceProp}
-        queryResponse={data}
         datasource={dataSource.value}
         topOfViewRef={topOfViewRef}
-        topOfViewRefType={TopOfViewRefType.Panel}
         createSpanLink={options.createSpanLink}
+        focusedSpanId={options.focusedSpanId}
+        createFocusSpanLink={options.createFocusSpanLink}
+        spanFilters={replaceSearchVariables(replaceVariables, options.spanFilters)}
       />
     </div>
   );
