@@ -7,6 +7,11 @@ module.exports = {
   target: 'web',
   entry: {
     app: './public/app/index.ts',
+    swagger: './public/swagger/index.tsx',
+  },
+  experiments: {
+    // Required to load WASM modules.
+    asyncWebAssembly: true,
   },
   output: {
     clean: true,
@@ -21,9 +26,6 @@ module.exports = {
       // some of data source plugins use global Prism object to add the language definition
       // we want to have same Prism object in core and in grafana/ui
       prismjs: require.resolve('prismjs'),
-      // some sub-dependencies use a different version of @emotion/react and generate warnings
-      // in the browser about @emotion/react loaded twice. We want to only load it once
-      '@emotion/react': require.resolve('@emotion/react'),
       // due to our webpack configuration not understanding package.json `exports`
       // correctly we must alias this package to the correct file
       // the alternative to this alias is to copy-paste the file into our
@@ -95,20 +97,11 @@ module.exports = {
           },
         ],
       },
-      {
-        test: /\.css$/,
-        use: ['style-loader', 'css-loader'],
-      },
       {
         test: /\.(svg|ico|jpg|jpeg|png|gif|eot|otf|webp|ttf|woff|woff2|cur|ani|pdf)(\?.*)?$/,
         type: 'asset/resource',
         generator: { filename: 'static/img/[name].[hash:8][ext]' },
       },
-      // for pre-caching SVGs as part of the JS bundles
-      {
-        test: /(unicons|mono|custom)[\\/].*\.svg$/,
-        type: 'asset/source',
-      },
       {
         // Required for msagl library (used in Nodegraph panel) to work
         test: /\.m?js$/,
@@ -125,12 +118,6 @@ module.exports = {
       chunks: 'all',
       minChunks: 1,
       cacheGroups: {
-        unicons: {
-          test: /[\\/]node_modules[\\/]@iconscout[\\/]react-unicons[\\/].*[jt]sx?$/,
-          chunks: 'initial',
-          priority: 20,
-          enforce: true,
-        },
         moment: {
           test: /[\\/]node_modules[\\/]moment[\\/].*[jt]sx?$/,
           chunks: 'initial',
